@@ -1,25 +1,36 @@
 from . import exc
-from . import plot
+from . import type
 from . import util
-from . import mock
+from .numba_util import profile_func
 from .preloads import Preloads
 from .dataset import preprocess
 from .dataset.imaging import SettingsImaging
 from .dataset.imaging import Imaging
 from .dataset.imaging import SimulatorImaging
+from .dataset.imaging import WTildeImaging
 from .dataset.interferometer import Interferometer
 from .dataset.interferometer import SettingsInterferometer
 from .dataset.interferometer import SimulatorInterferometer
-from .fit.fit import FitImaging
-from .fit.fit import FitInterferometer
+from .fit.fit_data import FitData
+from .fit.fit_data import FitDataComplex
+from .fit.fit_dataset import FitDataset
+from .fit.fit_dataset import FitImaging
+from .fit.fit_dataset import FitInterferometer
 from .instruments import acs
 from .instruments import euclid
+from .inversion.mappers.abstract import AbstractMapper
 from .inversion import pixelizations as pix
 from .inversion import regularization as reg
-from .inversion.inversions import SettingsInversion
-from .inversion.inversions import inversion as Inversion
-from .inversion.mappers import mapper as Mapper
-from .inversion.pixelizations import SettingsPixelization
+from .inversion.inversion.settings import SettingsInversion
+from .inversion.inversion.factory import inversion_from as Inversion
+from .inversion.inversion.factory import (
+    inversion_imaging_unpacked_from as InversionImaging,
+)
+from .inversion.inversion.factory import (
+    inversion_interferometer_unpacked_from as InversionInterferometer,
+)
+from .inversion.mappers.abstract import mapper as Mapper
+from .inversion.pixelizations.settings import SettingsPixelization
 from .mask.mask_1d import Mask1D
 from .mask.mask_2d import Mask2D
 from .mock import fixtures
@@ -27,6 +38,7 @@ from .operators.convolver import Convolver
 from .operators.convolver import Convolver
 from .operators.transformer import TransformerDFT
 from .operators.transformer import TransformerNUFFT
+from .layout.layout import Layout1D
 from .layout.layout import Layout2D
 from .structures.arrays.one_d.array_1d import Array1D
 from .structures.arrays.two_d.array_2d import Array2D
@@ -35,15 +47,15 @@ from .structures.arrays.abstract_array import Header
 from .structures.grids.one_d.grid_1d import Grid1D
 from .structures.grids.two_d.grid_2d import Grid2D
 from .structures.grids.two_d.grid_2d import Grid2DSparse
-from .structures.grids.two_d.grid_2d_interpolate import Grid2DInterpolate
 from .structures.grids.two_d.grid_2d_iterate import Grid2DIterate
 from .structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
 from .structures.grids.two_d.grid_2d_irregular import Grid2DIrregularUniform
 from .structures.grids.two_d.grid_2d_pixelization import Grid2DRectangular
 from .structures.grids.two_d.grid_2d_pixelization import Grid2DVoronoi
 from .structures.vector_fields.vector_field_irregular import VectorField2DIrregular
-from autoarray.layout.region import Region1D
-from autoarray.layout.region import Region2D
+from .structures.grids import grid_decorators as grid_dec
+from .layout.region import Region1D
+from .layout.region import Region2D
 from .structures.kernel_2d import Kernel2D
 from .structures.visibilities import Visibilities
 from .structures.visibilities import VisibilitiesNoiseMap
@@ -52,4 +64,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "2021.6.07.1"
+__version__ = "2021.10.14.1"
