@@ -1,62 +1,82 @@
-import pickle
-
-import numpy as np
 import copy
+import numpy as np
+import pickle
+from typing import List, Optional, Type, Union
 
-from autoarray.structures import abstract_structure
-from autoarray.structures.grids.one_d import grid_1d
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures.grids.two_d import grid_2d_interpolate
-from autoarray.structures.grids.two_d import grid_2d_iterate
-from autoarray.mask import mask_1d
-from autoarray.mask import mask_2d
+from autoconf import conf
+from autoarray.structures.abstract_structure import AbstractStructure
+from autoarray.structures.arrays.one_d.array_1d import Array1D
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.grids.one_d.grid_1d import Grid1D
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.structures.grids.two_d.grid_2d_iterate import Grid2DIterate
+from autoarray.mask.mask_1d import Mask1D
+from autoarray.mask.mask_2d import Mask2D
+
+from autoarray import exc
 
 
-def grid_from_mask_and_grid_class(
-    mask, grid_class, fractional_accuracy, sub_steps, pixel_scales_interp
-):
+class AbstractWTilde:
+    def __init__(self, curvature_preload, noise_map_value):
+
+        self.curvature_preload = curvature_preload
+        self.noise_map_value = noise_map_value
+
+    def check_noise_map(self, noise_map):
+
+        if noise_map[0] != self.noise_map_value:
+            raise exc.InversionException(
+                "The preloaded values of WTildeImaging are not consistent with the noise-map passed to them, thus "
+                "they cannot be used for the inversion."
+                ""
+                f"The value of the noise map is {noise_map[0]} whereas in WTildeImaging it is {self.noise_map_value}"
+                ""
+                "Update WTildeImaging or do not use the w_tilde formalism to perform the LinearEqn."
+            )
+
+
+def grid_via_grid_class_from(
+    mask: Union[Mask1D, Mask2D],
+    grid_class: Union[Type[Grid1D], Type[Grid2D]],
+    fractional_accuracy: float,
+    sub_steps: List[int],
+) -> Optional[Union[Grid1D, Grid2D]]:
+
     if mask.pixel_scales is None:
         return None
 
     if grid_class is None:
-        if isinstance(mask, mask_1d.AbstractMask1d):
-            grid_class = grid_1d.Grid1D
-        elif isinstance(mask, mask_2d.AbstractMask2D):
-            grid_class = grid_2d.Grid2D
+        if isinstance(mask, Mask1D):
+            grid_class = Grid1D
+        elif isinstance(mask, Mask2D):
+            grid_class = Grid2D
 
-    if grid_class is grid_1d.Grid1D:
+    if grid_class is Grid1D:
 
-        return grid_1d.Grid1D.from_mask(mask=mask)
+        return Grid1D.from_mask(mask=mask)
 
-    if grid_class is grid_2d.Grid2D:
+    if grid_class is Grid2D:
 
-        return grid_2d.Grid2D.from_mask(mask=mask)
+        return Grid2D.from_mask(mask=mask)
 
-    elif grid_class is grid_2d_iterate.Grid2DIterate:
+    elif grid_class is Grid2DIterate:
 
-        return grid_2d_iterate.Grid2DIterate.from_mask(
+        return Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=fractional_accuracy, sub_steps=sub_steps
         )
 
-    elif grid_class is grid_2d_interpolate.Grid2DInterpolate:
-
-        return grid_2d_interpolate.Grid2DInterpolate.from_mask(
-            mask=mask, pixel_scales_interp=pixel_scales_interp
-        )
-
 
 class AbstractSettingsDataset:
     def __init__(
         self,
-        grid_class=None,
-        grid_inversion_class=None,
-        sub_size=2,
-        sub_size_inversion=2,
-        fractional_accuracy=0.9999,
-        sub_steps=None,
-        pixel_scales_interp=None,
-        signal_to_noise_limit=None,
-        signal_to_noise_limit_radii=None,
+        grid_class: Optional[Union[Type[Grid1D], Type[Grid2D]]] = None,
+        grid_inversion_class: Optional[Union[Type[Grid1D], Type[Grid2D]]] = None,
+        sub_size: int = 2,
+        sub_size_inversion: int = 2,
+        fractional_accuracy: float = 0.9999,
+        sub_steps: Optional[List[int]] = None,
+        signal_to_noise_limit: Optional[float] = None,
+        signal_to_noise_limit_radii: Optional[float] = None,
     ):
         """
         A dataset is a collection of data structures (e.g. the data, noise-map, PSF), a mask, grid, convolver
@@ -68,24 +88,21 @@ class AbstractSettingsDataset:
         Parameters
         ----------
         grid_class : ag.Grid2D
-            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D`,
-            `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a description of these options).
+            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D` and
+            `Grid2DIterate` (see the `Grid2D` documentation for a description of these options).
         grid_inversion_class : ag.Grid2D
-            The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
-            The options are `Grid2D`, `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a
+            The type of grid used to create the grid that maps the `LinearEqn` source pixels to the data's image-pixels.
+            The options are `Grid2D` and `Grid2DIterate` (see the `Grid2D` documentation for a
             description of these options).
-        sub_size : int
+        sub_size
             If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
-        fractional_accuracy : float
+        fractional_accuracy
             If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
             If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
-        pixel_scales_interp : float or (float, float)
-            If the grid and / or grid_inversion use a `Grid2DInterpolate`, this sets the resolution of the interpolation
-            grid.
-        signal_to_noise_limit : float
+        signal_to_noise_limit
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
             signa to noise limit.
         """
@@ -100,46 +117,44 @@ class AbstractSettingsDataset:
             sub_steps = [2, 4, 8, 16]
 
         self.sub_steps = sub_steps
-        self.pixel_scales_interp = pixel_scales_interp
         self.signal_to_noise_limit = signal_to_noise_limit
         self.signal_to_noise_limit_radii = signal_to_noise_limit_radii
 
-    def grid_from_mask(self, mask):
+    def grid_from(self, mask) -> Union[Grid1D, Grid2D]:
 
-        return grid_from_mask_and_grid_class(
+        return grid_via_grid_class_from(
             mask=mask,
             grid_class=self.grid_class,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
-            pixel_scales_interp=self.pixel_scales_interp,
         )
 
-    def grid_inversion_from_mask(self, mask):
+    def grid_inversion_from(self, mask) -> Union[Grid1D, Grid2D]:
 
-        return grid_from_mask_and_grid_class(
+        return grid_via_grid_class_from(
             mask=mask,
             grid_class=self.grid_inversion_class,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
-            pixel_scales_interp=self.pixel_scales_interp,
         )
 
 
 class AbstractDataset:
     def __init__(
         self,
-        data: abstract_structure.AbstractStructure,
-        noise_map: abstract_structure.AbstractStructure,
+        data: AbstractStructure,
+        noise_map: AbstractStructure,
         settings=AbstractSettingsDataset(),
         name: str = None,
     ):
-        """A collection of abstract data structures for different types of data (an image, pixel-scale, noise-map, etc.)
+        """
+        A collection of abstract data structures for different types of data (an image, pixel-scale, noise-map, etc.)
 
         Parameters
         ----------
-        data : abstract_structure.AbstractStructure
+        data : AbstractStructure
             The array of the image data, in units of electrons per second.
-        noise_map : abstract_structure.AbstractStructure
+        noise_map : AbstractStructure
             An array describing the RMS standard deviation error in each pixel, preferably in units of electrons per
             second.
         """
@@ -155,7 +170,7 @@ class AbstractDataset:
 
             if settings.signal_to_noise_limit_radii is not None:
 
-                signal_to_noise_mask = mask_2d.Mask2D.circular(
+                signal_to_noise_mask = Mask2D.circular(
                     shape_native=mask.shape_native,
                     radius=settings.signal_to_noise_limit_radii,
                     pixel_scales=mask.pixel_scales,
@@ -163,7 +178,7 @@ class AbstractDataset:
 
             else:
 
-                signal_to_noise_mask = mask_2d.Mask2D.unmasked(
+                signal_to_noise_mask = Mask2D.unmasked(
                     shape_native=data.shape_native, pixel_scales=mask.pixel_scales
                 )
 
@@ -176,19 +191,23 @@ class AbstractDataset:
 
             noise_map = noise_map._new_structure(noise_map_limit, mask=mask).slim
 
-        mask_grid = mask.mask_new_sub_size_from(mask=mask, sub_size=settings.sub_size)
-        self.grid = settings.grid_from_mask(mask=mask_grid)
-
         self.noise_map = noise_map
 
-        mask_inversion = mask.mask_new_sub_size_from(
-            mask=mask, sub_size=settings.sub_size_inversion
-        )
+        if conf.instance["general"]["structures"]["use_dataset_grids"]:
 
-        self.grid_inversion = settings.grid_inversion_from_mask(mask=mask_inversion)
+            mask_grid = mask.mask_new_sub_size_from(
+                mask=mask, sub_size=settings.sub_size
+            )
+            self.grid = settings.grid_from(mask=mask_grid)
+
+            mask_inversion = mask.mask_new_sub_size_from(
+                mask=mask, sub_size=settings.sub_size_inversion
+            )
+
+            self.grid_inversion = settings.grid_inversion_from(mask=mask_inversion)
 
     @property
-    def mask(self):
+    def mask(self) -> Union[Mask1D, Mask2D]:
         return self.data.mask
 
     @property
@@ -213,11 +232,11 @@ class AbstractDataset:
             return pickle.load(f)
 
     @property
-    def inverse_noise_map(self):
+    def inverse_noise_map(self) -> Union[Array1D, Array2D]:
         return 1.0 / self.noise_map
 
     @property
-    def signal_to_noise_map(self):
+    def signal_to_noise_map(self) -> Union[Array1D, Array2D]:
         """
         The estimated signal-to-noise_maps mappers of the image.
         """
@@ -226,14 +245,14 @@ class AbstractDataset:
         return signal_to_noise_map
 
     @property
-    def signal_to_noise_max(self):
+    def signal_to_noise_max(self) -> float:
         """
         The maximum value of signal-to-noise_maps in an image pixel in the image's signal-to-noise_maps mappers.
         """
         return np.max(self.signal_to_noise_map)
 
     @property
-    def absolute_signal_to_noise_map(self):
+    def absolute_signal_to_noise_map(self) -> Union[Array1D, Array2D]:
         """
         The estimated absolute_signal-to-noise_maps mappers of the image.
         """
@@ -242,14 +261,14 @@ class AbstractDataset:
         )
 
     @property
-    def absolute_signal_to_noise_max(self):
+    def absolute_signal_to_noise_max(self) -> float:
         """
         The maximum value of absolute signal-to-noise_map in an image pixel in the image's signal-to-noise_maps mappers.
         """
         return np.max(self.absolute_signal_to_noise_map)
 
     @property
-    def potential_chi_squared_map(self):
+    def potential_chi_squared_map(self) -> Union[Array1D, Array2D]:
         """
         The potential chi-squared-map of the imaging data_type. This represents how much each pixel can contribute to
         the chi-squared-map, assuming the model fails to fit it at all (e.g. model value = 0.0).
@@ -259,21 +278,13 @@ class AbstractDataset:
         )
 
     @property
-    def potential_chi_squared_max(self):
+    def potential_chi_squared_max(self) -> float:
         """
         The maximum value of the potential chi-squared-map.
         """
         return np.max(self.potential_chi_squared_map)
 
-    def modify_noise_map(self, noise_map):
-
-        imaging = copy.deepcopy(self)
-
-        imaging.noise_map = noise_map
-
-        return imaging
-
-    def trimmed_after_convolution_from(self, kernel_shape):
+    def trimmed_after_convolution_from(self, kernel_shape) -> "AbstractDataset":
 
         imaging = copy.copy(self)
 
