@@ -1,33 +1,35 @@
 import logging
 import numpy as np
 import copy
+from typing import List, Optional
+
+from autoarray.dataset.abstract_dataset import AbstractSettingsDataset
+from autoarray.dataset.abstract_dataset import AbstractDataset
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.operators.transformer import TransformerDFT
+from autoarray.operators.transformer import TransformerNUFFT
+from autoarray.structures.visibilities import Visibilities
+from autoarray.structures.visibilities import VisibilitiesNoiseMap
 
-from autoconf import conf
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d
 from autoarray.structures.arrays.two_d import array_2d_util
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures.grids.two_d import grid_2d_irregular
-from autoarray.structures import visibilities as vis
-from autoarray.dataset import abstract_dataset, preprocess
-from autoarray.operators import transformer as trans
+from autoarray.dataset import preprocess
 
 
 logger = logging.getLogger(__name__)
 
 
-class SettingsInterferometer(abstract_dataset.AbstractSettingsDataset):
+class SettingsInterferometer(AbstractSettingsDataset):
     def __init__(
         self,
-        grid_class=grid_2d.Grid2D,
-        grid_inversion_class=grid_2d.Grid2D,
-        sub_size=1,
-        sub_size_inversion=4,
-        fractional_accuracy=0.9999,
-        sub_steps=None,
-        pixel_scales_interp=None,
-        signal_to_noise_limit=None,
-        transformer_class=trans.TransformerNUFFT,
+        grid_class=Grid2D,
+        grid_inversion_class=Grid2D,
+        sub_size: int = 1,
+        sub_size_inversion=1,
+        fractional_accuracy: float = 0.9999,
+        sub_steps: List[int] = None,
+        signal_to_noise_limit: Optional[float] = None,
+        transformer_class=TransformerNUFFT,
     ):
         """
           The lens dataset is the collection of data_type (image, noise-map), a mask, grid, convolver \
@@ -40,23 +42,20 @@ class SettingsInterferometer(abstract_dataset.AbstractSettingsDataset):
           ----------
         grid_class : ag.Grid2D
             The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D`,
-            `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a description of these options).
+            and `Grid2DIterate` (see the `Grid2D` documentation for a description of these options).
         grid_inversion_class : ag.Grid2D
-            The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
-            The options are `Grid2D`, `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a
+            The type of grid used to create the grid that maps the `LinearEqn` source pixels to the data's image-pixels.
+            The options are `Grid2D` and `Grid2DIterate` (see the `Grid2D` documentation for a
             description of these options).
-        sub_size : int
+        sub_size
             If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
-        fractional_accuracy : float
+        fractional_accuracy
             If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
             If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
-        pixel_scales_interp : float or (float, float)
-            If the grid and / or grid_inversion use a `Grid2DInterpolate`, this sets the resolution of the interpolation
-            grid.
-        signal_to_noise_limit : float
+        signal_to_noise_limit
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
             signa to noise limit.
           """
@@ -68,14 +67,13 @@ class SettingsInterferometer(abstract_dataset.AbstractSettingsDataset):
             sub_size_inversion=sub_size_inversion,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
-            pixel_scales_interp=pixel_scales_interp,
             signal_to_noise_limit=signal_to_noise_limit,
         )
 
         self.transformer_class = transformer_class
 
 
-class Interferometer(abstract_dataset.AbstractDataset):
+class Interferometer(AbstractDataset):
     def __init__(
         self,
         visibilities,
@@ -120,15 +118,15 @@ class Interferometer(abstract_dataset.AbstractDataset):
         ----------
         """
 
-        visibilities = vis.Visibilities.from_fits(
+        visibilities = Visibilities.from_fits(
             file_path=visibilities_path, hdu=visibilities_hdu
         )
 
-        noise_map = vis.VisibilitiesNoiseMap.from_fits(
+        noise_map = VisibilitiesNoiseMap.from_fits(
             file_path=noise_map_path, hdu=noise_map_hdu
         )
 
-        uv_wavelengths = array_2d_util.numpy_array_2d_from_fits(
+        uv_wavelengths = array_2d_util.numpy_array_2d_via_fits_from(
             file_path=uv_wavelengths_path, hdu=uv_wavelengths_hdu
         )
 
@@ -175,29 +173,19 @@ class Interferometer(abstract_dataset.AbstractDataset):
 
     @property
     def dirty_image(self):
-        return self.transformer.image_from_visibilities(visibilities=self.visibilities)
+        return self.transformer.image_from(visibilities=self.visibilities)
 
     @property
     def dirty_noise_map(self):
-        return self.transformer.image_from_visibilities(visibilities=self.noise_map)
+        return self.transformer.image_from(visibilities=self.noise_map)
 
     @property
     def dirty_signal_to_noise_map(self):
-        return self.transformer.image_from_visibilities(
-            visibilities=self.signal_to_noise_map
-        )
+        return self.transformer.image_from(visibilities=self.signal_to_noise_map)
 
     @property
     def dirty_inverse_noise_map(self):
-        return self.transformer.image_from_visibilities(
-            visibilities=self.inverse_noise_map
-        )
-
-    def modified_visibilities_from_visibilities(self, visibilities):
-
-        interferometer = copy.deepcopy(self)
-        interferometer.data = vis.Visibilities(visibilities=visibilities)
-        return interferometer
+        return self.transformer.image_from(visibilities=self.inverse_noise_map)
 
     @property
     def signal_to_noise_map(self):
@@ -229,20 +217,12 @@ class Interferometer(abstract_dataset.AbstractDataset):
             np.imag(self.noise_map),
         )
 
-        interferometer.noise_map = vis.VisibilitiesNoiseMap(
+        interferometer.noise_map = VisibilitiesNoiseMap(
             visibilities=noise_map_limit_real + 1j * noise_map_limit_imag
         )
 
         return interferometer
 
-    def modify_noise_map(self, noise_map):
-
-        interferometer = copy.deepcopy(self)
-
-        interferometer.noise_map = noise_map
-
-        return interferometer
-
     def output_to_fits(
         self,
         visibilities_path=None,
@@ -272,8 +252,7 @@ class AbstractSimulatorInterferometer:
         self,
         uv_wavelengths,
         exposure_time: float,
-        background_sky_level: float = 0.0,
-        transformer_class=trans.TransformerDFT,
+        transformer_class=TransformerDFT,
         noise_sigma=0.1,
         noise_if_add_noise_false=0.1,
         noise_seed=-1,
@@ -283,44 +262,39 @@ class AbstractSimulatorInterferometer:
 
         Parameters
         ----------
-        real_space_shape_native : (int, int)
+        real_space_shape_native
             The shape of the observation. Note that we do not simulator a full Imaging array (e.g. 2000 x 2000 pixels for \
             Hubble imaging), but instead just a cut-out around the strong lens.
-        real_space_pixel_scales : float
+        real_space_pixel_scales
             The size of each pixel in scaled units.
         psf : PSF
             An arrays describing the PSF kernel of the image.
-        exposure_time_map : float
+        exposure_time_map
             The exposure time of an observation using this data_type.
-        background_sky_map : float
-            The level of the background sky of an observationg using this data_type.
         """
 
         self.uv_wavelengths = uv_wavelengths
         self.exposure_time = exposure_time
-        self.background_sky_level = background_sky_level
         self.transformer_class = transformer_class
         self.noise_sigma = noise_sigma
         self.noise_if_add_noise_false = noise_if_add_noise_false
         self.noise_seed = noise_seed
 
-    def from_image(self, image, name=None):
+    def via_image_from(self, image, name=None):
         """
         Returns a realistic simulated image by applying effects to a plain simulated image.
 
         Parameters
         ----------
         name
-        real_space_image : np.ndarray
+        real_space_image
             The image before simulating (e.g. the lens and source galaxies before optics blurring and UVPlane read-out).
         real_space_pixel_scales: float
             The scale of each pixel in scaled units
-        exposure_time_map : np.ndarray
+        exposure_time_map
             An array representing the effective exposure time of each pixel.
         psf: PSF
             An array describing the PSF the simulated image is blurred with.
-        background_sky_map : np.ndarray
-            The value of background sky in every image pixel (electrons per second).
         add_poisson_noise: Bool
             If `True` poisson noise_maps is simulated and added to the image, based on the total counts in each image
             pixel
@@ -332,25 +306,17 @@ class AbstractSimulatorInterferometer:
             uv_wavelengths=self.uv_wavelengths, real_space_mask=image.mask
         )
 
-        background_sky_map = array_2d.Array2D.full(
-            fill_value=self.background_sky_level,
-            shape_native=image.shape_native,
-            pixel_scales=image.pixel_scales,
-        )
-
-        image = image + background_sky_map
-
-        visibilities = transformer.visibilities_from_image(image=image)
+        visibilities = transformer.visibilities_from(image=image)
 
         if self.noise_sigma is not None:
             visibilities = preprocess.data_with_complex_gaussian_noise_added(
                 data=visibilities, sigma=self.noise_sigma, seed=self.noise_seed
             )
-            noise_map = vis.VisibilitiesNoiseMap.full(
+            noise_map = VisibilitiesNoiseMap.full(
                 fill_value=self.noise_sigma, shape_slim=(visibilities.shape[0],)
             )
         else:
-            noise_map = vis.VisibilitiesNoiseMap.full(
+            noise_map = VisibilitiesNoiseMap.full(
                 fill_value=self.noise_if_add_noise_false,
                 shape_slim=(visibilities.shape[0],),
             )
