@@ -1,7 +1,8 @@
 import numpy as np
 from scipy.stats import norm
 
-from autoarray.structures.arrays.two_d import array_2d
+from autoarray.structures.arrays.two_d import array_2d as a2d
+
 from autoarray import exc
 
 
@@ -16,9 +17,9 @@ def array_with_new_shape(array, new_shape):
 
     Parameters
     -----------
-    array : aa.Array2D
+    array
         The array which is trimmed / padded to a new 2D shape.
-    new_shape : (int, int)
+    new_shape
         The new 2D shape of the array.
     """
 
@@ -36,9 +37,9 @@ def array_eps_to_counts(array_eps, exposure_time_map):
 
     Parameters
     ----------
-    array_eps : aa.Array2D
+    array_eps
         The array which is converted from electrons per seconds to counts.
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the array.
     """
     return np.multiply(array_eps, exposure_time_map)
@@ -55,9 +56,9 @@ def array_counts_to_eps(array_counts, exposure_time_map):
 
     Parameters
     ----------
-    array_counts  : aa.Array2D
+    array_counts
         The array which is converted from counts to electrons per seconds.
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the array.
     """
     return np.divide(array_counts, exposure_time_map)
@@ -74,11 +75,11 @@ def array_eps_to_adus(array_eps, exposure_time_map, gain):
 
     Parameters
     ----------
-    array_eps  : aa.Array2D
+    array_eps
         The array which is converted from electrons per seconds to adus.
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the array.
-    gain : float
+    gain
         The gain of the instrument used in the conversion to / from counts and ADUs.
     """
     return np.multiply(array_eps, exposure_time_map) / gain
@@ -95,11 +96,11 @@ def array_adus_to_eps(array_adus, exposure_time_map, gain):
 
     Parameters
     ----------
-    array_adus  : aa.Array2D
+    array_adus
         The array which is converted from adus to electrons per seconds
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the array.
-    gain : float
+    gain
         The gain of the instrument used in the conversion to / from counts and ADUs.
     """
     return np.divide(gain * array_adus, exposure_time_map)
@@ -124,15 +125,15 @@ def array_with_random_uniform_values_added(array, upper_limit=0.001):
 
     Parameters
     ----------
-    data : aa.Array2D
+    data
         The array that the uniform noise values are added to.
-    upper_limit : float
+    upper_limit
         The upper limit of the uniform distribution from which the values are drawn.
     """
     return array + upper_limit * np.random.uniform(size=array.shape_slim)
 
 
-def noise_map_from_data_eps_and_exposure_time_map(data_eps, exposure_time_map):
+def noise_map_via_data_eps_and_exposure_time_map_from(data_eps, exposure_time_map):
     """Estimate the noise-map value in every data-point, by converting the data to units of counts and taking the
     square root of these values.
 
@@ -143,15 +144,15 @@ def noise_map_from_data_eps_and_exposure_time_map(data_eps, exposure_time_map):
 
     Parameters
     ----------
-    data_eps : aa.Array2D
+    data_eps
         The data in electrons second used to estimate the Poisson noise in every data point.
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the data.
     """
     return np.sqrt(np.abs(data_eps * exposure_time_map)) / exposure_time_map
 
 
-def noise_map_from_weight_map(weight_map):
+def noise_map_via_weight_map_from(weight_map):
     """Setup the noise-map from a weight map, which is a form of noise-map that comes via HST image-reduction and \
     the software package MultiDrizzle.
 
@@ -164,9 +165,9 @@ def noise_map_from_weight_map(weight_map):
 
     Parameters
     -----------
-    pixel_scales : float
+    pixel_scales
         The size of each pixel in scaled units.
-    weight_map : np.ndarray
+    weight_map
         The weight-value of each pixel which is converted to a variance.
     """
     np.seterr(divide="ignore")
@@ -175,7 +176,7 @@ def noise_map_from_weight_map(weight_map):
     return noise_map
 
 
-def noise_map_from_inverse_noise_map(inverse_noise_map):
+def noise_map_via_inverse_noise_map_from(inverse_noise_map):
     """Setup the noise-map from an inverse noise-map.
 
     The variance in each pixel is computed as:
@@ -184,13 +185,13 @@ def noise_map_from_inverse_noise_map(inverse_noise_map):
 
     Parameters
     -----------
-    inverse_noise_map : np.ndarray
+    inverse_noise_map
         The inverse noise_map value of each pixel which is converted to a variance.
     """
     return 1.0 / inverse_noise_map
 
 
-def noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
+def noise_map_via_data_eps_exposure_time_map_and_background_noise_map_from(
     data_eps, exposure_time_map, background_noise_map
 ):
     """Estimate the noise-map values in every data-point, by converting the data to units of counts, adding the
@@ -200,11 +201,11 @@ def noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
 
     Parameters
     ----------
-    data_eps : aa.Array2D
+    data_eps
         The data in electrons second used to estimate the Poisson noise in every data point.
-    exposure_time_map : aa.Array2D
+    exposure_time_map
         The exposure time at every data-point of the data.
-    background_noise_map : aa.Array2D
+    background_noise_map
         The RMS standard deviation error in every data point due to a background component of the noise-map in units
         of electrons per second.
     """
@@ -219,7 +220,7 @@ def noise_map_from_data_eps_exposure_time_map_and_background_noise_map(
     )
 
 
-def background_noise_map_from_edges_of_image(image, no_edges):
+def background_noise_map_via_edges_of_image_from(image, no_edges):
     """
     Estimate the background noise level in an image using the data values at its edges. These edge values are binned
     into a histogram, with a Gaussian profile fitted to this histogram, such that its standard deviation (sigma) gives
@@ -229,9 +230,9 @@ def background_noise_map_from_edges_of_image(image, no_edges):
 
     Parameters
     ----------
-    image : aa.Array2D
+    image
         The image whose edge values are used to estimate the background noise.
-    no_edges : int
+    no_edges
         Number of edges used to estimate the background level.
     """
 
@@ -253,14 +254,14 @@ def background_noise_map_from_edges_of_image(image, no_edges):
 
         edges = np.concatenate((edges, top_edge, bottom_edge, right_edge, left_edge))
 
-    return array_2d.Array2D.full(
+    return a2d.Array2D.full(
         fill_value=norm.fit(edges)[1],
         shape_native=image.shape_native,
         pixel_scales=image.pixel_scales,
     )
 
 
-def psf_with_odd_dimensions_from_psf(psf):
+def psf_with_odd_dimensions_from(psf):
     """
     If the PSF kernel has one or two even-sized dimensions, return a PSF object where the kernel has odd-sized
     dimensions (odd-sized dimensions are required by a *Convolver*).
@@ -271,16 +272,16 @@ def psf_with_odd_dimensions_from_psf(psf):
 
     Parameters
     ----------
-    rescale_factor : float
+    rescale_factor
         The factor by which the kernel is rescaled. If this has a value of 1.0, the kernel is rescaled to the
         closest odd-sized dimensions (e.g. 20 -> 19). Higher / lower values scale to higher / lower dimensions.
     normalize : bool
         Whether the PSF should be normalized after being rescaled.
     """
-    return psf.rescaled_with_odd_dimensions_from_rescale_factor(rescale_factor=1.0)
+    return psf.rescaled_with_odd_dimensions_from(rescale_factor=1.0)
 
 
-def exposure_time_map_from_exposure_time_and_background_noise_map(
+def exposure_time_map_via_exposure_time_and_background_noise_map_from(
     exposure_time, background_noise_map
 ):
     """
@@ -291,9 +292,9 @@ def exposure_time_map_from_exposure_time_and_background_noise_map(
 
     Parameters
     ----------
-    exposure_time : float
+    exposure_time
         The total exposure time of the observation.
-    background_noise_map : aa.Array2D
+    background_noise_map
         The RMS standard deviation error in every data point due to a background component of the noise-map in units
         of electrons per second.
     """
@@ -310,7 +311,7 @@ def setup_random_seed(seed):
 
     Parameters
     ----------
-    seed : int
+    seed
         The seed of the random number generator.
     """
     if seed == -1:
@@ -320,7 +321,7 @@ def setup_random_seed(seed):
     np.random.seed(seed)
 
 
-def poisson_noise_from_data_eps(data_eps, exposure_time_map, seed=-1):
+def poisson_noise_via_data_eps_from(data_eps, exposure_time_map, seed=-1):
     """
     Generate a two-dimensional poisson noise_maps-mappers from an image.
 
@@ -328,11 +329,11 @@ def poisson_noise_from_data_eps(data_eps, exposure_time_map, seed=-1):
 
     Parameters
     ----------
-    data_eps : np.ndarray
+    data_eps
         The 2D image, whose values in counts are used to draw Poisson noise_maps values.
     exposure_time_map : Union(ndarray, int)
         2D array of the exposure time in each pixel used to convert to / from counts and electrons per second.
-    seed : int
+    seed
         The seed of the random number generator, used for the random noise_maps maps.
 
     Returns
@@ -355,11 +356,11 @@ def data_eps_with_poisson_noise_added(data_eps, exposure_time_map, seed=-1):
 
     Parameters
     ----------
-    data_eps : np.ndarray
+    data_eps
         The 2D image, whose values in counts are used to draw Poisson noise_maps values.
     exposure_time_map : Union(ndarray, int)
         2D array of the exposure time in each pixel used to convert to / from counts and electrons per second.
-    seed : int
+    seed
         The seed of the random number generator, used for the random noise_maps maps.
 
     Returns
@@ -367,21 +368,21 @@ def data_eps_with_poisson_noise_added(data_eps, exposure_time_map, seed=-1):
     poisson_noise_map: np.ndarray
         An array describing simulated poisson noise_maps
     """
-    return data_eps + poisson_noise_from_data_eps(
+    return data_eps + poisson_noise_via_data_eps_from(
         data_eps=data_eps, exposure_time_map=exposure_time_map, seed=seed
     )
 
 
-def gaussian_noise_from_shape_and_sigma(shape, sigma, seed=-1):
+def gaussian_noise_via_shape_and_sigma_from(shape, sigma, seed=-1):
     """Generate a two-dimensional read noises-map, generating values from a Gaussian distribution with mean 0.0.
 
     Params
     ----------
-    shape : (int, int)
+    shape
         The (x,y) image_shape of the generated Gaussian noises map.
-    read_noise : float
+    read_noise
         Standard deviation of the 1D Gaussian that each noises value is drawn from
-    seed : int
+    seed
         The seed of the random number generator, used for the random noises maps.
     """
     if seed == -1:
@@ -393,14 +394,14 @@ def gaussian_noise_from_shape_and_sigma(shape, sigma, seed=-1):
 
 
 def data_with_gaussian_noise_added(data, sigma, seed=-1):
-    return data + gaussian_noise_from_shape_and_sigma(
+    return data + gaussian_noise_via_shape_and_sigma_from(
         shape=data.shape, sigma=sigma, seed=seed
     )
 
 
 def data_with_complex_gaussian_noise_added(data, sigma, seed=-1):
 
-    gaussian_noise = gaussian_noise_from_shape_and_sigma(
+    gaussian_noise = gaussian_noise_via_shape_and_sigma_from(
         shape=(data.shape[0], 2), sigma=sigma, seed=seed
     )
 
