@@ -48,3 +48,11 @@ class InversionException(Exception):
 
 class PlottingException(Exception):
     pass
+
+
+class PreloadsException(Exception):
+    pass
+
+
+class ProfilingException(Exception):
+    pass
