@@ -1,25 +1,26 @@
-from autoarray.structures.arrays import abstract_array
-from autoarray.structures.arrays.two_d import array_2d_util
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.layout import layout as lo, layout_util
-from autoarray.layout import region as reg
-from autoarray import exc
-
 from astropy.io import fits
-
+import copy
+import logging
 import numpy as np
-import shutil
 import os
 from os import path
+import shutil
 
-import logging
+from autoarray.structures.arrays.abstract_array import Header
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.layout.layout import Layout2D
+from autoarray.layout.region import Region2D
+
+from autoarray import exc
+from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.layout import layout_util
 
 logging.basicConfig()
 logger = logging.getLogger()
 logger.setLevel("INFO")
 
 
-def fits_hdu_from_quadrant_letter(quadrant_letter):
+def fits_hdu_via_quadrant_letter_from(quadrant_letter):
 
     if quadrant_letter == "D" or quadrant_letter == "C":
         return 1
@@ -39,9 +40,11 @@ def array_eps_to_counts(array_eps, bscale, bzero):
     return (array_eps - bzero) / bscale
 
 
-class Array2DACS(array_2d.Array2D):
+class Array2DACS(Array2D):
     """
-    An ACS array consists of four quadrants ('A', 'B', 'C', 'D') which have the following layout:
+    An ACS array consists of four quadrants ('A', 'B', 'C', 'D') which have the following layout (which are described
+    at the following STScI 
+    link https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418).
 
        <--------S-----------   ---------S----------->
     [] [========= 2 =========] [========= 3 =========] []          /\
@@ -65,13 +68,15 @@ class Array2DACS(array_2d.Array2D):
         the rotations required to give correct arctic clocking and convert the image from units of COUNTS / CPS to
         ELECTRONS.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+        
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
 
-        hdu = fits_hdu_from_quadrant_letter(quadrant_letter=quadrant_letter)
+        hdu = fits_hdu_via_quadrant_letter_from(quadrant_letter=quadrant_letter)
 
-        array = array_2d_util.numpy_array_2d_from_fits(file_path=file_path, hdu=hdu)
+        array = array_2d_util.numpy_array_2d_via_fits_from(file_path=file_path, hdu=hdu)
 
         return cls.from_ccd(array_electrons=array, quadrant_letter=quadrant_letter)
 
@@ -88,8 +93,10 @@ class Array2DACS(array_2d.Array2D):
         Using an input array of both quadrants in electrons, use the quadrant letter to extract the quadrant from the
         full CCD and perform the rotations required to give correct arctic.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+        
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
         if quadrant_letter == "A":
 
@@ -134,7 +141,7 @@ class Array2DACS(array_2d.Array2D):
                 "Quadrant letter for FrameACS must be A, B, C or D."
             )
 
-        return cls.quadrant(
+        return cls.quadrant_a(
             array_electrons=array_electrons,
             header=header,
             roe_corner=roe_corner,
@@ -144,7 +151,7 @@ class Array2DACS(array_2d.Array2D):
         )
 
     @classmethod
-    def quadrant(
+    def quadrant_a(
         cls,
         array_electrons,
         roe_corner,
@@ -157,11 +164,13 @@ class Array2DACS(array_2d.Array2D):
         Use an input array of the left quadrant in electrons and perform the rotations required to give correct
         arctic clocking.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+        
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=roe_corner
         )
 
@@ -180,7 +189,7 @@ class Array2DACS(array_2d.Array2D):
 
         if bias is not None:
 
-            bias = layout_util.rotate_array_from_roe_corner(
+            bias = layout_util.rotate_array_via_roe_corner_from(
                 array=bias, roe_corner=roe_corner
             )
 
@@ -201,11 +210,13 @@ class Array2DACS(array_2d.Array2D):
         Use an input array of the right quadrant in electrons and perform the rotations required to give correct
         arctic clocking.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(1, 1)
         )
 
@@ -223,7 +234,7 @@ class Array2DACS(array_2d.Array2D):
 
         if bias is not None:
 
-            bias = layout_util.rotate_array_from_roe_corner(
+            bias = layout_util.rotate_array_via_roe_corner_from(
                 array=bias, roe_corner=(1, 1)
             )
 
@@ -243,11 +254,13 @@ class Array2DACS(array_2d.Array2D):
         Use an input array of the left quadrant in electrons and perform the rotations required to give correct
         arctic clocking.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(1, 0)
         )
 
@@ -263,7 +276,7 @@ class Array2DACS(array_2d.Array2D):
 
         if bias is not None:
 
-            bias = layout_util.rotate_array_from_roe_corner(
+            bias = layout_util.rotate_array_via_roe_corner_from(
                 array=bias, roe_corner=(1, 0)
             )
 
@@ -281,11 +294,13 @@ class Array2DACS(array_2d.Array2D):
         Use an input array of the right quadrant in electrons and perform the rotations required to give correct
         arctic clocking.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(1, 1)
         )
 
@@ -300,7 +315,7 @@ class Array2DACS(array_2d.Array2D):
 
         if bias is not None:
 
-            bias = layout_util.rotate_array_from_roe_corner(
+            bias = layout_util.rotate_array_via_roe_corner_from(
                 array=bias, roe_corner=(1, 1)
             )
 
@@ -358,8 +373,9 @@ class ImageACS(Array2DACS):
         cls,
         file_path,
         quadrant_letter,
+        bias_subtract_via_bias_file=False,
         bias_subtract_via_prescan=False,
-        bias_path=None,
+        bias_file_path=None,
         use_calibrated_gain=True,
     ):
         """
@@ -367,16 +383,32 @@ class ImageACS(Array2DACS):
         the rotations required to give correct arctic clocking and convert the image from units of COUNTS / CPS to
         ELECTRONS.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
+
+        Also see https://github.com/spacetelescope/hstcal/blob/master/pkg/acs/calacs/acscte/dopcte-gen2.c#L418
+
+        Parameters
+        ----------
+        file_path
+            The full path of the file that the image is loaded from, including the file name and ``.fits`` extension.
+        quadrant_letter
+            The letter of the ACS quadrant the image is extracted from and loaded.
+        bias_subtract_via_bias_file
+            If True, the corresponding bias file of the image is loaded (via the name of the file in the fits header).
+        bias_subtract_via_prescan
+            If True, the prescan on the image is used to estimate a component of bias that is subtracted from the image.
+        bias_file_path
+            If `bias_subtract_via_bias_file=True`, this overwrites the path to the bias file instead of the default
+            behaviour of using the .fits header.
+        use_calibrated_gain
+            If True, the calibrated gain values are used to convert from COUNTS to ELECTRONS.
         """
 
-        hdu = fits_hdu_from_quadrant_letter(quadrant_letter=quadrant_letter)
+        hdu = fits_hdu_via_quadrant_letter_from(quadrant_letter=quadrant_letter)
 
-        header_sci_obj = array_2d_util.header_obj_from_fits(file_path=file_path, hdu=0)
-        header_hdu_obj = array_2d_util.header_obj_from_fits(
-            file_path=file_path, hdu=hdu
-        )
+        header_sci_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=0)
+        header_hdu_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=hdu)
 
         header = HeaderACS(
             header_sci_obj=header_sci_obj,
@@ -395,28 +427,30 @@ class ImageACS(Array2DACS):
                 f"The file {file_path} does not point to a valid HST ACS dataset."
             )
 
-        array = array_2d_util.numpy_array_2d_from_fits(
+        array = array_2d_util.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=hdu, do_not_scale_image_data=True
         )
 
-        array = header.array_from_original_to_electrons(array=array)
+        array = header.array_original_to_electrons(
+            array=array, use_calibrated_gain=use_calibrated_gain
+        )
 
-        if use_calibrated_gain:
-            array = array * header.calibrated_gain
-        else:
-            array = array * header.gain
+        if bias_subtract_via_bias_file:
 
-        if bias_path is not None:
+            if bias_file_path is None:
 
-            bias = array_2d_util.numpy_array_2d_from_fits(
-                file_path=bias_path, hdu=hdu, do_not_scale_image_data=True
+                file_dir = os.path.split(file_path)[0]
+                bias_file_path = path.join(file_dir, header.bias_file)
+
+            bias = array_2d_util.numpy_array_2d_via_fits_from(
+                file_path=bias_file_path, hdu=hdu, do_not_scale_image_data=True
             )
 
-            header_sci_obj = array_2d_util.header_obj_from_fits(
-                file_path=bias_path, hdu=0
+            header_sci_obj = array_2d_util.header_obj_from(
+                file_path=bias_file_path, hdu=0
             )
-            header_hdu_obj = array_2d_util.header_obj_from_fits(
-                file_path=bias_path, hdu=hdu
+            header_hdu_obj = array_2d_util.header_obj_from(
+                file_path=bias_file_path, hdu=hdu
             )
 
             bias_header = HeaderACS(
@@ -445,24 +479,24 @@ class ImageACS(Array2DACS):
         )
 
 
-class Layout2DACS(lo.Layout2D):
+class Layout2DACS(Layout2D):
     @classmethod
     def from_sizes(cls, roe_corner, serial_prescan_size=24, parallel_overscan_size=20):
         """
         Use an input array of the left quadrant in electrons and perform the rotations required to give correct
         arctic clocking.
 
-        See the docstring of the `FrameACS` class for a complete description of the Euclid FPA, quadrants and
+        See the docstring of the `FrameACS` class for a complete description of the HST FPA, quadrants and
         rotations.
         """
 
-        parallel_overscan = reg.Region2D(
+        parallel_overscan = Region2D(
             (2068 - parallel_overscan_size, 2068, serial_prescan_size, 2072)
         )
 
-        serial_prescan = reg.Region2D((0, 2068, 0, serial_prescan_size))
+        serial_prescan = Region2D((0, 2068, 0, serial_prescan_size))
 
-        return lo.Layout2D.rotated_from_roe_corner(
+        return Layout2D.rotated_from_roe_corner(
             roe_corner=roe_corner,
             shape_native=(2068, 2072),
             parallel_overscan=parallel_overscan,
@@ -470,7 +504,7 @@ class Layout2DACS(lo.Layout2D):
         )
 
 
-class HeaderACS(abstract_array.Header):
+class HeaderACS(Header):
     def __init__(
         self,
         header_sci_obj,
@@ -506,7 +540,7 @@ class HeaderACS(abstract_array.Header):
         if round(self.gain) == 1:
             calibrated_gain = [0.99989998, 0.97210002, 1.01070000, 1.01800000]
         elif round(self.gain) == 2:
-            calibrated_gain = [0.99989998, 0.97210002, 1.01070000, 1.01800000]
+            calibrated_gain = [2.002, 1.945, 2.028, 1.994]
         elif round(self.gain) == 4:
             calibrated_gain = [4.011, 3.902, 4.074, 3.996]
         else:
@@ -527,19 +561,33 @@ class HeaderACS(abstract_array.Header):
     def original_units(self):
         return self.header_hdu_obj["BUNIT"]
 
+    @property
+    def bias_file(self):
+        return self.header_sci_obj["BIASFILE"].replace("jref$", "")
+
     def array_eps_to_counts(self, array_eps):
         return array_eps_to_counts(
             array_eps=array_eps, bscale=self.bscale, bzero=self.bzero
         )
 
-    def array_from_original_to_electrons(self, array):
+    def array_original_to_electrons(self, array, use_calibrated_gain):
 
         if self.original_units in "COUNTS":
-            return (array * self.bscale) + self.bzero
+            array = (array * self.bscale) + self.bzero
         elif self.original_units in "CPS":
-            return (array * self.exposure_time * self.bscale) + self.bzero
+            array = (array * self.exposure_time * self.bscale) + self.bzero
 
-    def array_from_electrons_to_original(self, array):
+        if use_calibrated_gain:
+            return array * self.calibrated_gain
+        else:
+            return array * self.gain
+
+    def array_electrons_to_original(self, array, use_calibrated_gain):
+
+        if use_calibrated_gain:
+            array /= self.calibrated_gain
+        else:
+            array /= self.gain
 
         if self.original_units in "COUNTS":
             return (array - self.bzero) / self.bscale
@@ -563,10 +611,10 @@ def prescan_fitted_bias_column(prescan, n_rows=2048, n_rows_ov=20):
         number of rows but may skip the first few columns of the prescan to
         avoid trails.
 
-    n_rows : int
+    n_rows
         The number of rows in the image, exculding overscan.
 
-    n_rows_ov : int, int
+    n_rows_ov, int
         The number of overscan rows in the image.
 
     Returns
@@ -602,11 +650,15 @@ def prescan_fitted_bias_column(prescan, n_rows=2048, n_rows_ov=20):
 
 
 def output_quadrants_to_fits(
+    file_path: str,
     quadrant_a,
     quadrant_b,
     quadrant_c,
     quadrant_d,
-    file_path: str,
+    header_a=None,
+    header_b=None,
+    header_c=None,
+    header_d=None,
     overwrite: bool = False,
 ):
 
@@ -618,63 +670,95 @@ def output_quadrants_to_fits(
     if overwrite and os.path.exists(file_path):
         os.remove(file_path)
 
-    quadrant_a = quadrant_convert_to_original(
-        quadrant=quadrant_a, roe_corner=(1, 0), use_flipud=True
-    )
-    quadrant_b = quadrant_convert_to_original(
-        quadrant=quadrant_b, roe_corner=(1, 1), use_flipud=True
-    )
-    quadrant_c = quadrant_convert_to_original(
-        quadrant=quadrant_c, roe_corner=(1, 0), use_flipud=False
-    )
-    quadrant_d = quadrant_convert_to_original(
-        quadrant=quadrant_d, roe_corner=(1, 1), use_flipud=False
-    )
-
     array_hdu_1 = np.zeros((2068, 4144))
-    array_hdu_1[0:2068, 0:2072] = quadrant_c.native
-    array_hdu_1[0:2068, 2072:4144] = quadrant_d.native
-
     array_hdu_4 = np.zeros((2068, 4144))
-    array_hdu_4[0:2068, 0:2072] = quadrant_a.native
-    array_hdu_4[0:2068, 2072:4144] = quadrant_b.native
 
-    hdul = fits.HDUList()
+    def get_header(quadrant):
+        try:
+            return quadrant.header
+        except AttributeError:
+            raise (
+                "You must pass in the header of the quadrants to output them to an ACS fits file."
+            )
 
-    hdul.append(fits.ImageHDU(np.zeros(array_hdu_1.shape)))
-    hdul.append(fits.ImageHDU(array_hdu_1))
-    hdul.append(fits.ImageHDU(np.zeros(array_hdu_1.shape)))
-    hdul.append(fits.ImageHDU(np.zeros(array_hdu_1.shape)))
-    hdul.append(fits.ImageHDU(array_hdu_4))
-    hdul.append(fits.ImageHDU(np.zeros(array_hdu_1.shape)))
+    header_a = get_header(quadrant_a) if header_a is None else header_a
+    try:
+        quadrant_a = copy.copy(np.asarray(quadrant_a.native))
+    except AttributeError:
+        quadrant_a = copy.copy(np.asarray(quadrant_a))
 
-    hdul[0].header = quadrant_a.header.header_sci_obj
-    hdul[1].header = quadrant_c.header.header_hdu_obj
-    hdul[4].header = quadrant_a.header.header_hdu_obj
+    quadrant_a = quadrant_convert_to_original(
+        quadrant=quadrant_a, roe_corner=(1, 0), header=header_a, use_flipud=True
+    )
+    array_hdu_4[0:2068, 0:2072] = quadrant_a
 
-    hdul.writeto(file_path)
+    header_b = get_header(quadrant_b) if header_b is None else header_b
+
+    try:
+        quadrant_b = copy.copy(np.asarray(quadrant_b.native))
+    except AttributeError:
+        quadrant_b = copy.copy(np.asarray(quadrant_b))
+    quadrant_b = quadrant_convert_to_original(
+        quadrant=quadrant_b, roe_corner=(1, 1), header=header_b, use_flipud=True
+    )
+    array_hdu_4[0:2068, 2072:4144] = quadrant_b
+
+    header_c = get_header(quadrant_c) if header_c is None else header_c
+    try:
+        quadrant_c = copy.copy(np.asarray(quadrant_c.native))
+    except AttributeError:
+        quadrant_c = copy.copy(np.asarray(quadrant_c))
+    quadrant_c = quadrant_convert_to_original(
+        quadrant=quadrant_c, roe_corner=(1, 0), header=header_c, use_flipud=False
+    )
+    array_hdu_1[0:2068, 0:2072] = quadrant_c
+
+    header_d = get_header(quadrant_d) if header_d is None else header_d
+    try:
+        quadrant_d = copy.copy(np.asarray(quadrant_d.native))
+    except AttributeError:
+        quadrant_d = copy.copy(np.asarray(quadrant_d))
+    quadrant_d = quadrant_convert_to_original(
+        quadrant=quadrant_d, roe_corner=(1, 1), header=header_d, use_flipud=False
+    )
+    array_hdu_1[0:2068, 2072:4144] = quadrant_d
+
+    hdu_list = fits.HDUList()
+
+    hdu_list.append(fits.ImageHDU())
+    hdu_list.append(fits.ImageHDU(array_hdu_1))
+    hdu_list.append(fits.ImageHDU())
+    hdu_list.append(fits.ImageHDU())
+    hdu_list.append(fits.ImageHDU(array_hdu_4))
+    hdu_list.append(fits.ImageHDU())
+
+    def set_header(header):
+        header.set("cticor", "ARCTIC", "CTI CORRECTION PERFORMED USING ARCTIC")
+        return header
+
+    hdu_list[0].header = set_header(header_a.header_sci_obj)
+    hdu_list[1].header = set_header(header_c.header_hdu_obj)
+    hdu_list[4].header = set_header(header_a.header_hdu_obj)
+    hdu_list.writeto(file_path)
 
 
 def quadrant_convert_to_original(
-    quadrant, roe_corner, use_flipud=False, use_calibrated_gain=True
+    quadrant, roe_corner, header, use_flipud=False, use_calibrated_gain=True
 ):
 
-    if quadrant.header.bias is not None:
-        quadrant += quadrant.header.bias
+    if header.bias is not None:
+        quadrant += header.bias.native
 
-    if quadrant.header.bias_serial_prescan_column is not None:
-        quadrant += quadrant.bias_serial_prescan_column
+    if header.bias_serial_prescan_column is not None:
+        quadrant += header.bias_serial_prescan_column
 
-    if use_calibrated_gain:
-        quadrant /= quadrant.header.calibrated_gain
-    else:
-        quadrant /= quadrant.header.gain
-
-    quadrant = quadrant.header.array_from_electrons_to_original(array=quadrant)
+    quadrant = header.array_electrons_to_original(
+        array=quadrant, use_calibrated_gain=use_calibrated_gain
+    )
 
     if use_flipud:
-        quadrant = np.flipud(quadrant.native)
+        quadrant = np.flipud(quadrant)
 
-    return layout_util.rotate_array_from_roe_corner(
-        array=quadrant.native, roe_corner=roe_corner
+    return layout_util.rotate_array_via_roe_corner_from(
+        array=quadrant, roe_corner=roe_corner
     )
