@@ -1,6 +1,9 @@
-from autoarray.layout import layout as lo, layout_util
-from autoarray.layout import region as reg
-from autoarray.structures.arrays.two_d import array_2d
+from autoarray.structures.arrays.abstract_array import Header
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.layout.layout import Layout2D
+from autoarray.layout.region import Region2D
+
+from autoarray.layout import layout_util
 
 
 def roe_corner_from(ccd_id, quadrant_id):
@@ -25,7 +28,7 @@ def roe_corner_from(ccd_id, quadrant_id):
         return (1, 1)
 
 
-class Array2DEuclid(array_2d.Array2D):
+class Array2DEuclid(Array2D):
     """
     In the Euclid FPA, the quadrant id ('E', 'F', 'G', 'H') depends on whether the CCD is located
     on the left side (rows 1-3) or right side (rows 4-6) of the FPA:
@@ -89,23 +92,8 @@ class Array2DEuclid(array_2d.Array2D):
         ccd_id = ext_header["CCDID"]
         quadrant_id = ext_header["QUADID"]
 
-        parallel_overscan_size = ext_header.get("PAROVRX", default=None)
-        if parallel_overscan_size is None:
-            parallel_overscan_size = 0
-        serial_overscan_size = ext_header.get("OVRSCANX", default=None)
-        serial_prescan_size = ext_header.get("PRESCANX", default=None)
-        serial_size = ext_header.get("NAXIS1", default=None)
-        parallel_size = ext_header.get("NAXIS2", default=None)
-
         return cls.from_ccd_and_quadrant_id(
-            array=array,
-            ccd_id=ccd_id,
-            quadrant_id=quadrant_id,
-            parallel_size=parallel_size,
-            serial_size=serial_size,
-            serial_prescan_size=serial_prescan_size,
-            serial_overscan_size=serial_overscan_size,
-            parallel_overscan_size=parallel_overscan_size,
+            array=array, ccd_id=ccd_id, quadrant_id=quadrant_id
         )
 
     @classmethod
@@ -147,11 +135,13 @@ class Array2DEuclid(array_2d.Array2D):
         rotations.
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(0, 0)
         )
 
-        return cls.manual(array=array_electrons, pixel_scales=0.1)
+        header = Header(original_roe_corner=(0, 0))
+
+        return cls.manual(array=array_electrons, pixel_scales=0.1, header=header)
 
     @classmethod
     def top_right(cls, array_electrons):
@@ -163,11 +153,13 @@ class Array2DEuclid(array_2d.Array2D):
         rotations.
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(0, 1)
         )
 
-        return cls.manual(array=array_electrons, pixel_scales=0.1)
+        header = Header(original_roe_corner=(0, 1))
+
+        return cls.manual(array=array_electrons, pixel_scales=0.1, header=header)
 
     @classmethod
     def bottom_left(cls, array_electrons):
@@ -179,11 +171,13 @@ class Array2DEuclid(array_2d.Array2D):
         rotations.
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(1, 0)
         )
 
-        return cls.manual(array=array_electrons, pixel_scales=0.1)
+        header = Header(original_roe_corner=(1, 0))
+
+        return cls.manual(array=array_electrons, pixel_scales=0.1, header=header)
 
     @classmethod
     def bottom_right(cls, array_electrons):
@@ -195,14 +189,47 @@ class Array2DEuclid(array_2d.Array2D):
         rotations.
         """
 
-        array_electrons = layout_util.rotate_array_from_roe_corner(
+        array_electrons = layout_util.rotate_array_via_roe_corner_from(
             array=array_electrons, roe_corner=(1, 1)
         )
 
-        return cls.manual(array=array_electrons, pixel_scales=0.1)
+        header = Header(original_roe_corner=(1, 1))
+
+        return cls.manual(array=array_electrons, pixel_scales=0.1, header=header)
 
 
-class Layout2DEuclid(lo.Layout2D):
+class Layout2DEuclid(Layout2D):
+    @classmethod
+    def from_fits_header(cls, ext_header):
+        """
+        Use an input array of a Euclid quadrant and its corresponding .fits file header to rotate the quadrant to
+        the correct orientation for arCTIc clocking.
+
+        See the docstring of the `Array2DEuclid` class for a complete description of the Euclid FPA, quadrants and
+        rotations.
+        """
+
+        ccd_id = ext_header["CCDID"]
+        quadrant_id = ext_header["QUADID"]
+
+        parallel_overscan_size = ext_header.get("PAROVRX", default=None)
+        if parallel_overscan_size is None:
+            parallel_overscan_size = 0
+        serial_overscan_size = ext_header.get("OVRSCANX", default=None)
+        serial_prescan_size = ext_header.get("PRESCANX", default=None)
+        serial_size = ext_header.get("NAXIS1", default=None)
+        parallel_size = ext_header.get("NAXIS2", default=None)
+
+        return cls.from_ccd_and_quadrant_id(
+            ccd_id=ccd_id,
+            quadrant_id=quadrant_id,
+            parallel_size=parallel_size,
+            serial_size=serial_size,
+            parallel_overscan_size=parallel_overscan_size,
+            serial_prescan_size=serial_prescan_size,
+            serial_overscan_size=serial_overscan_size,
+        )
+
     @classmethod
     def from_ccd_and_quadrant_id(
         cls,
@@ -301,7 +328,7 @@ class Layout2DEuclid(lo.Layout2D):
 
         if parallel_overscan_size > 0:
 
-            parallel_overscan = reg.Region2D(
+            parallel_overscan = Region2D(
                 (
                     0,
                     parallel_overscan_size,
@@ -314,8 +341,8 @@ class Layout2DEuclid(lo.Layout2D):
 
             parallel_overscan = None
 
-        serial_prescan = reg.Region2D((0, parallel_size, 0, serial_prescan_size))
-        serial_overscan = reg.Region2D(
+        serial_prescan = Region2D((0, parallel_size, 0, serial_prescan_size))
+        serial_overscan = Region2D(
             (
                 0,
                 parallel_size - parallel_overscan_size,
@@ -332,7 +359,7 @@ class Layout2DEuclid(lo.Layout2D):
             serial_overscan=serial_overscan,
         )
 
-        return layout_2d.new_rotated_from_roe_corner(roe_corner=(0, 0))
+        return layout_2d.new_rotated_from(roe_corner=(0, 0))
 
     @classmethod
     def top_right(
@@ -346,7 +373,7 @@ class Layout2DEuclid(lo.Layout2D):
 
         if parallel_overscan_size > 0:
 
-            parallel_overscan = reg.Region2D(
+            parallel_overscan = Region2D(
                 (
                     0,
                     parallel_overscan_size,
@@ -359,10 +386,10 @@ class Layout2DEuclid(lo.Layout2D):
 
             parallel_overscan = None
 
-        serial_prescan = reg.Region2D(
+        serial_prescan = Region2D(
             (0, parallel_size, serial_size - serial_prescan_size, serial_size)
         )
-        serial_overscan = reg.Region2D(
+        serial_overscan = Region2D(
             (0, parallel_size - parallel_overscan_size, 0, serial_overscan_size)
         )
 
@@ -374,7 +401,7 @@ class Layout2DEuclid(lo.Layout2D):
             serial_overscan=serial_overscan,
         )
 
-        return layout_2d.new_rotated_from_roe_corner(roe_corner=(0, 1))
+        return layout_2d.new_rotated_from(roe_corner=(0, 1))
 
     @classmethod
     def bottom_left(
@@ -388,7 +415,7 @@ class Layout2DEuclid(lo.Layout2D):
 
         if parallel_overscan_size > 0:
 
-            parallel_overscan = reg.Region2D(
+            parallel_overscan = Region2D(
                 (
                     parallel_size - parallel_overscan_size,
                     parallel_size,
@@ -401,8 +428,8 @@ class Layout2DEuclid(lo.Layout2D):
 
             parallel_overscan = None
 
-        serial_prescan = reg.Region2D((0, parallel_size, 0, serial_prescan_size))
-        serial_overscan = reg.Region2D(
+        serial_prescan = Region2D((0, parallel_size, 0, serial_prescan_size))
+        serial_overscan = Region2D(
             (
                 0,
                 parallel_size - parallel_overscan_size,
@@ -419,7 +446,7 @@ class Layout2DEuclid(lo.Layout2D):
             serial_overscan=serial_overscan,
         )
 
-        return layout_2d.new_rotated_from_roe_corner(roe_corner=(1, 0))
+        return layout_2d.new_rotated_from(roe_corner=(1, 0))
 
     @classmethod
     def bottom_right(
@@ -433,7 +460,7 @@ class Layout2DEuclid(lo.Layout2D):
 
         if parallel_overscan_size > 0:
 
-            parallel_overscan = reg.Region2D(
+            parallel_overscan = Region2D(
                 (
                     parallel_size - parallel_overscan_size,
                     parallel_size,
@@ -446,10 +473,10 @@ class Layout2DEuclid(lo.Layout2D):
 
             parallel_overscan = None
 
-        serial_prescan = reg.Region2D(
+        serial_prescan = Region2D(
             (0, parallel_size, serial_size - serial_prescan_size, serial_size)
         )
-        serial_overscan = reg.Region2D(
+        serial_overscan = Region2D(
             (0, parallel_size - parallel_overscan_size, 0, serial_overscan_size)
         )
 
@@ -461,4 +488,4 @@ class Layout2DEuclid(lo.Layout2D):
             serial_overscan=serial_overscan,
         )
 
-        return layout_2d.new_rotated_from_roe_corner(roe_corner=(1, 1))
+        return layout_2d.new_rotated_from(roe_corner=(1, 1))
