@@ -1,8 +1,37 @@
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.layout import region as reg
+from autoarray.structures.arrays.one_d.array_1d import Array1D
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.layout.region import Region1D
+from autoarray.layout.region import Region2D
+
 from autoarray.layout import layout_util
 
 
+class Layout1D:
+    def __init__(self, shape_1d, prescan=None, overscan=None):
+        """
+        Abstract base class for a layout, which defines the regions a signal, its input normalization and other
+        properties.
+        """
+
+        self.shape_1d = shape_1d
+
+        if isinstance(prescan, tuple):
+            prescan = Region1D(region=prescan)
+
+        if isinstance(overscan, tuple):
+            overscan = Region1D(region=overscan)
+
+        self.prescan = prescan
+        self.overscan = overscan
+
+    def extract_overscan_array_1d_from(self, array):
+        return Array1D.manual_native(
+            array=array.native[self.overscan.slice],
+            header=array.header,
+            pixel_scales=array.pixel_scales,
+        )
+
+
 class Layout2D:
     def __init__(
         self,
@@ -18,7 +47,7 @@ class Layout2D:
 
         Parameters
         -----------
-        normalization : float
+        normalization
             The normalization of the charge injection lines.
         regions: [(int,)]
             A list of the integer coordinates specifying the corners of each charge injection region \
@@ -29,13 +58,13 @@ class Layout2D:
         self.original_roe_corner = original_roe_corner
 
         if isinstance(parallel_overscan, tuple):
-            parallel_overscan = reg.Region2D(region=parallel_overscan)
+            parallel_overscan = Region2D(region=parallel_overscan)
 
         if isinstance(serial_prescan, tuple):
-            serial_prescan = reg.Region2D(region=serial_prescan)
+            serial_prescan = Region2D(region=serial_prescan)
 
         if isinstance(serial_overscan, tuple):
-            serial_overscan = reg.Region2D(region=serial_overscan)
+            serial_overscan = Region2D(region=serial_overscan)
 
         self.parallel_overscan = parallel_overscan
         self.serial_prescan = serial_prescan
@@ -51,13 +80,13 @@ class Layout2D:
         serial_overscan=None,
     ):
 
-        parallel_overscan = layout_util.rotate_region_from_roe_corner(
+        parallel_overscan = layout_util.rotate_region_via_roe_corner_from(
             region=parallel_overscan, shape_native=shape_native, roe_corner=roe_corner
         )
-        serial_prescan = layout_util.rotate_region_from_roe_corner(
+        serial_prescan = layout_util.rotate_region_via_roe_corner_from(
             region=serial_prescan, shape_native=shape_native, roe_corner=roe_corner
         )
-        serial_overscan = layout_util.rotate_region_from_roe_corner(
+        serial_overscan = layout_util.rotate_region_via_roe_corner_from(
             region=serial_overscan, shape_native=shape_native, roe_corner=roe_corner
         )
 
@@ -89,19 +118,19 @@ class Layout2D:
             serial_overscan=serial_overscan,
         )
 
-    def new_rotated_from_roe_corner(self, roe_corner):
+    def new_rotated_from(self, roe_corner):
 
-        parallel_overscan = layout_util.rotate_region_from_roe_corner(
+        parallel_overscan = layout_util.rotate_region_via_roe_corner_from(
             region=self.parallel_overscan,
             shape_native=self.shape_2d,
             roe_corner=roe_corner,
         )
-        serial_prescan = layout_util.rotate_region_from_roe_corner(
+        serial_prescan = layout_util.rotate_region_via_roe_corner_from(
             region=self.serial_prescan,
             shape_native=self.shape_2d,
             roe_corner=roe_corner,
         )
-        serial_overscan = layout_util.rotate_region_from_roe_corner(
+        serial_overscan = layout_util.rotate_region_via_roe_corner_from(
             region=self.serial_overscan,
             shape_native=self.shape_2d,
             roe_corner=roe_corner,
@@ -116,7 +145,7 @@ class Layout2D:
         )
 
     def original_orientation_from(self, array):
-        return layout_util.rotate_array_from_roe_corner(
+        return layout_util.rotate_array_via_roe_corner_from(
             array=array, roe_corner=self.original_roe_corner
         )
 
@@ -168,7 +197,7 @@ class Layout2D:
                <---------S----------
         """
 
-        return array_2d.Array2D.manual(
+        return Array2D.manual(
             array=array.native[self.parallel_overscan.slice],
             header=array.header,
             pixel_scales=array.pixel_scales,
@@ -222,7 +251,7 @@ class Layout2D:
                <---------S----------
         """
 
-        return array_2d.Array2D.manual(
+        return Array2D.manual(
             array=array.native[self.serial_overscan.slice],
             header=array.header,
             pixel_scales=array.pixel_scales,
