@@ -1,9 +1,8 @@
 import numpy as np
+from typing import Tuple
 
 from autoarray import exc
 
-from typing import Tuple
-
 
 class Region1D:
     def __init__(self, region: Tuple[int, int]):
@@ -71,9 +70,15 @@ class Region1D:
 
     def front_edge_region_from(self, pixels):
 
-        x_coord = self.x0
-        x_min = x_coord + pixels[0]
-        x_max = x_coord + pixels[1]
+        x_min = self.x0 + pixels[0]
+        x_max = self.x0 + pixels[1]
+
+        return Region1D((x_min, x_max))
+
+    def trails_region_from(self, pixels):
+
+        x_min = self.x1 + pixels[0]
+        x_max = self.x1 + pixels[1]
 
         return Region1D((x_min, x_max))
 
@@ -86,7 +91,7 @@ class Region2D:
 
         Parameters
         -----------
-        region : (int,)
+        region : Tuple[int]
             The coordinates on the image of the region (y0, y1, x0, y1).
         """
 
