@@ -1,19 +1,19 @@
 import numpy as np
 from skimage.transform import rescale
-from typing import Tuple
+from typing import Tuple, Union
 import warnings
 
-from autoarray import decorator_util
 from autoarray import exc
+from autoarray import numba_util
 from autoarray.structures.grids.two_d import grid_2d_util
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_centres_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
-    centre: (float, float),
-) -> (float, float):
+    pixel_scales: Union[float, Tuple[float, float]],
+    centre: Tuple[float, float],
+) -> Tuple[float, float]:
     """
     Returns the (y,x) scaled central coordinates of a mask from its shape, pixel-scales and centre.
 
@@ -21,9 +21,9 @@ def mask_2d_centres_from(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the 2D array the scaled centre is computed for.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D array.
     centre : (float, flloat)
         The (y,x) centre of the 2D mask.
@@ -35,7 +35,7 @@ def mask_2d_centres_from(
 
     Examples
     --------
-    centres_scaled = centres_from_shape_pixel_scales_and_centre(shape=(5,5), pixel_scales=(0.5, 0.5), centre=(0.0, 0.0))
+    centres_scaled = centres_from(shape=(5,5), pixel_scales=(0.5, 0.5), centre=(0.0, 0.0))
     """
     y_centre_scaled = (float(shape_native[0] - 1) / 2) - (centre[0] / pixel_scales[0])
     x_centre_scaled = (float(shape_native[1] - 1) / 2) + (centre[1] / pixel_scales[1])
@@ -43,14 +43,14 @@ def mask_2d_centres_from(
     return (y_centre_scaled, x_centre_scaled)
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def total_pixels_2d_from(mask_2d: np.ndarray) -> int:
     """
     Returns the total number of unmasked pixels in a mask.
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked and included when counting pixels.
 
     Returns
@@ -65,7 +65,7 @@ def total_pixels_2d_from(mask_2d: np.ndarray) -> int:
                  [False, False, False]
                  [True, False, True]])
 
-    total_regular_pixels = total_regular_pixels_from_mask(mask=mask)
+    total_regular_pixels = total_regular_pixels_from(mask=mask)
     """
 
     total_regular_pixels = 0
@@ -78,16 +78,16 @@ def total_pixels_2d_from(mask_2d: np.ndarray) -> int:
     return total_regular_pixels
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def total_sub_pixels_2d_from(mask_2d: np.ndarray, sub_size: int) -> int:
     """
     Returns the total number of sub-pixels in unmasked pixels in a mask.
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked and included when counting sub pixels.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
 
     Returns
@@ -102,12 +102,12 @@ def total_sub_pixels_2d_from(mask_2d: np.ndarray, sub_size: int) -> int:
                      [False, False, False]
                      [True, False, True]])
 
-    total_sub_pixels = total_sub_pixels_from_mask(mask=mask, sub_size=2)
+    total_sub_pixels = total_sub_pixels_from(mask=mask, sub_size=2)
     """
     return total_pixels_2d_from(mask_2d) * sub_size ** 2
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def total_sparse_pixels_2d_from(
     mask_2d: np.ndarray, unmasked_sparse_grid_pixel_centres: np.ndarray
 ) -> int:
@@ -117,9 +117,9 @@ def total_sparse_pixels_2d_from(
 
     Parameters
     -----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask within which pixelization pixels must be inside
-    unmasked_sparse_grid_pixel_centres : np.ndarray
+    unmasked_sparse_grid_pixel_centres
         The centres of the unmasked pixelization grid pixels.
     """
 
@@ -138,10 +138,10 @@ def total_sparse_pixels_2d_from(
     return total_sparse_pixels
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_circular_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     radius: float,
     centre: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
@@ -152,11 +152,11 @@ def mask_2d_circular_from(
 
     Parameters
     ----------
-    shape_native: (int, int)
+    shape_native: Tuple[int, int]
         The (y,x) shape of the mask in units of pixels.
     pixel_scales: float
         The scaled units to pixel units conversion factor of each pixel.
-    radius : float
+    radius
         The radius (in scaled units) of the circle within which pixels unmasked.
     centre
             The centre of the circle used to mask pixels.
@@ -168,7 +168,7 @@ def mask_2d_circular_from(
 
     Examples
     --------
-    mask = mask_circular_from_shape_pixel_scale_and_radius(
+    mask = mask_circular_from(
         shape=(10, 10), pixel_scales=0.1, radius=0.5, centre=(0.0, 0.0))
     """
 
@@ -192,10 +192,10 @@ def mask_2d_circular_from(
     return mask_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_circular_annular_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     inner_radius: float,
     outer_radius: float,
     centre: Tuple[float, float] = (0.0, 0.0),
@@ -207,13 +207,13 @@ def mask_2d_circular_annular_from(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the mask in units of pixels.
-    pixel_scales : (float, float)
+    pixel_scales
         The scaled units to pixel units conversion factor of each pixel.
-    inner_radius : float
+    inner_radius
         The radius (in scaled units) of the inner circle outside of which pixels are unmasked.
-    outer_radius : float
+    outer_radius
         The radius (in scaled units) of the outer circle within which pixels are unmasked.
     centre
             The centre of the annulus used to mask pixels.
@@ -225,7 +225,7 @@ def mask_2d_circular_annular_from(
 
     Examples
     --------
-    mask = mask_annnular_from_shape_pixel_scale_and_radius(
+    mask = mask_annnular_from(
         shape=(10, 10), pixel_scales=0.1, inner_radius=0.5, outer_radius=1.5, centre=(0.0, 0.0))
     """
 
@@ -249,10 +249,10 @@ def mask_2d_circular_annular_from(
     return mask_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_circular_anti_annular_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     inner_radius: float,
     outer_radius: float,
     outer_radius_2_scaled: float,
@@ -266,15 +266,15 @@ def mask_2d_circular_anti_annular_from(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the mask in units of pixels.
-    pixel_scales : (float, float)
+    pixel_scales
         The scaled units to pixel units conversion factor of each pixel.
-    inner_radius : float
+    inner_radius
         The inner radius in scaled units of the annulus within which pixels are `False` and unmasked.
-    outer_radius : float
+    outer_radius
         The first outer radius in scaled units of the annulus within which pixels are `True` and masked.
-    outer_radius_2 : float
+    outer_radius_2
         The second outer radius in scaled units of the annulus within which pixels are `False` and unmasked and
         outside of which all entries are `True` and masked.
     centre
@@ -287,7 +287,7 @@ def mask_2d_circular_anti_annular_from(
 
     Examples
     --------
-    mask = mask_annnular_from_shape_pixel_scale_and_radius(
+    mask = mask_annnular_from(
         shape=(10, 10), pixel_scales=0.1, inner_radius=0.5, outer_radius=1.5, centre=(0.0, 0.0))
 
     """
@@ -330,7 +330,7 @@ def mask_2d_via_pixel_coordinates_from(
         The (y,x) shape of the mask in units of pixels.
     pixel_coordinates : [[int, int]]
         The input lists of 2D pixel coordinates where `False` entries are created.
-    buffer : int
+    buffer
         All input ``pixel_coordinates`` are buffed with `False` entries in all 8 neighboring directions by this
         amount.
     """
@@ -347,7 +347,7 @@ def mask_2d_via_pixel_coordinates_from(
         return buffed_mask_2d_from(mask_2d=mask_2d, buffer=buffer)
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def elliptical_radius_from(
     y_scaled: float, x_scaled: float, angle: float, axis_ratio: float
 ) -> float:
@@ -360,9 +360,9 @@ def elliptical_radius_from(
 
     Parameters
     ----------
-    y_scaled : float
+    y_scaled
         The scaled y coordinate in Cartesian coordinates which is converted to elliptical coordinates.
-    x_scaled : float
+    x_scaled
         The scaled x coordinate in Cartesian coordinates which is converted to elliptical coordinates.
     angle
             The rotation angle in degrees counter-clockwise from the positive x-axis
@@ -386,10 +386,10 @@ def elliptical_radius_from(
     )
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_elliptical_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     major_axis_radius: float,
     axis_ratio: float,
     angle: float,
@@ -403,11 +403,11 @@ def mask_2d_elliptical_from(
 
     Parameters
     ----------
-    shape_native: (int, int)
+    shape_native: Tuple[int, int]
         The (y,x) shape of the mask in units of pixels.
-    pixel_scales : (float, float)
+    pixel_scales
         The scaled units to pixel units conversion factor of each pixel.
-    major_axis_radius : float
+    major_axis_radius
         The major-axis (in scaled units) of the ellipse within which pixels are unmasked.
     axis_ratio
             The axis-ratio of the ellipse within which pixels are unmasked.
@@ -424,7 +424,7 @@ def mask_2d_elliptical_from(
 
     Examples
     --------
-    mask = mask_elliptical_from_shape_pixel_scale_and_radius(
+    mask = mask_elliptical_from(
         shape=(10, 10), pixel_scales=0.1, major_axis_radius=0.5, elliptical_comps=(0.333333, 0.0), centre=(0.0, 0.0))
     """
 
@@ -450,10 +450,10 @@ def mask_2d_elliptical_from(
     return mask_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_elliptical_annular_from(
     shape_native: Tuple[int, int],
-    pixel_scales: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     inner_major_axis_radius: float,
     inner_axis_ratio: float,
     inner_phi: float,
@@ -470,22 +470,22 @@ def mask_2d_elliptical_annular_from(
 
     Parameters
     ----------
-    shape_native: (int, int)
+    shape_native: Tuple[int, int]
         The (y,x) shape of the mask in units of pixels.
-    pixel_scales : (float, float)
+    pixel_scales
         The scaled units to pixel units conversion factor of each pixel.
-    inner_major_axis_radius : float
+    inner_major_axis_radius
         The major-axis (in scaled units) of the inner ellipse within which pixels are masked.
     inner_axis_ratio
             The axis-ratio of the inner ellipse within which pixels are masked.
-    inner_phi : float
+    inner_phi
         The rotation angle of the inner ellipse within which pixels are masked, (counter-clockwise from the
         positive x-axis).
-    outer_major_axis_radius : float
+    outer_major_axis_radius
         The major-axis (in scaled units) of the outer ellipse within which pixels are unmasked.
     outer_axis_ratio
             The axis-ratio of the outer ellipse within which pixels are unmasked.
-    outer_phi : float
+    outer_phi
         The rotation angle of the outer ellipse within which pixels are unmasked, (counter-clockwise from the
         positive x-axis).
     centre
@@ -498,7 +498,7 @@ def mask_2d_elliptical_annular_from(
 
     Examples
     --------
-    mask = mask_elliptical_annuli_from_shape_pixel_scale_and_radius(
+    mask = mask_elliptical_annuli_from(
         shape=(10, 10), pixel_scales=0.1,
          inner_major_axis_radius=0.5, inner_axis_ratio=0.5, inner_phi=45.0,
          outer_major_axis_radius=1.5, outer_axis_ratio=0.8, outer_phi=90.0,
@@ -534,7 +534,7 @@ def mask_2d_elliptical_annular_from(
     return mask_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def blurring_mask_2d_from(
     mask_2d: np.ndarray, kernel_shape_native: Tuple[int, int]
 ) -> np.ndarray:
@@ -549,9 +549,9 @@ def blurring_mask_2d_from(
 
     Parameters
     -----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked.
-    kernel_shape_native : (int, int)
+    kernel_shape_native
         The 2D shape of the PSF which is used to compute the blurring mask.
 
     Returns
@@ -566,7 +566,7 @@ def blurring_mask_2d_from(
                      [True, False, True]
                      [True, True, True]])
 
-    blurring_mask = blurring_mask_from_mask_and_psf_shape(mask=mask)
+    blurring_mask = blurring_mask_from(mask=mask)
 
     """
 
@@ -598,7 +598,7 @@ def blurring_mask_2d_from(
     return blurring_mask_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_via_shape_native_and_native_for_slim(
     shape_native: Tuple[int, int], native_for_slim: np.ndarray
 ) -> np.ndarray:
@@ -616,9 +616,9 @@ def mask_2d_via_shape_native_and_native_for_slim(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The shape of the 2D array which the pixels are defined on.
-    native_for_slim : np.ndarray
+    native_for_slim
         An array describing the native 2D array index that every slimmed array index maps too.
 
     Returns
@@ -630,7 +630,7 @@ def mask_2d_via_shape_native_and_native_for_slim(
     --------
     native_for_slim = np.array([[0,1], [1,0], [1,1], [1,2], [2,1]])
 
-    mask = mask_from_shape_and_native_for_slim(shape=(3,3), native_for_slim=native_for_slim)
+    mask = mask_from(shape=(3,3), native_for_slim=native_for_slim)
     """
 
     mask = np.ones(shape_native)
@@ -641,7 +641,7 @@ def mask_2d_via_shape_native_and_native_for_slim(
     return mask
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def check_if_edge_pixel(mask_2d: np.ndarray, y: int, x: int) -> bool:
     """
     Checks if an input [y,x] pixel on the input `mask` is an edge-pixel.
@@ -651,11 +651,11 @@ def check_if_edge_pixel(mask_2d: np.ndarray, y: int, x: int) -> bool:
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the input pixel is checked if it is an edge pixel.
-    y : int
+    y
         The y pixel coordinate on the mask that is checked for if it is an edge pixel.
-    x : int
+    x
         The x pixel coordinate on the mask that is checked for if it is an edge pixel.
 
     Returns
@@ -679,7 +679,7 @@ def check_if_edge_pixel(mask_2d: np.ndarray, y: int, x: int) -> bool:
         return False
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def total_edge_pixels_from(mask_2d: np.ndarray) -> int:
     """
     Returns the total number of edge-pixels in a mask.
@@ -689,7 +689,7 @@ def total_edge_pixels_from(mask_2d: np.ndarray) -> int:
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the total number of edge pixels is computed.
 
     Returns
@@ -709,7 +709,7 @@ def total_edge_pixels_from(mask_2d: np.ndarray) -> int:
     return edge_pixel_total
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def edge_1d_indexes_from(mask_2d: np.ndarray) -> np.ndarray:
     """
     Returns a 1D array listing all edge pixel indexes in the mask.
@@ -719,7 +719,7 @@ def edge_1d_indexes_from(mask_2d: np.ndarray) -> np.ndarray:
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the 1D edge pixel indexes are computed.
 
     Returns
@@ -755,7 +755,7 @@ def edge_1d_indexes_from(mask_2d: np.ndarray) -> np.ndarray:
     return edge_pixels
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def check_if_border_pixel(
     mask_2d: np.ndarray, edge_pixel_slim: int, native_to_slim: np.ndarray
 ) -> bool:
@@ -773,12 +773,12 @@ def check_if_border_pixel(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the input pixel is checked if it is a border pixel.
-    edge_pixel_slim : int
+    edge_pixel_slim
         The edge pixel index in 1D that is checked if it is a border pixel (this 1D index is mapped to 2d via the
         array `sub_native_index_for_sub_slim_index_2d`).
-    native_to_slim : np.ndarray
+    native_to_slim
         An array describing the native 2D array index that every slimmed array index maps too.
 
     Returns
@@ -802,7 +802,7 @@ def check_if_border_pixel(
         return False
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def total_border_pixels_from(mask_2d, edge_pixels, native_to_slim):
     """
     Returns the total number of border-pixels in a mask.
@@ -818,12 +818,12 @@ def total_border_pixels_from(mask_2d, edge_pixels, native_to_slim):
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the total number of border pixels is computed.
-    edge_pixel_1d : int
+    edge_pixel_1d
         The edge pixel index in 1D that is checked if it is a border pixel (this 1D index is mapped to 2d via the
         array `sub_native_index_for_sub_slim_index_2d`).
-    native_to_slim : np.ndarray
+    native_to_slim
         An array describing the 2D array index that every 1D array index maps too.
 
     Returns
@@ -842,7 +842,7 @@ def total_border_pixels_from(mask_2d, edge_pixels, native_to_slim):
     return border_pixel_total
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def border_slim_indexes_from(mask_2d: np.ndarray) -> np.ndarray:
     """
     Returns a slim array of shape [total_unmasked_border_pixels] listing all borders pixel indexes in the mask.
@@ -858,7 +858,7 @@ def border_slim_indexes_from(mask_2d: np.ndarray) -> np.ndarray:
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the slimmed border pixel indexes are calculated.
 
     Returns
@@ -917,9 +917,9 @@ def sub_border_pixel_slim_indexes_from(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask for which the 1D border pixel indexes are calculated.
-    sub_size : int
+    sub_size
         The size of the sub-grid in each mask pixel.
 
     Returns
@@ -957,7 +957,7 @@ def sub_border_pixel_slim_indexes_from(
     return sub_border_pixels
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def buffed_mask_2d_from(mask_2d: np.ndarray, buffer: int = 1) -> np.ndarray:
     """
     Returns a buffed mask from an input mask, where the buffed mask is the input mask but all `False` entries in the
@@ -965,9 +965,9 @@ def buffed_mask_2d_from(mask_2d: np.ndarray, buffer: int = 1) -> np.ndarray:
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask whose `False` entries are buffed.
-    buffer : int
+    buffer
         The number of pixels around each `False` entry that pixel are buffed in all 8 directions.
 
     Returns
@@ -1008,9 +1008,9 @@ def rescaled_mask_2d_from(mask_2d: np.ndarray, rescale_factor: float) -> np.ndar
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask that is increased or decreased in size via rescaling.
-    rescale_factor : float
+    rescale_factor
         The factor by which the mask is increased in size or decreased in size.
 
     Returns
@@ -1036,7 +1036,7 @@ def rescaled_mask_2d_from(mask_2d: np.ndarray, rescale_factor: float) -> np.ndar
     return np.isclose(rescaled_mask_2d, 1)
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def slim_index_for_sub_slim_index_via_mask_2d_from(
     mask_2d: np.ndarray, sub_size: int
 ) -> np.ndarray:
@@ -1052,9 +1052,9 @@ def slim_index_for_sub_slim_index_via_mask_2d_from(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask whose indexes are mapped.
-    sub_size : int
+    sub_size
         The sub-size of the grid on the mask, so that the sub-mask indexes can be computed correctly.
 
     Returns
@@ -1102,9 +1102,9 @@ def sub_slim_indexes_for_slim_index_via_mask_2d_from(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         The mask whose indexes are mapped.
-    sub_size : int
+    sub_size
         The sub-size of the grid on the mask, so that the sub-mask indexes can be computed correctly.
 
     Returns
@@ -1134,7 +1134,7 @@ def sub_slim_indexes_for_slim_index_via_mask_2d_from(
     return sub_slim_indexes_for_slim_index
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def sub_slim_index_for_sub_native_index_from(sub_mask_2d: np.ndarray):
     """
     Returns a 2D array which maps every `False` entry of a 2D mask to its sub slim mask array. Every
@@ -1156,7 +1156,7 @@ def sub_slim_index_for_sub_native_index_from(sub_mask_2d: np.ndarray):
 
     Parameters
     ----------
-    sub_mask_2d : np.ndarray
+    sub_mask_2d
         The 2D mask that the util array is created for.
 
     Returns
@@ -1167,18 +1167,16 @@ def sub_slim_index_for_sub_native_index_from(sub_mask_2d: np.ndarray):
     Examples
     --------
     mask = np.full(fill_value=False, shape=(9,9))
-    sub_two_to_one = mask_to_mask_1d_index_from_mask(mask=mask)
+    sub_two_to_one = mask_to_mask_1d_index_from(mask=mask)
     """
 
-    sub_slim_index_for_sub_native_index = np.full(
-        fill_value=-1, shape=sub_mask_2d.shape
-    )
+    sub_slim_index_for_sub_native_index = -1 * np.ones(shape=sub_mask_2d.shape)
 
     sub_mask_1d_index = 0
 
     for sub_mask_y in range(sub_mask_2d.shape[0]):
         for sub_mask_x in range(sub_mask_2d.shape[1]):
-            if sub_mask_2d[sub_mask_y, sub_mask_x] is False:
+            if sub_mask_2d[sub_mask_y, sub_mask_x] == False:
                 sub_slim_index_for_sub_native_index[
                     sub_mask_y, sub_mask_x
                 ] = sub_mask_1d_index
@@ -1187,7 +1185,7 @@ def sub_slim_index_for_sub_native_index_from(sub_mask_2d: np.ndarray):
     return sub_slim_index_for_sub_native_index
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def native_index_for_slim_index_2d_from(
     mask_2d: np.ndarray, sub_size: int
 ) -> np.ndarray:
@@ -1203,9 +1201,9 @@ def native_index_for_slim_index_2d_from(
 
     Parameters
     -----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked.
-    sub_size : int
+    sub_size
         The size of the sub-grid in each mask pixel.
 
     Returns
@@ -1241,7 +1239,7 @@ def native_index_for_slim_index_2d_from(
     return sub_native_index_for_sub_slim_index_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def mask_2d_neighbors_from(mask_2d: np.ndarray) -> np.ndarray:
     """
     Returns an array of shape [total_unmasked_pixels] that maps every unmasked pixel to the slim index of a
@@ -1252,7 +1250,7 @@ def mask_2d_neighbors_from(mask_2d: np.ndarray) -> np.ndarray:
 
     Parameters
     -----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked.
 
     Returns
