@@ -1,7 +1,9 @@
-from autoarray import decorator_util
+from autoarray import numba_util
 import numpy as np
+
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d
 from autoarray.mask import mask_2d_util
 
 
@@ -266,17 +268,17 @@ class Convolver:
                     mask_1d_index += 1
 
     @staticmethod
-    @decorator_util.jit()
+    @numba_util.jit()
     def frame_at_coordinates_jit(coordinates, mask, mask_index_array, kernel_2d):
         """
-    Returns the frame (indexes of pixels light is blurred into) and kernel_frame (kernel kernel values of those \
+        Returns the frame (indexes of pixels light is blurred into) and kernel_frame (kernel kernel values of those \
         pixels) for a given coordinate in a masks and its PSF.
 
         Parameters
         ----------
-        coordinates: (int, int)
+        coordinates: Tuple[int, int]
             The coordinates of mask_index_array on which the frame should be centred
-        kernel_shape_native: (int, int)
+        kernel_shape_native: Tuple[int, int]
             The shape of the kernel for which this frame will be used
         """
 
@@ -307,13 +309,14 @@ class Convolver:
         return frame, kernel_frame
 
     def convolve_image(self, image, blurring_image):
-        """For a given 1D array and blurring array, convolve the two using this convolver.
+        """
+        For a given 1D array and blurring array, convolve the two using this convolver.
 
         Parameters
         -----------
-        image : np.ndarray
+        image
             1D array of the values which are to be blurred with the convolver's PSF.
-        blurring_image : np.ndarray
+        blurring_image
             1D array of the blurring values which blur into the array after PSF convolution.
         """
 
@@ -334,10 +337,10 @@ class Convolver:
             blurring_frame_1d_lengths=self.blurring_frame_1d_lengths,
         )
 
-        return array_2d.Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
 
     @staticmethod
-    @decorator_util.jit()
+    @numba_util.jit()
     def convolve_jit(
         image_1d_array,
         image_frame_1d_indexes,
@@ -378,6 +381,52 @@ class Convolver:
 
         return blurred_image_1d
 
+    def convolve_image_no_blurring(self, image):
+        """For a given 1D array and blurring array, convolve the two using this convolver.
+
+        Parameters
+        -----------
+        image
+            1D array of the values which are to be blurred with the convolver's PSF.
+        blurring_image
+            1D array of the blurring values which blur into the array after PSF convolution.
+        """
+
+        convolved_image = self.convolve_no_blurring_jit(
+            image_1d_array=image.binned.slim,
+            image_frame_1d_indexes=self.image_frame_1d_indexes,
+            image_frame_1d_kernels=self.image_frame_1d_kernels,
+            image_frame_1d_lengths=self.image_frame_1d_lengths,
+        )
+
+        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+
+    @staticmethod
+    @numba_util.jit()
+    def convolve_no_blurring_jit(
+        image_1d_array,
+        image_frame_1d_indexes,
+        image_frame_1d_kernels,
+        image_frame_1d_lengths,
+    ):
+
+        blurred_image_1d = np.zeros(image_1d_array.shape)
+
+        for image_1d_index in range(len(image_1d_array)):
+
+            frame_1d_indexes = image_frame_1d_indexes[image_1d_index]
+            frame_1d_kernel = image_frame_1d_kernels[image_1d_index]
+            frame_1d_length = image_frame_1d_lengths[image_1d_index]
+            image_value = image_1d_array[image_1d_index]
+
+            for kernel_1d_index in range(frame_1d_length):
+
+                vector_index = frame_1d_indexes[kernel_1d_index]
+                kernel_value = frame_1d_kernel[kernel_1d_index]
+                blurred_image_1d[vector_index] += image_value * kernel_value
+
+        return blurred_image_1d
+
     def convolve_mapping_matrix(self, mapping_matrix):
         """For a given inversion mapping matrix, convolve every pixel's mapped with the PSF kernel.
 
@@ -446,7 +495,7 @@ class Convolver:
 
         Parameters
         -----------
-        mapping_matrix : np.ndarray
+        mapping_matrix
             The 2D mapping matrix describing how every inversion pixel maps to a pixel on the data pixel.
         """
         return self.convolve_matrix_jit(
@@ -457,7 +506,7 @@ class Convolver:
         )
 
     @staticmethod
-    @decorator_util.jit()
+    @numba_util.jit()
     def convolve_matrix_jit(
         mapping_matrix,
         image_frame_1d_indexes,
