@@ -1,15 +1,16 @@
-from autoarray.operators import transformer_util
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures import visibilities as vis
-from autoarray.structures.arrays.two_d import array_2d_util
 from astropy import units
-from pynufft.linalg.nufft_cpu import NUFFT_cpu
-import pylops
-import warnings
-
 import copy
 import numpy as np
+import pylops
+from pynufft.linalg.nufft_cpu import NUFFT_cpu
+import warnings
+
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.structures.visibilities import Visibilities
+
+from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.operators import transformer_util
 
 
 class TransformerDFT(pylops.LinearOperator):
@@ -45,7 +46,7 @@ class TransformerDFT(pylops.LinearOperator):
         self.dtype = "complex128"
         self.explicit = False
 
-    def visibilities_from_image(self, image):
+    def visibilities_from(self, image):
 
         if self.preload_transform:
 
@@ -63,11 +64,11 @@ class TransformerDFT(pylops.LinearOperator):
                 uv_wavelengths=self.uv_wavelengths,
             )
 
-        return vis.Visibilities(visibilities=visibilities)
+        return Visibilities(visibilities=visibilities)
 
-    def image_from_visibilities(self, visibilities):
+    def image_from(self, visibilities):
 
-        image_slim = transformer_util.image_from_visibilities_jit(
+        image_slim = transformer_util.image_via_jit_from(
             n_pixels=self.grid.shape[0],
             grid_radians=self.grid,
             uv_wavelengths=self.uv_wavelengths,
@@ -80,11 +81,11 @@ class TransformerDFT(pylops.LinearOperator):
             sub_size=self.real_space_mask.sub_size,
         )
 
-        return array_2d.Array2D.manual_native(
+        return Array2D.manual_native(
             array=image_native, pixel_scales=self.real_space_mask.pixel_scales
         )
 
-    def transformed_mapping_matrix_from_mapping_matrix(self, mapping_matrix):
+    def transform_mapping_matrix(self, mapping_matrix):
 
         if self.preload_transform:
 
@@ -111,9 +112,9 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         self.uv_wavelengths = uv_wavelengths
         self.real_space_mask = real_space_mask.mask_sub_1
         #        self.grid = self.real_space_mask.unmasked_grid.in_radians
-        self.grid = grid_2d.Grid2D.from_mask(mask=self.real_space_mask).in_radians
-        self._sub_native_index_for_sub_slim_index = copy.copy(
-            real_space_mask._sub_native_index_for_sub_slim_index.astype("int")
+        self.grid = Grid2D.from_mask(mask=self.real_space_mask).in_radians
+        self.native_index_for_slim_index = copy.copy(
+            real_space_mask.native_index_for_slim_index.astype("int")
         )
 
         # NOTE: The plan need only be initialized once
@@ -181,26 +182,26 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
             Jd=interp_kernel,
         )
 
-    def visibilities_from_image(self, image):
+    def visibilities_from(self, image):
         """
         ...
         """
 
         warnings.filterwarnings("ignore")
 
-        return vis.Visibilities(
+        return Visibilities(
             visibilities=self.forward(
                 image.binned.native[::-1, :]
             )  # flip due to PyNUFFT internal flip
         )
 
-    def image_from_visibilities(self, visibilities):
+    def image_from(self, visibilities):
         image = np.real(self.adjoint(visibilities))
-        return array_2d.Array2D.manual_native(
+        return Array2D.manual_native(
             array=image, pixel_scales=self.real_space_mask.pixel_scales
         )
 
-    def transformed_mapping_matrix_from_mapping_matrix(self, mapping_matrix):
+    def transform_mapping_matrix(self, mapping_matrix):
 
         transformed_mapping_matrix = 0 + 0j * np.zeros(
             (self.uv_wavelengths.shape[0], mapping_matrix.shape[1])
@@ -214,9 +215,9 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
                 sub_size=1,
             )
 
-            image = array_2d.Array2D(array=image_2d, mask=self.grid.mask)
+            image = Array2D(array=image_2d, mask=self.grid.mask)
 
-            visibilities = self.visibilities_from_image(image=image)
+            visibilities = self.visibilities_from(image=image)
 
             transformed_mapping_matrix[:, source_pixel_1d_index] = visibilities
 
@@ -236,7 +237,7 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         x2d = array_2d_util.array_2d_native_complex_via_indexes_from(
             array_2d_slim=x,
             sub_shape_native=self.real_space_mask.shape_native,
-            native_index_for_slim_index_2d=self._sub_native_index_for_sub_slim_index,
+            native_index_for_slim_index_2d=self.native_index_for_slim_index,
         )[::-1, :]
 
         y = self.k2y(self.xx2k(self.x2xx(x2d)))
@@ -254,11 +255,11 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
 
         warnings.filterwarnings("ignore")
 
-        def a_complex_from_a_real_and_a_imag(a_real, a_imag):
+        def a_complex_from(a_real, a_imag):
 
             return a_real + 1j * a_imag
 
-        y = a_complex_from_a_real_and_a_imag(
+        y = a_complex_from(
             a_real=y[: int(self.shape[0] / 2.0)], a_imag=y[int(self.shape[0] / 2.0) :]
         )
 
