@@ -1,19 +1,22 @@
-from autoarray.plot.mat_wrap.wrap import wrap_base
-from autoarray.plot.mat_wrap.wrap import wrap_2d
-from autoarray.plot.mat_wrap.wrap import wrap_1d
+from autoarray.plot.wrap.wrap_base import set_backend
 
-wrap_base.set_backend()
+set_backend()
 
 import matplotlib.pyplot as plt
 import numpy as np
+from typing import Optional, List, Union
+
+from autoarray.structures.arrays.one_d.array_1d import Array1D
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.inversion.mappers.rectangular import MapperRectangular
+from autoarray.inversion.mappers.voronoi import MapperVoronoi
+from autoarray.plot.mat_wrap.visuals import Visuals1D
+from autoarray.plot.mat_wrap.visuals import Visuals2D
 
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.plot.mat_wrap import visuals as vis
-from autoarray.inversion import mappers
-
-import typing
-from typing import Optional
+from autoarray.plot.wrap import wrap_base as wb
+from autoarray.plot.wrap import wrap_1d as w1d
+from autoarray.plot.wrap import wrap_2d as w2d
 
 
 class AutoLabels:
@@ -31,20 +34,21 @@ class AutoLabels:
 class AbstractMatPlot:
     def __init__(
         self,
-        units: wrap_base.Units = wrap_base.Units(),
-        figure: wrap_base.Figure = wrap_base.Figure(),
-        axis: wrap_base.Axis = wrap_base.Axis(),
-        cmap: wrap_base.Cmap = wrap_base.Cmap(),
-        colorbar: wrap_base.Colorbar = wrap_base.Colorbar(),
-        colorbar_tickparams: wrap_base.ColorbarTickParams = wrap_base.ColorbarTickParams(),
-        tickparams: wrap_base.TickParams = wrap_base.TickParams(),
-        yticks: wrap_base.YTicks = wrap_base.YTicks(),
-        xticks: wrap_base.XTicks = wrap_base.XTicks(),
-        title: wrap_base.Title = wrap_base.Title(),
-        ylabel: wrap_base.YLabel = wrap_base.YLabel(),
-        xlabel: wrap_base.XLabel = wrap_base.XLabel(),
-        legend: wrap_base.Legend = wrap_base.Legend(),
-        output: wrap_base.Output = wrap_base.Output(),
+        units: wb.Units = wb.Units(),
+        figure: wb.Figure = wb.Figure(),
+        axis: wb.Axis = wb.Axis(),
+        cmap: wb.Cmap = wb.Cmap(),
+        colorbar: wb.Colorbar = wb.Colorbar(),
+        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
+        tickparams: wb.TickParams = wb.TickParams(),
+        yticks: wb.YTicks = wb.YTicks(),
+        xticks: wb.XTicks = wb.XTicks(),
+        title: wb.Title = wb.Title(),
+        ylabel: wb.YLabel = wb.YLabel(),
+        xlabel: wb.XLabel = wb.XLabel(),
+        text: wb.Text = wb.Text(),
+        legend: wb.Legend = wb.Legend(),
+        output: wb.Output = wb.Output(),
     ):
         """
         Visualizes data structures (e.g an `Array2D`, `Grid2D`, `VectorField`, etc.) using Matplotlib.
@@ -64,38 +68,38 @@ class AbstractMatPlot:
         
         Parameters
         ----------
-        units : wrap_base.Units
+        units
             The units of the figure used to plot the data structure which sets the y and x ticks and labels.
-        figure : wrap_base.Figure
+        figure
             Opens the matplotlib figure before plotting via `plt.figure` and closes it once plotting is complete
             via `plt.close`
-        axis : wrap_base.Axis
+        axis
             Sets the extent of the figure axis via `plt.axis` and allows for a manual axis range.
-        cmap : wrap_base.Cmap
+        cmap
             Customizes the colormap of the plot and its normalization via matplotlib `colors` objects such 
             as `colors.Normalize` and `colors.LogNorm`.
-        colorbar : wrap_base.Colorbar
+        colorbar
             Plots the colorbar of the plot via `plt.colorbar` and customizes its tick labels and values using method
             like `cb.set_yticklabels`.
-        colorbar_tickparams : wrap_base.ColorbarTickParams
+        colorbar_tickparams
             Customizes the yticks of the colorbar plotted via `plt.colorbar`.
-        tickparams : wrap_base.TickParams
+        tickparams
             Customizes the appearances of the y and x ticks on the plot (e.g. the fontsize) using `plt.tick_params`.
-        yticks : wrap_base.YTicks
+        yticks
             Sets the yticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.yticks`.
-        xticks : wrap_base.XTicks
+        xticks
             Sets the xticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.xticks`.
-        title : wrap_base.Title
+        title
             Sets the figure title and customizes its appearance using `plt.title`.        
-        ylabel : wrap_base.YLabel
+        ylabel
             Sets the figure ylabel and customizes its appearance using `plt.ylabel`.
-        xlabel : wrap_base.XLabel
+        xlabel
             Sets the figure xlabel and customizes its appearance using `plt.xlabel`.
-        legend : wrap_base.Legend
+        legend
             Sets whether the plot inclues a legend and customizes its appearance and labels using `plt.legend`.
-        output : wrap_base.Output
+        output
             Sets if the figure is displayed on the user's screen or output to `.png` using `plt.show` and `plt.savefig`
         """
 
@@ -111,10 +115,12 @@ class AbstractMatPlot:
         self.xticks = xticks
         self.ylabel = ylabel
         self.xlabel = xlabel
+        self.text = text
         self.legend = legend
         self.output = output
 
         self.number_subplots = None
+        self.subplot_shape = None
         self.subplot_index = None
 
     def set_for_subplot(self, is_for_subplot: bool):
@@ -127,7 +133,7 @@ class AbstractMatPlot:
 
         Parameters
         ----------
-        is_for_subplot : bool
+        is_for_subplot
             The entry the `is_for_subplot` attribute of every `MatWrap` object is set too.
         """
         self.is_for_subplot = is_for_subplot
@@ -144,9 +150,13 @@ class AbstractMatPlot:
 
         Parameters
         -----------
-        number_subplots : int
+        number_subplots
             The number of subplots that are to be plotted in the figure.
         """
+
+        if self.subplot_shape is not None:
+            return self.subplot_shape
+
         if number_subplots <= 2:
             return 1, 2
         elif number_subplots <= 4:
@@ -185,22 +195,25 @@ class AbstractMatPlot:
 class MatPlot1D(AbstractMatPlot):
     def __init__(
         self,
-        units: wrap_base.Units = wrap_base.Units(),
-        figure: wrap_base.Figure = wrap_base.Figure(),
-        axis: wrap_base.Axis = wrap_base.Axis(),
-        cmap: wrap_base.Cmap = wrap_base.Cmap(),
-        colorbar: wrap_base.Colorbar = wrap_base.Colorbar(),
-        colorbar_tickparams: wrap_base.ColorbarTickParams = wrap_base.ColorbarTickParams(),
-        tickparams: wrap_base.TickParams = wrap_base.TickParams(),
-        yticks: wrap_base.YTicks = wrap_base.YTicks(),
-        xticks: wrap_base.XTicks = wrap_base.XTicks(),
-        title: wrap_base.Title = wrap_base.Title(),
-        ylabel: wrap_base.YLabel = wrap_base.YLabel(),
-        xlabel: wrap_base.XLabel = wrap_base.XLabel(),
-        legend: wrap_base.Legend = wrap_base.Legend(),
-        output: wrap_base.Output = wrap_base.Output(),
-        yx_plot: wrap_1d.YXPlot = wrap_1d.YXPlot(),
-        vertical_line_axvline: wrap_1d.AXVLine = wrap_1d.AXVLine(),
+        units: wb.Units = wb.Units(),
+        figure: wb.Figure = wb.Figure(),
+        axis: wb.Axis = wb.Axis(),
+        cmap: wb.Cmap = wb.Cmap(),
+        colorbar: wb.Colorbar = wb.Colorbar(),
+        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
+        tickparams: wb.TickParams = wb.TickParams(),
+        yticks: wb.YTicks = wb.YTicks(),
+        xticks: wb.XTicks = wb.XTicks(),
+        title: wb.Title = wb.Title(),
+        ylabel: wb.YLabel = wb.YLabel(),
+        xlabel: wb.XLabel = wb.XLabel(),
+        text: wb.Text = wb.Text(),
+        legend: wb.Legend = wb.Legend(),
+        output: wb.Output = wb.Output(),
+        yx_plot: w1d.YXPlot = w1d.YXPlot(),
+        vertical_line_axvline: w1d.AXVLine = w1d.AXVLine(),
+        yx_scatter: w1d.YXPlot = w1d.YXScatter(),
+        fill_between: w1d.FillBetween = w1d.FillBetween(),
     ):
         """
         Visualizes 1D data structures (e.g a `Line`, etc.) using Matplotlib.
@@ -215,42 +228,42 @@ class MatPlot1D(AbstractMatPlot):
 
         Parameters
         ----------
-        units : wrap_base.Units
+        units
             The units of the figure used to plot the data structure which sets the y and x ticks and labels.
-        figure : wrap_base.Figure
+        figure
             Opens the matplotlib figure before plotting via `plt.figure` and closes it once plotting is complete
             via `plt.close`.
-        axis : wrap_base.Axis
+        axis
             Sets the extent of the figure axis via `plt.axis` and allows for a manual axis range.
-        cmap : wrap_base.Cmap
+        cmap
             Customizes the colormap of the plot and its normalization via matplotlib `colors` objects such 
             as `colors.Normalize` and `colors.LogNorm`.
-        colorbar : wrap_base.Colorbar
+        colorbar
             Plots the colorbar of the plot via `plt.colorbar` and customizes its tick labels and values using method
             like `cb.set_yticklabels`.
-        colorbar_tickparams : wrap_base.ColorbarTickParams
+        colorbar_tickparams
             Customizes the yticks of the colorbar plotted via `plt.colorbar`.
-        tickparams : wrap_base.TickParams
+        tickparams
             Customizes the appearances of the y and x ticks on the plot, (e.g. the fontsize), using `plt.tick_params`.
-        yticks : wrap_base.YTicks
+        yticks
             Sets the yticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.yticks`.
-        xticks : wrap_base.XTicks
+        xticks
             Sets the xticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.xticks`.
-        title : wrap_base.Title
+        title
             Sets the figure title and customizes its appearance using `plt.title`.        
-        ylabel : wrap_base.YLabel
+        ylabel
             Sets the figure ylabel and customizes its appearance using `plt.ylabel`.
-        xlabel : wrap_base.XLabel
+        xlabel
             Sets the figure xlabel and customizes its appearance using `plt.xlabel`.
-        legend : wrap_base.Legend
+        legend
             Sets whether the plot inclues a legend and customizes its appearance and labels using `plt.legend`.
-        output : wrap_base.Output
+        output
             Sets if the figure is displayed on the user's screen or output to `.png` using `plt.show` and `plt.savefig`
-        yx_plot : wrap_1d.YXPlot
+        yx_plot
             Sets how the y versus x plot appears, for example if it each axis is linear or log, using `plt.plot`.
-        vertical_line_axvline : wrao_1d
+        vertical_line_axvline
             Sets how a vertical line plotted on the figure using the `plt.axvline` method.
         """
 
@@ -267,12 +280,15 @@ class MatPlot1D(AbstractMatPlot):
             title=title,
             ylabel=ylabel,
             xlabel=xlabel,
+            text=text,
             legend=legend,
             output=output,
         )
 
         self.yx_plot = yx_plot
         self.vertical_line_axvline = vertical_line_axvline
+        self.yx_scatter = yx_scatter
+        self.fill_between = fill_between
 
         self.is_for_multi_plot = False
         self.is_for_subplot = False
@@ -300,15 +316,17 @@ class MatPlot1D(AbstractMatPlot):
 
     def plot_yx(
         self,
-        y,
-        x,
-        visuals_1d: vis.Visuals1D,
+        y: Union[np.ndarray, List, Array1D],
+        visuals_1d: Visuals1D,
         auto_labels: AutoLabels,
+        x: Optional[Union[np.ndarray, List, Array1D]] = None,
         plot_axis_type_override: Optional[str] = None,
+        y_errors=None,
+        x_errors=None,
         bypass: bool = False,
     ):
 
-        if y is None:
+        if (y is None) or np.count_nonzero(y) == 0:
             return
 
         if (not self.is_for_subplot) and (not self.is_for_multi_plot):
@@ -320,8 +338,11 @@ class MatPlot1D(AbstractMatPlot):
 
         self.title.set(auto_title=auto_labels.title)
 
+        use_integers = False
+
         if x is None:
             x = np.arange(len(y))
+            use_integers = True
 
         if self.yx_plot.plot_axis_type is None:
             plot_axis_type = "linear"
@@ -332,9 +353,23 @@ class MatPlot1D(AbstractMatPlot):
             plot_axis_type = plot_axis_type_override
 
         self.yx_plot.plot_y_vs_x(
-            y=y, x=x, label=auto_labels.legend, plot_axis_type=plot_axis_type
+            y=y,
+            x=x,
+            label=auto_labels.legend,
+            plot_axis_type=plot_axis_type,
+            y_errors=y_errors,
+            x_errors=x_errors,
         )
 
+        if visuals_1d.shaded_region is not None:
+
+            self.fill_between.fill_between_shaded_regions(
+                x=x, y1=visuals_1d.shaded_region[0], y2=visuals_1d.shaded_region[1]
+            )
+
+        if "extent" in self.axis.config_dict:
+            self.axis.set()
+
         self.ylabel.set(units=self.units, include_brackets=False)
         self.xlabel.set(units=self.units, include_brackets=False)
 
@@ -344,13 +379,19 @@ class MatPlot1D(AbstractMatPlot):
             plt.yscale("symlog")
 
         self.xticks.set(
-            array=None, min_value=np.min(x), max_value=np.max(x), units=self.units
+            array=None,
+            min_value=np.min(x),
+            max_value=np.max(x),
+            units=self.units,
+            use_integers=use_integers,
         )
 
         self.title.set(auto_title=auto_labels.title)
         self.ylabel.set(units=self.units, auto_label=auto_labels.ylabel)
         self.xlabel.set(units=self.units, auto_label=auto_labels.xlabel)
 
+        self.text.set()
+
         visuals_1d.plot_via_plotter(plotter=self)
 
         if auto_labels.legend is not None:  # or vertical_line_labels is not None:
@@ -364,35 +405,37 @@ class MatPlot1D(AbstractMatPlot):
 class MatPlot2D(AbstractMatPlot):
     def __init__(
         self,
-        units: wrap_base.Units = wrap_base.Units(),
-        figure: wrap_base.Figure = wrap_base.Figure(),
-        axis: wrap_base.Axis = wrap_base.Axis(),
-        cmap: wrap_base.Cmap = wrap_base.Cmap(),
-        colorbar: wrap_base.Colorbar = wrap_base.Colorbar(),
-        colorbar_tickparams: wrap_base.ColorbarTickParams = wrap_base.ColorbarTickParams(),
-        tickparams: wrap_base.TickParams = wrap_base.TickParams(),
-        yticks: wrap_base.YTicks = wrap_base.YTicks(),
-        xticks: wrap_base.XTicks = wrap_base.XTicks(),
-        title: wrap_base.Title = wrap_base.Title(),
-        ylabel: wrap_base.YLabel = wrap_base.YLabel(),
-        xlabel: wrap_base.XLabel = wrap_base.XLabel(),
-        legend: wrap_base.Legend = wrap_base.Legend(),
-        output: wrap_base.Output = wrap_base.Output(),
-        array_overlay: wrap_2d.ArrayOverlay = wrap_2d.ArrayOverlay(),
-        grid_scatter: wrap_2d.GridScatter = wrap_2d.GridScatter(),
-        grid_plot: wrap_2d.GridPlot = wrap_2d.GridPlot(),
-        vector_field_quiver: wrap_2d.VectorFieldQuiver = wrap_2d.VectorFieldQuiver(),
-        patch_overlay: wrap_2d.PatchOverlay = wrap_2d.PatchOverlay(),
-        voronoi_drawer: wrap_2d.VoronoiDrawer = wrap_2d.VoronoiDrawer(),
-        origin_scatter: wrap_2d.OriginScatter = wrap_2d.OriginScatter(),
-        mask_scatter: wrap_2d.MaskScatter = wrap_2d.MaskScatter(),
-        border_scatter: wrap_2d.BorderScatter = wrap_2d.BorderScatter(),
-        positions_scatter: wrap_2d.PositionsScatter = wrap_2d.PositionsScatter(),
-        index_scatter: wrap_2d.IndexScatter = wrap_2d.IndexScatter(),
-        pixelization_grid_scatter: wrap_2d.PixelizationGridScatter = wrap_2d.PixelizationGridScatter(),
-        parallel_overscan_plot: wrap_2d.ParallelOverscanPlot = wrap_2d.ParallelOverscanPlot(),
-        serial_prescan_plot: wrap_2d.SerialPrescanPlot = wrap_2d.SerialPrescanPlot(),
-        serial_overscan_plot: wrap_2d.SerialOverscanPlot = wrap_2d.SerialOverscanPlot(),
+        units: wb.Units = wb.Units(),
+        figure: wb.Figure = wb.Figure(),
+        axis: wb.Axis = wb.Axis(),
+        cmap: wb.Cmap = wb.Cmap(),
+        colorbar: wb.Colorbar = wb.Colorbar(),
+        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
+        tickparams: wb.TickParams = wb.TickParams(),
+        yticks: wb.YTicks = wb.YTicks(),
+        xticks: wb.XTicks = wb.XTicks(),
+        title: wb.Title = wb.Title(),
+        ylabel: wb.YLabel = wb.YLabel(),
+        xlabel: wb.XLabel = wb.XLabel(),
+        legend: wb.Legend = wb.Legend(),
+        text: wb.Text = wb.Text(),
+        output: wb.Output = wb.Output(),
+        array_overlay: w2d.ArrayOverlay = w2d.ArrayOverlay(),
+        grid_scatter: w2d.GridScatter = w2d.GridScatter(),
+        grid_plot: w2d.GridPlot = w2d.GridPlot(),
+        grid_errorbar: w2d.GridErrorbar = w2d.GridErrorbar(),
+        vector_field_quiver: w2d.VectorFieldQuiver = w2d.VectorFieldQuiver(),
+        patch_overlay: w2d.PatchOverlay = w2d.PatchOverlay(),
+        voronoi_drawer: w2d.VoronoiDrawer = w2d.VoronoiDrawer(),
+        origin_scatter: w2d.OriginScatter = w2d.OriginScatter(),
+        mask_scatter: w2d.MaskScatter = w2d.MaskScatter(),
+        border_scatter: w2d.BorderScatter = w2d.BorderScatter(),
+        positions_scatter: w2d.PositionsScatter = w2d.PositionsScatter(),
+        index_scatter: w2d.IndexScatter = w2d.IndexScatter(),
+        pixelization_grid_scatter: w2d.PixelizationGridScatter = w2d.PixelizationGridScatter(),
+        parallel_overscan_plot: w2d.ParallelOverscanPlot = w2d.ParallelOverscanPlot(),
+        serial_prescan_plot: w2d.SerialPrescanPlot = w2d.SerialPrescanPlot(),
+        serial_overscan_plot: w2d.SerialOverscanPlot = w2d.SerialOverscanPlot(),
     ):
         """
         Visualizes 2D data structures (e.g an `Array2D`, `Grid2D`, `VectorField`, etc.) using Matplotlib.
@@ -412,68 +455,68 @@ class MatPlot2D(AbstractMatPlot):
 
         Parameters
         ----------
-        units : wrap_base.Units
+        units
             The units of the figure used to plot the data structure which sets the y and x ticks and labels.
-        figure : wrap_base.Figure
+        figure
             Opens the matplotlib figure before plotting via `plt.figure` and closes it once plotting is complete
             via `plt.close`.
-        axis : wrap_base.Axis
+        axis
             Sets the extent of the figure axis via `plt.axis` and allows for a manual axis range.
-        cmap : wrap_base.Cmap
+        cmap
             Customizes the colormap of the plot and its normalization via matplotlib `colors` objects such 
             as `colors.Normalize` and `colors.LogNorm`.
-        colorbar : wrap_base.Colorbar
+        colorbar
             Plots the colorbar of the plot via `plt.colorbar` and customizes its tick labels and values using method
             like `cb.set_yticklabels`.
-        colorbar_tickparams : wrap_base.ColorbarTickParams
+        colorbar_tickparams
             Customizes the yticks of the colorbar plotted via `plt.colorbar`.
-        tickparams : wrap_base.TickParams
+        tickparams
             Customizes the appearances of the y and x ticks on the plot, (e.g. the fontsize), using `plt.tick_params`.
-        yticks : wrap_base.YTicks
+        yticks
             Sets the yticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.yticks`.
-        xticks : wrap_base.XTicks
+        xticks
             Sets the xticks of the plot, including scaling them to new units depending on the `Units` object, via
             `plt.xticks`.
-        title : wrap_base.Title
+        title
             Sets the figure title and customizes its appearance using `plt.title`.        
-        ylabel : wrap_base.YLabel
+        ylabel
             Sets the figure ylabel and customizes its appearance using `plt.ylabel`.
-        xlabel : wrap_base.XLabel
+        xlabel
             Sets the figure xlabel and customizes its appearance using `plt.xlabel`.
-        legend : wrap_base.Legend
+        legend
             Sets whether the plot inclues a legend and customizes its appearance and labels using `plt.legend`.
-        output : wrap_base.Output
+        output
             Sets if the figure is displayed on the user's screen or output to `.png` using `plt.show` and `plt.savefig`
-        array_overlay: wrap_2d.ArrayOverlay
+        array_overlay
             Overlays an input `Array2D` over the figure using `plt.imshow`.
-        grid_scatter : wrap_2d.GridScatter
+        grid_scatter
             Scatters a `Grid2D` of (y,x) coordinates over the figure using `plt.scatter`.
-        grid_plot: wrap_2d.Grid2DPlot
+        grid_plot
             Plots lines of data (e.g. a y versus x plot via `plt.plot`, vertical lines via `plt.avxline`, etc.)
-        vector_field_quiver: wrap_2d.VectorFieldQuiver
+        vector_field_quiver
             Plots a `VectorField` object using the matplotlib function `plt.quiver`.
-        patch_overlay: wrap_2d.PatchOverlay
+        patch_overlay
             Overlays matplotlib `patches.Patch` objects over the figure, such as an `Ellipse`.
-        voronoi_drawer: wrap_2d.VoronoiDrawer
+        voronoi_drawer
             Draws a colored Voronoi mesh of pixels using `plt.fill`.
-        origin_scatter : wrap_2d.OriginScatter
+        origin_scatter
             Scatters the (y,x) origin of the data structure on the figure.
-        mask_scatter : wrap_2d.MaskScatter
+        mask_scatter
             Scatters an input `Mask2d` over the plotted data structure's figure.
-        border_scatter : wrap_2d.BorderScatter
+        border_scatter
             Scatters the border of an input `Mask2d` over the plotted data structure's figure.
-        positions_scatter : wrap_2d.PositionsScatter
+        positions_scatter
             Scatters specific (y,x) coordinates input as a `Grid2DIrregular` object over the figure.
-        index_scatter : wrap_2d.IndexScatter
+        index_scatter
             Scatters specific coordinates of an input `Grid2D` based on input values of the `Grid2D`'s 1D or 2D indexes.
-        pixelization_grid_scatter : wrap_2d.PixelizationGridScatter
+        pixelization_grid_scatter
             Scatters the `PixelizationGrid` of a `Pixelization` object.
-        parallel_overscan_plot : wrap_2d.ParallelOverscanPlot
+        parallel_overscan_plot
             Plots the parallel overscan on an `Array2D` data structure representing a CCD imaging via `plt.plot`.
-        serial_prescan_plot : wrap_2d.SerialPrescanPlot
+        serial_prescan_plot
             Plots the serial prescan on an `Array2D` data structure representing a CCD imaging via `plt.plot`.
-        serial_overscan_plot : wrap_2d.SerialOverscanPlot
+        serial_overscan_plot
             Plots the serial overscan on an `Array2D` data structure representing a CCD imaging via `plt.plot`.
         """
 
@@ -490,6 +533,7 @@ class MatPlot2D(AbstractMatPlot):
             title=title,
             ylabel=ylabel,
             xlabel=xlabel,
+            text=text,
             legend=legend,
             output=output,
         )
@@ -498,10 +542,11 @@ class MatPlot2D(AbstractMatPlot):
         self.mask_scatter = mask_scatter
         self.border_scatter = border_scatter
         self.grid_scatter = grid_scatter
+        self.grid_plot = grid_plot
+        self.grid_errorbar = grid_errorbar
         self.positions_scatter = positions_scatter
         self.index_scatter = index_scatter
         self.pixelization_grid_scatter = pixelization_grid_scatter
-        self.grid_plot = grid_plot
         self.vector_field_quiver = vector_field_quiver
         self.patch_overlay = patch_overlay
         self.array_overlay = array_overlay
@@ -514,8 +559,8 @@ class MatPlot2D(AbstractMatPlot):
 
     def plot_array(
         self,
-        array: array_2d.Array2D,
-        visuals_2d: vis.Visuals2D,
+        array: Array2D,
+        visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
         bypass: bool = False,
     ):
@@ -526,11 +571,11 @@ class MatPlot2D(AbstractMatPlot):
 
         Parameters
         -----------
-        array : array_2d.Array2D
+        array
             The 2D array of data_type which is plotted.
-        visuals_2d : vis.Visuals2D
+        visuals_2d
             Contains all the visuals that are plotted over the `Array2D` (e.g. the origin, mask, grids, etc.).
-        bypass : bool
+        bypass
             If `True`, `plt.close` is omitted and the matplotlib figure remains open. This is used when making subplots.
         """
 
@@ -552,12 +597,12 @@ class MatPlot2D(AbstractMatPlot):
 
         if array.zoom_for_plot:
 
-            extent_imshow = array.extent_of_zoomed_array(buffer=buffer)
+            extent = array.extent_of_zoomed_array(buffer=buffer)
             array = array.zoomed_around_mask(buffer=buffer)
 
         else:
 
-            extent_imshow = array.extent
+            extent = array.extent
 
         if not self.is_for_subplot:
             self.figure.open()
@@ -565,15 +610,15 @@ class MatPlot2D(AbstractMatPlot):
             if not bypass:
                 self.setup_subplot()
 
-        aspect = self.figure.aspect_from_shape_native(shape_native=array.shape_native)
-        norm_scale = self.cmap.norm_from_array(array=array)
+        aspect = self.figure.aspect_from(shape_native=array.shape_native)
+        norm_scale = self.cmap.norm_from(array=array)
 
         plt.imshow(
             X=array.native,
             aspect=aspect,
             cmap=self.cmap.config_dict["cmap"],
             norm=norm_scale,
-            extent=extent_imshow,
+            extent=extent,
         )
 
         if visuals_2d.array_overlay is not None:
@@ -582,7 +627,10 @@ class MatPlot2D(AbstractMatPlot):
             )
 
         extent_axis = self.axis.config_dict.get("extent")
-        extent_axis = extent_axis if extent_axis is not None else extent_imshow
+
+        if extent_axis is None:
+
+            extent_axis = extent
 
         self.axis.set(extent=extent_axis)
 
@@ -605,11 +653,21 @@ class MatPlot2D(AbstractMatPlot):
         self.ylabel.set(units=self.units, include_brackets=True)
         self.xlabel.set(units=self.units, include_brackets=True)
 
+        self.text.set()
+
         if self.colorbar is not None:
             cb = self.colorbar.set()
             self.colorbar_tickparams.set(cb=cb)
 
-        visuals_2d.plot_via_plotter(plotter=self, grid_indexes=array.mask.masked_grid)
+        grid_indexes = None
+
+        if (
+            visuals_2d.indexes is not None
+            or visuals_2d.pixelization_indexes is not None
+        ):
+            grid_indexes = array.mask.masked_grid
+
+        visuals_2d.plot_via_plotter(plotter=self, grid_indexes=grid_indexes)
 
         if not self.is_for_subplot and not bypass:
             self.output.to_figure(structure=array, auto_filename=auto_labels.filename)
@@ -618,18 +676,20 @@ class MatPlot2D(AbstractMatPlot):
     def plot_grid(
         self,
         grid,
-        visuals_2d: vis.Visuals2D,
+        visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
         color_array=None,
-        errors=None,
+        y_errors=None,
+        x_errors=None,
+        buffer=1.0,
     ):
         """Plot a grid of (y,x) Cartesian coordinates as a scatter plotter of points.
 
         Parameters
         -----------
-        grid : Grid2D
+        grid
             The (y,x) coordinates of the grid, in an array of shape (total_coordinates, 2).
-        indexes : []
+        indexes
             A set of points that are plotted in a different colour for emphasis (e.g. to show the mappings between \
             different planes).
         """
@@ -641,41 +701,60 @@ class MatPlot2D(AbstractMatPlot):
 
         if color_array is None:
 
-            self.grid_scatter.scatter_grid(grid=grid)
+            if y_errors is None and x_errors is None:
+                self.grid_scatter.scatter_grid(grid=grid)
+            else:
+                self.grid_errorbar.errorbar_grid(
+                    grid=grid, y_errors=y_errors, x_errors=x_errors
+                )
 
         elif color_array is not None:
 
-            plt.cm.get_cmap(self.cmap.config_dict["cmap"])
-            self.grid_scatter.scatter_grid_colored(
-                grid=grid, color_array=color_array, cmap=self.cmap.config_dict["cmap"]
-            )
+            cmap = plt.get_cmap(self.cmap.config_dict["cmap"])
+
+            if y_errors is None and x_errors is None:
+                self.grid_scatter.scatter_grid_colored(
+                    grid=grid, color_array=color_array, cmap=cmap
+                )
+            else:
+                self.grid_errorbar.errorbar_grid_colored(
+                    grid=grid,
+                    cmap=cmap,
+                    color_array=color_array,
+                    y_errors=y_errors,
+                    x_errors=x_errors,
+                )
+
             if self.colorbar is not None:
-                cb = self.colorbar.set()
-                self.colorbar_tickparams.set(cb=cb)
+
+                colorbar = self.colorbar.set_with_color_values(
+                    cmap=self.cmap.config_dict["cmap"], color_values=color_array
+                )
+                if colorbar is not None and self.colorbar_tickparams is not None:
+                    self.colorbar_tickparams.set(cb=colorbar)
 
         self.title.set(auto_title=auto_labels.title)
         self.ylabel.set(units=self.units, include_brackets=True)
         self.xlabel.set(units=self.units, include_brackets=True)
 
-        extent_axis = self.axis.config_dict.get("extent")
-        extent_axis = extent_axis if extent_axis is not None else grid.extent
+        self.text.set()
 
-        self.axis.set(extent=extent_axis, grid=grid)
+        extent = self.axis.config_dict.get("extent")
+
+        if extent is None:
+
+            extent = grid.extent + (buffer * grid.extent)
+
+        self.axis.set(extent=extent, grid=grid)
 
         self.tickparams.set()
 
         if not self.axis.symmetric_around_centre:
             self.yticks.set(
-                array=None,
-                min_value=extent_axis[2],
-                max_value=extent_axis[3],
-                units=self.units,
+                array=None, min_value=extent[2], max_value=extent[3], units=self.units
             )
             self.xticks.set(
-                array=None,
-                min_value=extent_axis[0],
-                max_value=extent_axis[1],
-                units=self.units,
+                array=None, min_value=extent[0], max_value=extent[1], units=self.units
             )
 
         visuals_2d.plot_via_plotter(plotter=self, grid_indexes=grid)
@@ -686,13 +765,13 @@ class MatPlot2D(AbstractMatPlot):
 
     def plot_mapper(
         self,
-        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
-        visuals_2d: vis.Visuals2D,
+        mapper: Union[MapperRectangular, MapperVoronoi],
+        visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
         source_pixelilzation_values=None,
     ):
 
-        if isinstance(mapper, mappers.MapperRectangular):
+        if isinstance(mapper, MapperRectangular):
 
             self._plot_rectangular_mapper(
                 mapper=mapper,
@@ -712,20 +791,22 @@ class MatPlot2D(AbstractMatPlot):
 
     def _plot_rectangular_mapper(
         self,
-        mapper: mappers.MapperRectangular,
-        visuals_2d: vis.Visuals2D,
+        mapper: MapperRectangular,
+        visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
         source_pixelilzation_values=None,
     ):
 
+        extent = self.axis.config_dict.get("extent")
+        extent = (
+            extent if extent is not None else mapper.source_pixelization_grid.extent
+        )
+
+        aspect_inv = self.figure.aspect_for_subplot_from(extent=extent)
+
         if not self.is_for_subplot:
             self.figure.open()
         else:
-
-            aspect_inv = self.figure.aspect_for_subplot_from_grid(
-                grid=mapper.source_grid_slim
-            )
-
             self.setup_subplot(aspect=aspect_inv)
 
         if source_pixelilzation_values is not None:
@@ -736,28 +817,17 @@ class MatPlot2D(AbstractMatPlot):
                 bypass=True,
             )
 
-        extent_axis = self.axis.config_dict.get("extent")
-        extent_axis = (
-            extent_axis
-            if extent_axis is not None
-            else mapper.source_pixelization_grid.extent
-        )
-
-        self.axis.set(extent=extent_axis, grid=mapper.source_pixelization_grid)
+        self.axis.set(extent=extent, grid=mapper.source_pixelization_grid)
 
         self.yticks.set(
-            array=None,
-            min_value=extent_axis[2],
-            max_value=extent_axis[3],
-            units=self.units,
+            array=None, min_value=extent[2], max_value=extent[3], units=self.units
         )
         self.xticks.set(
-            array=None,
-            min_value=extent_axis[0],
-            max_value=extent_axis[1],
-            units=self.units,
+            array=None, min_value=extent[0], max_value=extent[1], units=self.units
         )
 
+        self.text.set()
+
         self.grid_plot.plot_rectangular_grid_lines(
             extent=mapper.source_pixelization_grid.extent,
             shape_native=mapper.shape_native,
@@ -778,45 +848,38 @@ class MatPlot2D(AbstractMatPlot):
 
     def _plot_voronoi_mapper(
         self,
-        mapper: mappers.MapperVoronoi,
-        visuals_2d: vis.Visuals2D,
+        mapper: MapperVoronoi,
+        visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
         source_pixelilzation_values=None,
     ):
 
+        extent = self.axis.config_dict.get("extent")
+        extent = (
+            extent if extent is not None else mapper.source_pixelization_grid.extent
+        )
+
+        aspect_inv = self.figure.aspect_for_subplot_from(extent=extent)
+
         if not self.is_for_subplot:
             self.figure.open()
         else:
-
-            aspect_inv = self.figure.aspect_for_subplot_from_grid(
-                grid=mapper.source_grid_slim
-            )
-
             self.setup_subplot(aspect=aspect_inv)
 
-        extent_axis = self.axis.config_dict.get("extent")
-        extent_axis = (
-            extent_axis
-            if extent_axis is not None
-            else mapper.source_pixelization_grid.extent
-        )
+        self.axis.set(extent=extent, grid=mapper.source_pixelization_grid)
 
-        self.axis.set(extent=extent_axis, grid=mapper.source_pixelization_grid)
+        plt.gca().set_aspect(aspect_inv)
 
         self.tickparams.set()
         self.yticks.set(
-            array=None,
-            min_value=extent_axis[2],
-            max_value=extent_axis[3],
-            units=self.units,
+            array=None, min_value=extent[2], max_value=extent[3], units=self.units
         )
         self.xticks.set(
-            array=None,
-            min_value=extent_axis[0],
-            max_value=extent_axis[1],
-            units=self.units,
+            array=None, min_value=extent[0], max_value=extent[1], units=self.units
         )
 
+        self.text.set()
+
         self.voronoi_drawer.draw_voronoi_pixels(
             mapper=mapper,
             values=source_pixelilzation_values,
