@@ -1,5 +1,5 @@
-from os import path
 import numpy as np
+from os import path
 import pickle
 
 
@@ -46,7 +46,7 @@ class AbstractStructure(np.ndarray):
         ----------
         data_structure : AbstractStructure
             The structure which is to be turned into a new structure.
-        mask : msk.Mask2D
+        mask :Mask2D
             The mask associated with this structure.
         """
         raise NotImplementedError()
@@ -108,10 +108,10 @@ class AbstractStructure(np.ndarray):
     def trimmed_after_convolution_from(self, kernel_shape):
         raise NotImplementedError
 
-    def structure_2d_from_result(self, result: np.ndarray):
+    def structure_2d_from(self, result: np.ndarray):
         raise NotImplementedError
 
-    def structure_2d_list_from_result_list(self, result_list: list):
+    def structure_2d_list_from(self, result_list: list):
         raise NotImplementedError
 
     @classmethod
