@@ -1,14 +1,16 @@
 import logging
 from astropy import time
 import numpy as np
+from typing import Dict, List, Tuple, Optional, Union
 
 from autoarray.dataset import preprocess
 
+
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
-def convert_array(array):
+def convert_array(array: Union[np.ndarray, List]) -> np.ndarray:
     """
     If the input array input a convert is of type list, convert it to type NumPy array.
 
@@ -27,10 +29,10 @@ def convert_array(array):
 class Header:
     def __init__(
         self,
-        header_sci_obj,
-        header_hdu_obj,
-        original_roe_corner=None,
-        readout_offsets: (int, int) = (0, 0),
+        header_sci_obj: Dict = None,
+        header_hdu_obj: Dict = None,
+        original_roe_corner: Tuple[int, int] = None,
+        readout_offsets: Optional[Tuple] = None,
     ):
 
         self.header_sci_obj = header_sci_obj
@@ -39,19 +41,19 @@ class Header:
         self.readout_offsets = readout_offsets
 
     @property
-    def date_of_observation(self):
+    def date_of_observation(self) -> str:
         return self.header_sci_obj["DATE-OBS"]
 
     @property
-    def time_of_observation(self):
+    def time_of_observation(self) -> str:
         return self.header_sci_obj["TIME-OBS"]
 
     @property
-    def exposure_time(self):
+    def exposure_time(self) -> str:
         return self.header_sci_obj["EXPTIME"]
 
     @property
-    def modified_julian_date(self):
+    def modified_julian_date(self) -> Optional[str]:
         if (
             self.date_of_observation is not None
             and self.time_of_observation is not None
