@@ -1,52 +1,81 @@
 import logging
-from astropy import time
 import numpy as np
+from typing import List, Tuple, Union
+
+from autoconf import conf
+
+from autoarray.structures.abstract_structure import AbstractStructure2D
+
+from autoarray.structures.arrays.one_d.array_1d import Array1D
+from autoarray.mask.mask_2d import Mask2D
 
 from autoarray import exc
-from autoarray.mask import mask_2d as msk
-from autoarray.structures import abstract_structure
 from autoarray.structures.arrays import abstract_array
-from autoarray.structures.arrays.one_d import array_1d
 from autoarray.structures.arrays.two_d import array_2d_util
 from autoarray.layout import layout_util
-from autoarray.dataset import preprocess
+
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
-def check_array_2d(array_2d):
+def check_array_2d(array_2d: np.ndarray):
     if len(array_2d.shape) != 1:
         raise exc.ArrayException(
-            "An array input into the array_2d.Array2D.__new__ method is not of shape 1."
+            "An array input into the Array2D.__new__ method is not of shape 1."
         )
 
 
-def convert_array_2d(array_2d, mask_2d):
+def convert_array_2d(array_2d: Union[np.ndarray, List], mask_2d: Mask2D) -> np.ndarray:
     """
-    Manual array functions take as input a list or ndarray which is to be returned as an Array2D. This function
-    performs the following and checks and conversions on the input:
+    The `manual` classmethods in the `Array2D` object take as input a list or ndarray which is returned as an
+    Array2D.
+
+    This function performs the following and checks and conversions on the input:
 
     1) If the input is a list, convert it to an ndarray.
     2) Check that the number of sub-pixels in the array is identical to that of the mask.
-    3) Map the input ndarray to its `slim` representation.
+    3) Map the input ndarray to its `slim` or `native` representation, depending on the `general.ini` config file
+    entry `store_slim`.
 
     For an Array2D, `slim` refers to a 1D NumPy array of shape [total_values] and `native` a 2D NumPy array of shape
     [total_y_values, total_values].
 
     Parameters
     ----------
-    array_2d : np.ndarray or list
+    array_2d
         The input structure which is converted to an ndarray if it is a list.
-    mask_2d : Mask2D
+    mask_2d
         The mask of the output Array2D.
     """
 
     array_2d = abstract_array.convert_array(array=array_2d)
 
+    if conf.instance["general"]["structures"]["store_slim"]:
+        return convert_array_2d_to_slim(array_2d=array_2d, mask_2d=mask_2d)
+    return convert_array_2d_to_native(array_2d=array_2d, mask_2d=mask_2d)
+
+
+def convert_array_2d_to_slim(array_2d: np.ndarray, mask_2d: Mask2D) -> np.ndarray:
+    """
+    The `manual` classmethods in the `Array2D` object take as input a list or ndarray which is returned as an
+    Array2D.
+
+    This function checks the dimensions of the input `array_2d` and maps it to its `slim` representation.
+
+    For an Array2D, `slim` refers to a 1D NumPy array of shape [total_values].
+
+    Parameters
+    ----------
+    array_2d
+        The input structure which is converted to its slim representation.
+    mask_2d
+        The mask of the output Array2D.
+    """
+
     if len(array_2d.shape) == 1:
 
-        array_2d_slim = abstract_array.convert_array(array=array_2d)
+        array_2d_slim = array_2d
 
         if array_2d_slim.shape[0] != mask_2d.sub_pixels_in_mask:
             raise exc.ArrayException(
@@ -59,31 +88,65 @@ def convert_array_2d(array_2d, mask_2d):
     if array_2d.shape != mask_2d.sub_shape_native:
         raise exc.ArrayException(
             "The input array is 2D but not the same dimensions as the sub-mask "
-            "(e.g. the mask 2D shape multipled by its sub size."
+            "(e.g. the mask 2D shape multipled by its sub size.)"
         )
 
-    sub_array_1d = array_2d_util.array_2d_slim_from(
+    return array_2d_util.array_2d_slim_from(
         array_2d_native=array_2d, mask_2d=mask_2d, sub_size=mask_2d.sub_size
     )
 
-    return sub_array_1d
+
+def convert_array_2d_to_native(array_2d: np.ndarray, mask_2d: Mask2D) -> np.ndarray:
+    """
+    The `manual` classmethods in the `Array2D` object take as input a list or ndarray which is returned as an
+    Array2D.
+
+    This function checks the dimensions of the input `array_2d` and maps it to its `native` representation.
+
+    For an Array2D, `native` a 2D NumPy array of shape [total_y_values, total_values].
+
+    Parameters
+    ----------
+    array_2d
+        The input structure which is converted to an ndarray if it is a list.
+    mask_2d : Mask2D
+        The mask of the output Array2D.
+    """
+
+    if len(array_2d.shape) == 2:
+
+        array_2d_native = array_2d * np.invert(mask_2d)
+
+        if array_2d.shape != mask_2d.sub_shape_native:
+            raise exc.ArrayException(
+                "The input array is 2D but not the same dimensions as the sub-mask "
+                "(e.g. the mask 2D shape multipled by its sub size.)"
+            )
+
+        return array_2d_native
+
+    if array_2d.shape[0] != mask_2d.sub_pixels_in_mask:
+        raise exc.ArrayException(
+            "The input 1D array does not have the same number of entries as sub-pixels in"
+            "the mask."
+        )
+
+    return array_2d_util.array_2d_native_from(
+        array_2d_slim=array_2d, mask_2d=mask_2d, sub_size=mask_2d.sub_size
+    )
 
 
-class AbstractArray2D(abstract_structure.AbstractStructure2D):
+class AbstractArray2D(AbstractStructure2D):
 
     header = None
 
-    def _new_structure(self, array, mask):
+    def _new_structure(
+        self, array: "AbstractArray2D", mask: Mask2D
+    ) -> "AbstractArray2D":
         return self.__class__(array=array, mask=mask, header=self.header)
 
     @property
-    def readout_offsets(self):
-        if self.header is not None:
-            return self.header.readout_offsets
-        return (0, 0)
-
-    @property
-    def slim(self):
+    def slim(self) -> Union["AbstractArray2D", "Array2D"]:
         """
         Return an `Array2D` where the data is stored its `slim` representation, which is an ndarray of shape
         [total_unmasked_pixels * sub_size**2].
@@ -102,7 +165,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
         return self._new_structure(array=sub_array_1d, mask=self.mask)
 
     @property
-    def native(self):
+    def native(self) -> Union["AbstractArray2D", "Array2D"]:
         """
         Return a `Array2D` where the data is stored in its `native` representation, which is an ndarray of shape
         [sub_size*total_y_pixels, sub_size*total_x_pixels].
@@ -120,7 +183,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
         return self._new_structure(array=sub_array_2d, mask=self.mask)
 
     @property
-    def binned(self):
+    def binned(self) -> Union["AbstractArray2D", "Array2D"]:
         """
         Convenience method to access the binned-up array in its 1D representation, which is a Grid2D stored as an
         ndarray of shape [total_unmasked_pixels, 2].
@@ -142,68 +205,51 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
         return self._new_structure(array=binned_array_1d, mask=self.mask.mask_sub_1)
 
     @property
-    def extent(self):
+    def extent(self) -> np.ndarray:
         return self.mask.extent
 
     @property
-    def in_counts(self):
+    def in_counts(self) -> "AbstractArray2D":
         return self.header.array_eps_to_counts(array_eps=self)
 
     @property
-    def in_counts_per_second(self):
+    def in_counts_per_second(self) -> "AbstractArray2D":
         return self.header.array_counts_to_counts_per_second(
             array_counts=self.in_counts
         )
 
     @property
-    def original_orientation(self):
-        return layout_util.rotate_array_from_roe_corner(
+    def original_orientation(self) -> Union[np.ndarray, "AbstractArray2D"]:
+        return layout_util.rotate_array_via_roe_corner_from(
             array=self, roe_corner=self.header.original_roe_corner
         )
 
     @property
-    def binned_across_rows(self):
-        binned_array = np.mean(np.ma.masked_array(self.native, self.mask), axis=0)
-        return array_1d.Array1D.manual_native(
-            array=binned_array, pixel_scales=self.pixel_scale
-        )
+    def readout_offsets(self) -> Tuple[int, int]:
+        if self.header is not None:
+            if self.header.readout_offsets is not None:
+                return self.header.readout_offsets
+        return (0, 0)
 
     @property
-    def binned_across_columns(self):
+    def binned_across_rows(self) -> Array1D:
+        binned_array = np.mean(np.ma.masked_array(self.native, self.mask), axis=0)
+        return Array1D.manual_native(array=binned_array, pixel_scales=self.pixel_scale)
+
+    @property
+    def binned_across_columns(self) -> Array1D:
         binned_array = np.mean(np.ma.masked_array(self.native, self.mask), axis=1)
-        return array_1d.Array1D.manual_native(
-            array=binned_array, pixel_scales=self.pixel_scale
-        )
+        return Array1D.manual_native(array=binned_array, pixel_scales=self.pixel_scale)
 
-    def new_with_array(self, array):
+    def zoomed_around_mask(self, buffer: int = 1) -> "AbstractArray2D":
         """
-        Parameters
-        ----------
-        array: np.ndarray
-            An ndarray
-
-        Returns
-        -------
-        new_array: Array2D
-            A new instance of this class that shares all of this instances attributes with a new ndarray.
-        """
-        arguments = vars(self)
-        arguments.update({"array": array})
-        return self.__class__(**arguments)
-
-    def map(self, func):
-        for y in range(self.shape[0]):
-            for x in range(self.shape[1]):
-                func(y, x)
-
-    def zoomed_around_mask(self, buffer=1):
-        """Extract the 2D region of an array corresponding to the rectangle encompassing all unmasked values.
+        Extract the 2D region of an array corresponding to the rectangle encompassing all unmasked values.
 
         This is used to extract and visualize only the region of an image that is used in an analysis.
 
         Parameters
         ----------
-        buffer : int
+        buffer
             The number pixels around the extracted array used as a buffer.
         """
 
@@ -215,7 +261,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
             x1=self.mask.zoom_region[3] + buffer,
         )
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=extracted_array_2d.shape,
             pixel_scales=self.pixel_scales,
             sub_size=self.sub_size,
@@ -226,8 +272,9 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         return self._new_structure(array=array, mask=mask)
 
-    def extent_of_zoomed_array(self, buffer=1):
-        """For an extracted zoomed array computed from the method *zoomed_around_mask* compute its extent in scaled
+    def extent_of_zoomed_array(self, buffer: int = 1) -> np.ndarray:
+        """
+        For an extracted zoomed array computed from the method *zoomed_around_mask* compute its extent in scaled
         coordinates.
 
         The extent of the grid in scaled units returned as an ndarray of the form [x_min, x_max, y_min, y_max].
@@ -236,7 +283,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         Parameters
         ----------
-        buffer : int
+        buffer
             The number pixels around the extracted array used as a buffer.
         """
         extracted_array_2d = array_2d_util.extracted_array_2d_from(
@@ -247,7 +294,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
             x1=self.mask.zoom_region[3] + buffer,
         )
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=extracted_array_2d.shape,
             pixel_scales=self.pixel_scales,
             sub_size=self.sub_size,
@@ -256,7 +303,9 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         return mask.extent
 
-    def resized_from(self, new_shape, mask_pad_value: int = 0.0):
+    def resized_from(
+        self, new_shape: Tuple[int, int], mask_pad_value: int = 0.0
+    ) -> "AbstractArray2D":
         """
         Resize the array around its centre to a new input shape.
 
@@ -268,15 +317,15 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         Parameters
         -----------
-        new_shape : (int, int)
+        new_shape
             The new 2D shape of the array.
         """
 
-        resized_array_2d = array_2d_util.resized_array_2d_from_array_2d(
+        resized_array_2d = array_2d_util.resized_array_2d_from(
             array_2d=self.native, resized_shape=new_shape
         )
 
-        resized_mask = self.mask.resized_mask_from_new_shape(
+        resized_mask = self.mask.resized_mask_from(
             new_shape=new_shape, pad_value=mask_pad_value
         )
 
@@ -284,8 +333,11 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         return self._new_structure(array=array, mask=resized_mask)
 
-    def padded_before_convolution_from(self, kernel_shape, mask_pad_value: int = 0.0):
-        """When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
+    def padded_before_convolution_from(
+        self, kernel_shape: Tuple[int, int], mask_pad_value: int = 0.0
+    ) -> "AbstractArray2D":
+        """
+        When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
         'missing' if the grid is used to evaluate the signal via an analytic function.
 
         To ensure this signal is included the array can be padded, where it is 'buffed' such that it includes all
@@ -294,7 +346,7 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
 
         Parameters
         ----------
-        kernel_shape : (float, float)
+        kernel_shape
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
         new_shape = (
@@ -303,17 +355,20 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
         )
         return self.resized_from(new_shape=new_shape, mask_pad_value=mask_pad_value)
 
-    def trimmed_after_convolution_from(self, kernel_shape):
-        """When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
+    def trimmed_after_convolution_from(
+        self, kernel_shape: Tuple[int, int]
+    ) -> "AbstractArray2D":
+        """
+        When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
         'missing' if the grid is used to evaluate the signal via an analytic function.
 
         To ensure this signal is included the array can be padded, a padded array can be computed via the method
-        *padded_from_kernel_shape*. This function trims the array back to its original shape, after the padded array
-        has been used for computationl.
+        *padded_before_convolution_from*. This function trims the array back to its original shape, after the padded array
+        has been used for computational.
 
         Parameters
         ----------
-        kernel_shape : (float, float)
+        kernel_shape
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
         psf_cut_y = int(np.ceil(kernel_shape[0] / 2)) - 1
@@ -324,24 +379,21 @@ class AbstractArray2D(abstract_structure.AbstractStructure2D):
             psf_cut_y : array_y - psf_cut_y, psf_cut_x : array_x - psf_cut_x
         ]
 
-        resized_mask = self.mask.resized_mask_from_new_shape(
-            new_shape=trimmed_array_2d.shape
-        )
+        resized_mask = self.mask.resized_mask_from(new_shape=trimmed_array_2d.shape)
 
         array = convert_array_2d(array_2d=trimmed_array_2d, mask_2d=resized_mask)
 
         return self.__class__(array=array, mask=resized_mask)
 
-    def output_to_fits(self, file_path, overwrite=False):
+    def output_to_fits(self, file_path: str, overwrite: bool = False):
         """
         Output the array to a .fits file.
 
         Parameters
         ----------
-        file_path : str
-            The path the file is output to, including the filename and the ``.fits`` extension,
-            e.g. '/path/to/filename.fits'
-        overwrite : bool
+        file_path
+            The output path of the file, including the filename and the `.fits` extension e.g. '/path/to/filename.fits'
+        overwrite
             If a file already exists at the path, if overwrite=True it is overwritten else an error is raised.
         """
         array_2d_util.numpy_array_2d_to_fits(
