@@ -1,21 +1,21 @@
 import logging
-
 import numpy as np
 
+from autoarray.structures.arrays.two_d.abstract_array_2d import AbstractArray2D
+from autoarray.mask.mask_2d import Mask2D
+
 from autoarray import exc
-from autoarray.geometry import geometry_util
-from autoarray.mask import mask_2d as msk
 from autoarray.structures.arrays import abstract_array
 from autoarray.structures.arrays.two_d import abstract_array_2d
+from autoarray.geometry import geometry_util
 from autoarray.structures.arrays.two_d import array_2d_util
-from autoarray.structures.grids.two_d import grid_2d
 from autoarray.structures.grids.two_d import grid_2d_util
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
-class Array2D(abstract_array_2d.AbstractArray2D):
+class Array2D(AbstractArray2D):
     def __new__(cls, array, mask, header=None, zoom_for_plot=True, *args, **kwargs):
         """
         An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
@@ -175,9 +175,9 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        array : np.ndarray
+        array
             The values of the array.
-        mask : msk.Mask2D
+        mask
             The 2D mask associated with the array, defining the pixels each array value is paired with and
             originates from.
         """
@@ -197,7 +197,7 @@ class Array2D(abstract_array_2d.AbstractArray2D):
         array,
         shape_native,
         pixel_scales,
-        sub_size=1,
+        sub_size: int = 1,
         origin=(0.0, 0.0),
         header=None,
     ):
@@ -213,17 +213,17 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
 
@@ -234,20 +234,23 @@ class Array2D(abstract_array_2d.AbstractArray2D):
                 "The input shape_native parameter is not a tuple of type (float, float)"
             )
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
         )
 
+        array = abstract_array_2d.convert_array_2d(array_2d=array, mask_2d=mask)
+
         return cls(array=array, mask=mask, header=header)
 
     @classmethod
     def manual_native(
-        cls, array, pixel_scales, sub_size=1, origin=(0.0, 0.0), header=None
+        cls, array, pixel_scales, sub_size: int = 1, origin=(0.0, 0.0), header=None
     ):
-        """Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 2D, for example:
+        """
+        Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 2D, for example:
 
         array=np.ndarray([[1.0, 2.0],
                          [3.0, 4.0]])
@@ -260,15 +263,15 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_y_pixels*sub_size, total_x_pixel*sub_size] or a
              list of lists.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
 
@@ -278,7 +281,7 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         shape_native = (int(array.shape[0] / sub_size), int(array.shape[1] / sub_size))
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
@@ -295,28 +298,29 @@ class Array2D(abstract_array_2d.AbstractArray2D):
         array,
         pixel_scales,
         shape_native=None,
-        sub_size=1,
+        sub_size: int = 1,
         origin=(0.0, 0.0),
         header=None,
     ):
-        """Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D, automatically
+        """
+        Create an Array2D (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D, automatically
         determining whether to use the 'manual_slim' or 'manual_native' methods.
 
         See the manual_slim and manual_native methods for examples.
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
         array = abstract_array.convert_array(array=array)
@@ -339,7 +343,8 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
     @classmethod
     def manual_mask(cls, array, mask, header=None):
-        """Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D with its mask,
+        """
+        Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the array values in 1D or 2D with its mask,
         for example:
 
         mask = Mask2D([[True, False, False, False])
@@ -347,10 +352,10 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        mask : Mask2D
+        mask
             The mask whose masked pixels are used to setup the sub-pixel grid.
         """
         array = abstract_array_2d.convert_array_2d(array_2d=array, mask_2d=mask)
@@ -362,7 +367,7 @@ class Array2D(abstract_array_2d.AbstractArray2D):
         fill_value,
         shape_native,
         pixel_scales,
-        sub_size=1,
+        sub_size: int = 1,
         origin=(0.0, 0.0),
         header=None,
     ):
@@ -375,16 +380,16 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        fill_value : float
+        fill_value
             The value all array elements are filled with.
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
         if sub_size is not None:
@@ -400,9 +405,15 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
     @classmethod
     def ones(
-        cls, shape_native, pixel_scales, sub_size=1, origin=(0.0, 0.0), header=None
+        cls,
+        shape_native,
+        pixel_scales,
+        sub_size: int = 1,
+        origin=(0.0, 0.0),
+        header=None,
     ):
-        """Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with ones, analogous to the
+        """
+        Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with ones, analogous to the
         method np.ones().
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -410,14 +421,14 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
         return cls.full(
@@ -431,9 +442,15 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
     @classmethod
     def zeros(
-        cls, shape_native, pixel_scales, sub_size=1, origin=(0.0, 0.0), header=None
+        cls,
+        shape_native,
+        pixel_scales,
+        sub_size: int = 1,
+        origin=(0.0, 0.0),
+        header=None,
     ):
-        """Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with zeros, analogous to the
+        """
+        Create an Array2D (see `AbstractArray2D.__new__`) where all values are filled with zeros, analogous to the
         method np.ones().
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -441,14 +458,14 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         """
         return cls.full(
@@ -461,32 +478,34 @@ class Array2D(abstract_array_2d.AbstractArray2D):
         )
 
     @classmethod
-    def from_fits(cls, file_path, pixel_scales, hdu=0, sub_size=1, origin=(0.0, 0.0)):
+    def from_fits(
+        cls, file_path, pixel_scales, hdu=0, sub_size: int = 1, origin=(0.0, 0.0)
+    ):
         """
         Create an Array2D (see `AbstractArray2D.__new__`) by loading the array values from a .fits file.
 
         Parameters
         ----------
         file_path : str
-            The path the file is loaded from, including the filename and the ``.fits`` extension,
+            The path the file is loaded from, including the filename and the `.fits` extension,
             e.g. '/path/to/filename.fits'
-        hdu : int
+        hdu
             The Header-Data Unit of the .fits file the array data is loaded from.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
-            The (y,x) scaled units origin of the mask's coordinate system.
+        origin
+            The (y,x) scaled units origin of the coordinate system.
         """
-        array_2d = array_2d_util.numpy_array_2d_from_fits(file_path=file_path, hdu=hdu)
-
-        header_sci_obj = array_2d_util.header_obj_from_fits(file_path=file_path, hdu=0)
-        header_hdu_obj = array_2d_util.header_obj_from_fits(
+        array_2d = array_2d_util.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=hdu
         )
 
+        header_sci_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=0)
+        header_hdu_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=hdu)
+
         return cls.manual_native(
             array=array_2d,
             pixel_scales=pixel_scales,
@@ -499,9 +518,10 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
     @classmethod
     def manual_yx_and_values(
-        cls, y, x, values, shape_native, pixel_scales, sub_size=1, header=None
+        cls, y, x, values, shape_native, pixel_scales, sub_size: int = 1, header=None
     ):
-        """Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the y and x pixel values where the array is filled
+        """
+        Create an `Array2D` (see `AbstractArray2D.__new__`) by inputting the y and x pixel values where the array is filled
         and the values to fill the array, for example:
 
         y = np.array([0, 0, 0, 1])
@@ -513,25 +533,27 @@ class Array2D(abstract_array_2d.AbstractArray2D):
 
         Parameters
         ----------
-        y : np.ndarray or list
+        y or list
             The y pixel indexes where value sare input, as an ndarray of shape [total_y_pixels*sub_size] or a list.
-        x : np.ndarray or list
+        x or list
             The x pixel indexes where value sare input, as an ndarray of shape [total_y_pixels*sub_size] or a list.
-        values : np.ndarray or list
+        values or list
             The values which are used too fill in the array.
-        shape_native : (int, int)
+        shape_native
             The 2D shape of the mask the grid is paired with.
-        pixel_scales: (float, float) or float
-            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
+        pixel_scales
+            The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a `float`,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        grid = grid_2d.Grid2D.manual_yx_1d(
+        from autoarray.structures.grids.two_d.grid_2d import Grid2D
+
+        grid = Grid2D.manual_yx_1d(
             y=y, x=x, shape_native=shape_native, pixel_scales=pixel_scales, sub_size=1
         )
 
