@@ -1,66 +1,16 @@
-import inspect
-import os
-
-from autoconf import conf
-from autoarray import decorator_util
-from autoarray.mask import mask_2d_util
-import numpy as np
 from astropy.io import fits
 from functools import wraps
+import inspect
+import numpy as np
+import os
+from typing import Tuple
+
+from autoconf import conf
+from autoarray import numba_util
+from autoarray.mask import mask_2d_util
 
 
-class Memoizer:
-    def __init__(self):
-        """
-        Class to store the results of a function given a set of inputs.
-        """
-        self.results = {}
-        self.calls = 0
-        self.arg_names = None
-
-    def __call__(self, func):
-        """
-        Memoize decorator. Any time a function is called that a memoizer has been attached to its results are stored in
-        the results dictionary or retrieved from the dictionary if the function has aaready been called with those
-        arguments.
-
-        Note that the same memoizer persists over all instances of a class. Any state for a given instance that is not
-        given in the representation of that instance will be ignored. That is, it is possible that the memoizer will
-        give incorrect results if instance state does not affect __str__ but does affect the value returned by the
-        memoized method.
-
-        Parameters
-        ----------
-        func: function
-            A function for which results should be memoized
-
-        Returns
-        -------
-        decorated : function
-            A function that memoizes results
-        """
-        if self.arg_names is not None:
-            raise AssertionError("Instantiate a new Memoizer for each function")
-        self.arg_names = inspect.getfullargspec(func).args
-
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            key = ", ".join(
-                [
-                    "('{}', {})".format(arg_name, arg)
-                    for arg_name, arg in list(zip(self.arg_names, args))
-                    + [(k, v) for k, v in kwargs.items()]
-                ]
-            )
-            if key not in self.results:
-                self.calls += 1
-            self.results[key] = func(*args, **kwargs)
-            return self.results[key]
-
-        return wrapper
-
-
-@decorator_util.jit()
+@numba_util.jit()
 def extracted_array_2d_from(
     array_2d: np.ndarray, y0: int, y1: int, x0: int, x1: int
 ) -> np.ndarray:
@@ -77,15 +27,15 @@ def extracted_array_2d_from(
 
     Parameters
     ----------
-    array_2d : np.ndarray
+    array_2d
         The 2D array that an array is extracted from.
-    y0 : int
+    y0
         The top row number (e.g. the higher y-coodinate) of the array that is extracted for the resize.
-    y1 : int
+    y1
         The bottom row number (e.g. the lower y-coodinate) of the array that is extracted for the resize.
-    x0 : int
+    x0
         The left column number (e.g. the lower x-coodinate) of the array that is extracted for the resize.
-    x1 : int
+    x1
         The right column number (e.g. the higher x-coodinate) of the array that is extracted for the resize.
 
     Returns
@@ -116,11 +66,11 @@ def extracted_array_2d_from(
     return resized_array
 
 
-@decorator_util.jit()
-def resized_array_2d_from_array_2d(
+@numba_util.jit()
+def resized_array_2d_from(
     array_2d: np.ndarray,
-    resized_shape: (int, int),
-    origin: (int, int) = (-1, -1),
+    resized_shape: Tuple[int, int],
+    origin: Tuple[int, int] = (-1, -1),
     pad_value: int = 0.0,
 ) -> np.ndarray:
     """
@@ -135,13 +85,13 @@ def resized_array_2d_from_array_2d(
 
     Parameters
     ----------
-    array_2d : np.ndarray
+    array_2d
         The 2D array that is resized.
-    resized_shape : (int, int)
+    resized_shape
         The (y,x) new pixel dimension of the trimmed array.
-    origin : (int, int)
+    origin
         The oigin of the resized array, e.g. the central pixel around which the array is extracted.
-    pad_value : float
+    pad_value
         If the reszied array is bigger in size than the input array, the value the padded edge values are filled in
         using.
 
@@ -211,7 +161,7 @@ def resized_array_2d_from_array_2d(
     return resized_array
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def replace_noise_map_2d_values_where_image_2d_values_are_negative(
     image_2d: np.ndarray, noise_map_2d: np.ndarray, target_signal_to_noise: float = 2.0
 ) -> np.ndarray:
@@ -225,11 +175,11 @@ def replace_noise_map_2d_values_where_image_2d_values_are_negative(
 
     Parameters
     ----------
-    image_2d : np.ndarray
+    image_2d
         The 2D image array used to locate the pixel indexes in the noise-map which are replaced.
-    noise_map_2d : np.ndarray
+    noise_map_2d
         The 2D noise-map array whose values are replaced.
-    target_signal_to_noise : float
+    target_signal_to_noise
         The target signal-to-noise the noise-map valueus are changed to.
 
     Returns
@@ -256,7 +206,7 @@ def replace_noise_map_2d_values_where_image_2d_values_are_negative(
     return noise_map_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def index_2d_for_index_slim_from(indexes_slim: np.ndarray, shape_native) -> np.ndarray:
     """
     For pixels on a native 2D array of shape (total_y_pixels, total_x_pixels), this array maps the slimmed 1D pixel
@@ -274,9 +224,9 @@ def index_2d_for_index_slim_from(indexes_slim: np.ndarray, shape_native) -> np.n
 
     Parameters
     ----------
-    indexes_slim : np.ndarray
+    indexes_slim
         The slim 1D pixel indexes which are mapped to 2D indexes.
-    shape_native : (int, int)
+    shape_native
         The shape of the 2D array which the pixels are natively defined on.
 
     Returns
@@ -299,7 +249,7 @@ def index_2d_for_index_slim_from(indexes_slim: np.ndarray, shape_native) -> np.n
     return index_2d_for_index_slim
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def index_slim_for_index_2d_from(indexes_2d: np.ndarray, shape_native) -> np.ndarray:
     """
     For pixels on a native 2D array of shape (total_y_pixels, total_x_pixels), this array maps the 2D pixel indexes to
@@ -317,9 +267,9 @@ def index_slim_for_index_2d_from(indexes_2d: np.ndarray, shape_native) -> np.nda
 
     Parameters
     ----------
-    indexes_2d : np.ndarray
+    indexes_2d
         The native 2D pixel indexes which are mapped to slimmed 1D indexes.
-    shape_native : (int, int)
+    shape_native
         The shape of the 2D array which the pixels are defined on.
 
     Returns
@@ -342,7 +292,7 @@ def index_slim_for_index_2d_from(indexes_2d: np.ndarray, shape_native) -> np.nda
     return index_slim_for_index_native_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def array_2d_slim_from(
     array_2d_native: np.ndarray, mask_2d: np.ndarray, sub_size: int
 ) -> np.ndarray:
@@ -365,11 +315,11 @@ def array_2d_slim_from(
 
     Parameters
     ----------
-    array_2d_native : np.ndarray
+    array_2d_native
         A 2D array of values on the dimensions of the sub-grid.
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values mean unmasked and are included in the mapping.
-    array_2d_native : np.ndarray
+    array_2d_native
         The 2D array of values which are mapped to a 1D array.
 
     Returns
@@ -429,11 +379,11 @@ def array_2d_native_from(
 
     Parameters
     ----------
-    array_2d_slim : np.ndarray
+    array_2d_slim
         The slimmed array of values which are mapped to a 2D array.
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values mean unmasked and are included in the mapping.
-    sub_size : int
+    sub_size
         The size (sub_size x sub_size) of each unmasked pixels sub-array.
 
     Returns
@@ -447,7 +397,7 @@ def array_2d_native_from(
 
     array_1d = np.array([[2.0, 4.0, 5.0, 6.0, 8.0])
 
-    array_2d = map_masked_1d_array_to_2d_array_from_array_1d_shape_and_slim_to_native(
+    array_2d = map_masked_1d_array_to_2d_array_from(
         array_1d=array_1d, shape=(3,3), slim_to_native=slim_to_native)
     """
 
@@ -464,10 +414,10 @@ def array_2d_native_from(
     )
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def array_2d_via_indexes_from(
     array_2d_slim: np.ndarray,
-    sub_shape: (int, int),
+    sub_shape: Tuple[int, int],
     native_index_for_slim_index_2d: np.ndarray,
 ) -> np.ndarray:
     """
@@ -490,9 +440,9 @@ def array_2d_via_indexes_from(
 
     Parameters
     ----------
-    array_2d_slim : np.ndarray
+    array_2d_slim
         The slimmed array of shape [total_values] which are mapped to the native array..
-    sub_shape : (int, int)
+    sub_shape
         The 2D dimensions of the native 2D sub-array.
     native_index_for_slim_index_2d : np.narray
         An array of shape [total_values] that maps from the slimmed array to the native array.
@@ -514,7 +464,7 @@ def array_2d_via_indexes_from(
     return sub_array_native_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def array_2d_slim_complex_from(
     array_2d_native: np.ndarray, mask: np.ndarray, sub_size: int
 ) -> np.ndarray:
@@ -537,11 +487,11 @@ def array_2d_slim_complex_from(
 
     Parameters
     ----------
-    array_2d_native : np.ndarray
+    array_2d_native
         A 2D array of values on the dimensions of the sub-grid.
-    mask : np.ndarray
+    mask
         A 2D array of bools, where `False` values mean unmasked and are included in the mapping.
-    array_2d : np.ndarray
+    array_2d
         The 2D array of values which are mapped to a 1D array.
 
     Returns
@@ -560,7 +510,7 @@ def array_2d_slim_complex_from(
     mask = np.array([[True, False],
                      [False, False]])
 
-    sub_array_1d = map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_size(
+    sub_array_1d = map_sub_array_2d_to_masked_sub_array_1d_from(
         mask=mask, array_2d=array_2d)
     """
 
@@ -584,10 +534,10 @@ def array_2d_slim_complex_from(
     return sub_array_1d
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def array_2d_native_complex_via_indexes_from(
     array_2d_slim: np.ndarray,
-    sub_shape_native: (int, int),
+    sub_shape_native: Tuple[int, int],
     native_index_for_slim_index_2d: np.ndarray,
 ) -> np.ndarray:
 
@@ -614,7 +564,7 @@ def numpy_array_2d_to_fits(
 
     Parameters
     ----------
-    array_2d : np.ndarray
+    array_2d
         The 2D array that is written to fits.
     file_path : str
         The full path of the file that is output, including the file name and ``.fits`` extension.
@@ -651,7 +601,7 @@ def numpy_array_2d_to_fits(
     hdu.writeto(file_path)
 
 
-def numpy_array_2d_from_fits(
+def numpy_array_2d_via_fits_from(
     file_path: str, hdu: int, do_not_scale_image_data: bool = False
 ):
     """
@@ -664,7 +614,7 @@ def numpy_array_2d_from_fits(
     ----------
     file_path : str
         The full path of the file that is loaded, including the file name and ``.fits`` extension.
-    hdu : int
+    hdu
         The HDU extension of the array that is loaded from the .fits file.
     do_not_scale_image_data : bool
         If True, the .fits file is not rescaled automatically based on the .fits header info.
@@ -676,7 +626,7 @@ def numpy_array_2d_from_fits(
 
     Examples
     --------
-    array_2d = numpy_array_from_fits(file_path='/path/to/file/filename.fits', hdu=0)
+    array_2d = numpy_array_2d_via_fits_from(file_path='/path/to/file/filename.fits', hdu=0)
     """
     hdu_list = fits.open(file_path, do_not_scale_image_data=do_not_scale_image_data)
 
@@ -687,7 +637,7 @@ def numpy_array_2d_from_fits(
     return np.array(hdu_list[hdu].data).astype("float64")
 
 
-def header_obj_from_fits(file_path: str, hdu: int):
+def header_obj_from(file_path: str, hdu: int):
     """
     Read a 2D NumPy array from a .fits file.
 
@@ -698,7 +648,7 @@ def header_obj_from_fits(file_path: str, hdu: int):
     ----------
     file_path : str
         The full path of the file that is loaded, including the file name and ``.fits`` extension.
-    hdu : int
+    hdu
         The HDU extension of the array that is loaded from the .fits file.
     do_not_scale_image_data : bool
         If True, the .fits file is not rescaled automatically based on the .fits header info.
@@ -710,7 +660,7 @@ def header_obj_from_fits(file_path: str, hdu: int):
 
     Examples
     --------
-    array_2d = numpy_array_from_fits(file_path='/path/to/file/filename.fits', hdu=0)
+    array_2d = numpy_array_2d_via_fits_from(file_path='/path/to/file/filename.fits', hdu=0)
     """
     hdu_list = fits.open(file_path)
 
