@@ -1,19 +1,24 @@
 import numpy as np
 from functools import wraps
+from typing import List, Union
 
 from autoconf import conf
-from autoarray.structures.grids.one_d import abstract_grid_1d
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures.grids.two_d import grid_2d_interpolate
-from autoarray.structures.grids.two_d import grid_2d_iterate
-from autoarray.structures.grids.two_d import grid_2d_irregular
-from autoarray.structures.arrays.one_d import array_1d
-from autoarray.structures.arrays import values
+from autoarray.structures.arrays.one_d.array_1d import Array1D
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.grids.one_d.abstract_grid_1d import AbstractGrid1D
+from autoarray.structures.grids.one_d.grid_1d import Grid1D
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.structures.grids.two_d.grid_transformed import Grid2DTransformed
+from autoarray.structures.grids.two_d.grid_transformed import Grid2DTransformedNumpy
+from autoarray.structures.grids.two_d.grid_2d_iterate import Grid2DIterate
+from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
+from autoarray.structures.grids.two_d.grid_2d_irregular import (
+    Grid2DIrregularTransformed,
+)
+from autoarray.structures.arrays.values import ValuesIrregular
 
 from autoarray import exc
 
-from typing import Union
-
 
 def grid_1d_to_structure(func):
     """
@@ -22,7 +27,7 @@ def grid_1d_to_structure(func):
 
     Parameters
     ----------
-    func : (obj, grid, *args, **kwargs) -> Object
+    func
         A function which computes a set of values from a 2D grid of (y,x) coordinates.
 
     Returns
@@ -32,35 +37,35 @@ def grid_1d_to_structure(func):
 
     @wraps(func)
     def wrapper(
-        obj, grid, *args, **kwargs
-    ) -> Union[array_1d.Array1D, values.ValuesIrregular]:
+        obj: object,
+        grid: Union[Grid1D, Grid2D, Grid2DIterate, Grid2DIrregular],
+        *args,
+        **kwargs
+    ) -> Union[Array1D, ValuesIrregular]:
         """
         This decorator homogenizes the input of a "grid_like" 2D structure (`Grid2D`, `Grid2DIterate`,
-        `Grid2DInterpolate`, `Grid2DIrregular` or `AbstractGrid1D`) into a function. It allows these classes to be
+        `Grid2DIrregular` or `AbstractGrid1D`) into a function. It allows these classes to be
         interchangeably input into a function, such that the grid is used to evaluate the function at every (y,x)
         coordinates of the grid using specific functionality of the input grid.
 
-        The grid_like objects `Grid2D` and `Grid2DIrregular` are input into the function as a slimmed 2D NumPy array
-        of shape [total_coordinates, 2] where the second dimension stores the (y,x) values. If a `Grid2DIterate` is
-        input, the function is evaluated using the appropriate iterated_*_from_func* function.
+        If the `Grid2DLike` objects `Grid2D` and `Grid2DIrregular` are input into the function as a slimmed 2D NumPy
+        array of shape [total_coordinates, 2] they are projected into 1D and evaluated on this 1D grid. If the
+        decorator is wrapping an object with a `centre` or `angle`, the projected give aligns the angle at a 90
+        degree offset, which for an ellipse is its major-axis.
 
-        The outputs of the function are converted from a 1D or 2D NumPy Array2D to an `Array2D`, `Grid2D`,
-        `ValuesIrregular` or `Grid2DIrregular` objects, whichever is applicable as follows:
+        The outputs of the function are converted from a 1D ndarray to an `Array1D` or `ValuesIrregular`,
+        whichever is applicable as follows:
 
-        - If the function returns (y,x) coordinates at every input point, the returned results are a `Grid2D`
-        or `Grid2DIrregular` structure, the same structure as the input.
+        - If an object where the coordinates are on a uniformly spaced grid is input (e.g. `Grid1D`, the radially
+        projected grid computed from a `Grid2D`) the returns values using an `Array1D` object which assumes
+        uniform spacing.
 
-        - If the function returns scalar values at every input point and a `Grid2D` is input, the returned results are
-        an `Array2D` structure which uses the same dimensions and mask as the `Grid2D`.
-
-        - If the function returns scalar values at every input point and `Grid2DIrregular` are input, the returned
-        results are a `ValuesIrregular` object with structure resembling that of the `Grid2DIrregular`.
-
-        If the input array is not a `Grid2D` structure (e.g. it is a 2D NumPy array) the output is a NumPy array.
+        - If an object where the coordinates are on an irregular grid is input (e.g. `Grid2DIrregular`)`the function
+        returns a `ValuesIrregular` object which is also irregular.
 
         Parameters
         ----------
-        obj : object
+        obj
             An object whose function uses grid_like inputs to compute quantities at every coordinate on the grid.
         grid : Grid2D or Grid2DIrregular
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
@@ -82,31 +87,23 @@ def grid_1d_to_structure(func):
             if obj.angle is not None:
                 angle = obj.angle + 90.0
 
-        if (
-            isinstance(grid, grid_2d.Grid2D)
-            or isinstance(grid, grid_2d_iterate.Grid2DIterate)
-            or isinstance(grid, grid_2d_interpolate.Grid2DInterpolate)
-        ):
+        if isinstance(grid, Grid2D) or isinstance(grid, Grid2DIterate):
             grid_2d_projected = grid.grid_2d_radial_projected_from(
                 centre=centre, angle=angle
             )
             result = func(obj, grid_2d_projected, *args, **kwargs)
-            return array_1d.Array1D.manual_slim(
-                array=result, pixel_scales=grid.pixel_scale
-            )
+            return Array1D.manual_slim(array=result, pixel_scales=grid.pixel_scale)
 
-        elif isinstance(grid, grid_2d_irregular.Grid2DIrregular):
+        elif isinstance(grid, Grid2DIrregular):
             result = func(obj, grid, *args, **kwargs)
-            return grid.structure_2d_from_result(result=result)
-        elif isinstance(grid, abstract_grid_1d.AbstractGrid1D):
+            return grid.structure_2d_from(result=result)
+        elif isinstance(grid, AbstractGrid1D):
             grid_2d_radial = grid.project_to_radial_grid_2d(angle=angle)
             result = func(obj, grid_2d_radial, *args, **kwargs)
-            return array_1d.Array1D.manual_slim(
-                array=result, pixel_scales=grid.pixel_scale
-            )
+            return Array1D.manual_slim(array=result, pixel_scales=grid.pixel_scale)
 
         raise exc.GridException(
-            "You cannot input a NumPy array to a `quantity_1d_from_grid` method."
+            "You cannot input a NumPy array to a `quantity_1d_from` method."
         )
 
     return wrapper
@@ -119,7 +116,7 @@ def grid_1d_output_structure(func):
 
     Parameters
     ----------
-    func : (obj, grid, *args, **kwargs) -> Object
+    func
         A function which computes a set of values from a 2D grid of (y,x) coordinates.
 
     Returns
@@ -129,37 +126,21 @@ def grid_1d_output_structure(func):
 
     @wraps(func)
     def wrapper(
-        obj, grid, *args, **kwargs
-    ) -> Union[array_1d.Array1D, values.ValuesIrregular]:
+        obj: object,
+        grid: Union[Grid1D, Grid2D, Grid2DIterate, Grid2DIrregular],
+        *args,
+        **kwargs
+    ) -> Union[Array1D, ValuesIrregular]:
         """
-        This decorator homogenizes the input of a "grid_like" 2D structure (`Grid2D`, `Grid2DIterate`,
-        `Grid2DInterpolate`, `Grid2DIrregular` or `AbstractGrid1D`) into a function. It allows these classes to be
-        interchangeably input into a function, such that the grid is used to evaluate the function at every (y,x)
-        coordinates of the grid using specific functionality of the input grid.
-
-        The grid_like objects `Grid2D` and `Grid2DIrregular` are input into the function as a slimmed 2D NumPy array
-        of shape [total_coordinates, 2] where the second dimension stores the (y,x) values. If a `Grid2DIterate` is
-        input, the function is evaluated using the appropriate iterated_*_from_func* function.
-
-        The outputs of the function are converted from a 1D or 2D NumPy Array2D to an `Array2D`, `Grid2D`,
-        `ValuesIrregular` or `Grid2DIrregular` objects, whichever is applicable as follows:
-
-        - If the function returns (y,x) coordinates at every input point, the returned results are a `Grid2D`
-        or `Grid2DIrregular` structure, the same structure as the input.
-
-        - If the function returns scalar values at every input point and a `Grid2D` is input, the returned results are
-        an `Array2D` structure which uses the same dimensions and mask as the `Grid2D`.
-
-        - If the function returns scalar values at every input point and `Grid2DIrregular` are input, the returned
-        results are a `ValuesIrregular` object with structure resembling that of the `Grid2DIrregular`.
-
-        If the input array is not a `Grid2D` structure (e.g. it is a 2D NumPy array) the output is a NumPy array.
+        This decorator homogenizes the output of functions which compute a 1D result, by inspecting the output
+        and converting the result to an `Array1D` object if it is uniformly spaced and a `ValuesIrregular` object if
+        it is irregular. "grid_like" 2D structure (`Grid2D`, `Grid2DIterate`,
 
         Parameters
         ----------
-        obj : object
+        obj
             An object whose function uses grid_like inputs to compute quantities at every coordinate on the grid.
-        grid : Grid2D or Grid2DIrregular
+        grid
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
 
         Returns
@@ -169,24 +150,16 @@ def grid_1d_output_structure(func):
 
         result = func(obj, grid, *args, **kwargs)
 
-        if (
-            isinstance(grid, grid_2d.Grid2D)
-            or isinstance(grid, grid_2d_iterate.Grid2DIterate)
-            or isinstance(grid, grid_2d_interpolate.Grid2DInterpolate)
-        ):
-            return array_1d.Array1D.manual_slim(
-                array=result, pixel_scales=grid.pixel_scale
-            )
+        if isinstance(grid, Grid2D) or isinstance(grid, Grid2DIterate):
+            return Array1D.manual_slim(array=result, pixel_scales=grid.pixel_scale)
 
-        elif isinstance(grid, grid_2d_irregular.Grid2DIrregular):
-            return grid.structure_2d_from_result(result=result)
-        elif isinstance(grid, abstract_grid_1d.AbstractGrid1D):
-            return array_1d.Array1D.manual_slim(
-                array=result, pixel_scales=grid.pixel_scale
-            )
+        elif isinstance(grid, Grid2DIrregular):
+            return grid.structure_2d_from(result=result)
+        elif isinstance(grid, AbstractGrid1D):
+            return Array1D.manual_slim(array=result, pixel_scales=grid.pixel_scale)
 
         raise exc.GridException(
-            "You cannot input a NumPy array to a `quantity_1d_from_grid` method."
+            "You cannot input a NumPy array to a `quantity_1d_from` method."
         )
 
     return wrapper
@@ -199,7 +172,7 @@ def grid_2d_to_structure(func):
 
     Parameters
     ----------
-    func : (obj, grid, *args, **kwargs) -> Object
+    func
         A function which computes a set of values from a 2D grid of (y,x) coordinates.
 
     Returns
@@ -208,16 +181,21 @@ def grid_2d_to_structure(func):
     """
 
     @wraps(func)
-    def wrapper(obj, grid, *args, **kwargs):
+    def wrapper(
+        obj: object,
+        grid: Union[np.ndarray, Grid2D, Grid2DIterate, Grid2DIrregular, Grid1D],
+        *args,
+        **kwargs
+    ) -> Union[np.ndarray, Array2D, ValuesIrregular, Grid2D, Grid2DIrregular]:
         """
         This decorator homogenizes the input of a "grid_like" 2D structure (`Grid2D`, `Grid2DIterate`,
-        `Grid2DInterpolate`, `Grid2DIrregular` or `AbstractGrid1D`) into a function. It allows these classes to be
+        `Grid2DIrregular` or `AbstractGrid1D`) into a function. It allows these classes to be
         interchangeably input into a function, such that the grid is used to evaluate the function at every (y,x)
         coordinates of the grid using specific functionality of the input grid.
 
         The grid_like objects `Grid2D` and `Grid2DIrregular` are input into the function as a slimmed 2D NumPy array
-        of shape [total_coordinates, 2] where the second dimension stores the (y,x) values. If a `Grid2DIterate` is
-        input, the function is evaluated using the appropriate iterated_*_from_func* function.
+        of shape [total_coordinates, 2] where the second dimension stores the (y,x)  If a `Grid2DIterate` is
+        input, the function is evaluated using the appropriate `iterated_from` function.
 
         The outputs of the function are converted from a 1D or 2D NumPy Array2D to an `Array2D`, `Grid2D`,
         `ValuesIrregular` or `Grid2DIrregular` objects, whichever is applicable as follows:
@@ -235,7 +213,7 @@ def grid_2d_to_structure(func):
 
         Parameters
         ----------
-        obj : object
+        obj
             An object whose function uses grid_like inputs to compute quantities at every coordinate on the grid.
         grid : Grid2D or Grid2DIrregular
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
@@ -245,24 +223,20 @@ def grid_2d_to_structure(func):
             The function values evaluated on the grid with the same structure as the input grid_like object.
         """
 
-        if isinstance(grid, grid_2d_iterate.Grid2DIterate):
-            return grid.iterated_result_from_func(func=func, cls=obj)
-        elif isinstance(grid, grid_2d_interpolate.Grid2DInterpolate):
-            return grid.result_from_func(func=func, cls=obj)
-        elif isinstance(grid, grid_2d_irregular.Grid2DIrregular):
+        if isinstance(grid, Grid2DIterate):
+            return grid.iterated_result_from(func=func, cls=obj)
+        elif isinstance(grid, Grid2DIrregular):
             result = func(obj, grid, *args, **kwargs)
-            return grid.structure_2d_from_result(result=result)
-        elif isinstance(grid, grid_2d.Grid2D):
+            return grid.structure_2d_from(result=result)
+        elif isinstance(grid, Grid2D):
             result = func(obj, grid, *args, **kwargs)
-            return grid.structure_2d_from_result(result=result)
-        elif isinstance(grid, abstract_grid_1d.AbstractGrid1D):
+            return grid.structure_2d_from(result=result)
+        elif isinstance(grid, AbstractGrid1D):
             grid_2d_radial = grid.project_to_radial_grid_2d()
             result = func(obj, grid_2d_radial, *args, **kwargs)
-            return grid.structure_2d_from_result(result=result)
+            return grid.structure_2d_from(result=result)
 
-        if not isinstance(grid, grid_2d_irregular.Grid2DIrregular) and not isinstance(
-            grid, grid_2d.Grid2D
-        ):
+        if not isinstance(grid, Grid2DIrregular) and not isinstance(grid, Grid2D):
             return func(obj, grid, *args, **kwargs)
 
     return wrapper
@@ -275,7 +249,7 @@ def grid_2d_to_structure_list(func):
 
     Parameters
     ----------
-    func : (obj, grid, *args, **kwargs) -> Object
+    func
         A function which computes a set of values from a 2D grid of (y,x) coordinates.
 
     Returns
@@ -284,15 +258,20 @@ def grid_2d_to_structure_list(func):
     """
 
     @wraps(func)
-    def wrapper(obj, grid, *args, **kwargs):
+    def wrapper(
+        obj: object,
+        grid: List[Union[np.ndarray, Grid2D, Grid2DIterate, Grid2DIrregular, Grid1D]],
+        *args,
+        **kwargs
+    ) -> List[Union[np.ndarray, Array2D, ValuesIrregular, Grid2D, Grid2DIrregular]]:
         """
-        This decorator serves the same purpose as the `grid_2d_to_structure` decorator, but it deals with functions whose
-        output is a list of results as opposed to a single NumPy array. It simply iterates over these lists to perform
-        the same conversions as `grid_2d_to_structure`.
+        This decorator serves the same purpose as the `grid_2d_to_structure` decorator, but it deals with functions
+        whose output is a list of results as opposed to a single NumPy array. It simply iterates over these lists to
+        perform the same conversions as `grid_2d_to_structure`.
 
         Parameters
         ----------
-        obj : object
+        obj
             An object whose function uses grid_like inputs to compute quantities at every coordinate on the grid.
         grid : Grid2D or Grid2DIrregular
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
@@ -303,41 +282,37 @@ def grid_2d_to_structure_list(func):
             of NumPy arrays.
         """
 
-        if isinstance(grid, grid_2d_iterate.Grid2DIterate):
+        if isinstance(grid, Grid2DIterate):
             mask = grid.mask.mask_new_sub_size_from(
                 mask=grid.mask, sub_size=max(grid.sub_steps)
             )
-            grid_compute = grid_2d.Grid2D.from_mask(mask=mask)
+            grid_compute = Grid2D.from_mask(mask=mask)
             result_list = func(obj, grid_compute, *args, **kwargs)
             result_list = [
-                grid_compute.structure_2d_from_result(result=result)
-                for result in result_list
+                grid_compute.structure_2d_from(result=result) for result in result_list
             ]
             result_list = [result.binned for result in result_list]
-            return grid.grid.structure_2d_list_from_result_list(result_list=result_list)
-        elif isinstance(grid, grid_2d_interpolate.Grid2DInterpolate):
-            return func(obj, grid, *args, **kwargs)
-        elif isinstance(grid, grid_2d_irregular.Grid2DIrregular):
+            return grid.grid.structure_2d_list_from(result_list=result_list)
+        elif isinstance(grid, Grid2DIrregular):
             result_list = func(obj, grid, *args, **kwargs)
-            return grid.structure_2d_list_from_result_list(result_list=result_list)
-        elif isinstance(grid, grid_2d.Grid2D):
+            return grid.structure_2d_list_from(result_list=result_list)
+        elif isinstance(grid, Grid2D):
             result_list = func(obj, grid, *args, **kwargs)
-            return grid.structure_2d_list_from_result_list(result_list=result_list)
-        elif isinstance(grid, abstract_grid_1d.AbstractGrid1D):
+            return grid.structure_2d_list_from(result_list=result_list)
+        elif isinstance(grid, AbstractGrid1D):
             grid_2d_radial = grid.project_to_radial_grid_2d()
             result_list = func(obj, grid_2d_radial, *args, **kwargs)
-            return grid.structure_2d_list_from_result_list(result_list=result_list)
+            return grid.structure_2d_list_from(result_list=result_list)
 
-        if not isinstance(grid, grid_2d_irregular.Grid2DIrregular) and not isinstance(
-            grid, grid_2d.Grid2D
-        ):
+        if not isinstance(grid, Grid2DIrregular) and not isinstance(grid, Grid2D):
             return func(obj, grid, *args, **kwargs)
 
     return wrapper
 
 
 def transform(func):
-    """Checks whether the input Grid2D of (y,x) coordinates have previously been transformed. If they have not \
+    """
+    Checks whether the input Grid2D of (y,x) coordinates have previously been transformed. If they have not \
     been transformed then they are transformed.
 
     Parameters
@@ -351,7 +326,28 @@ def transform(func):
     """
 
     @wraps(func)
-    def wrapper(cls, grid, *args, **kwargs):
+    def wrapper(
+        cls,
+        grid: Union[
+            np.ndarray,
+            Grid2D,
+            Grid2DIrregular,
+            Grid2DIterate,
+            Grid2DTransformed,
+            Grid2DTransformedNumpy,
+            Grid2DIrregularTransformed,
+        ],
+        *args,
+        **kwargs
+    ) -> Union[
+        np.ndarray,
+        Grid2D,
+        Grid2DIrregular,
+        Grid2DIterate,
+        Grid2DTransformed,
+        Grid2DTransformedNumpy,
+        Grid2DIrregularTransformed,
+    ]:
         """
 
         Parameters
@@ -368,11 +364,7 @@ def transform(func):
 
         if not isinstance(
             grid,
-            (
-                grid_2d.Grid2DTransformed,
-                grid_2d.Grid2DTransformedNumpy,
-                grid_2d_irregular.Grid2DIrregularTransformed,
-            ),
+            (Grid2DTransformed, Grid2DTransformedNumpy, Grid2DIrregularTransformed),
         ):
             result = func(
                 cls, cls.transform_grid_to_reference_frame(grid), *args, **kwargs
@@ -405,7 +397,12 @@ def relocate_to_radial_minimum(func):
     """
 
     @wraps(func)
-    def wrapper(cls, grid, *args, **kwargs):
+    def wrapper(
+        cls,
+        grid: Union[np.ndarray, Grid2D, Grid2DIrregular, Grid2DIterate],
+        *args,
+        **kwargs
+    ) -> Union[np.ndarray, Grid2D, Grid2DIrregular, Grid2DIterate]:
         """
 
         Parameters
