@@ -1,19 +1,24 @@
 import numpy as np
 from sklearn.cluster import KMeans
+from typing import List, Optional, Tuple, Union
+
+from autoarray.structures.grids.two_d.abstract_grid_2d import AbstractGrid2D
+from autoarray.mask.mask_2d import Mask2D
+
+from autoarray.structures.arrays.two_d import array_2d as a2d
+
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.structures.arrays.two_d import array_2d_util
 from autoarray.structures.grids import abstract_grid
 from autoarray.structures.grids.two_d import abstract_grid_2d
-from autoarray.mask import mask_2d as msk, mask_2d_util
-from autoarray.structures.grids.two_d import grid_2d_util, sparse_util
+from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.structures.grids.two_d import grid_2d_util
 from autoarray.geometry import geometry_util
-
-from typing import Union, Tuple
+from autoarray.mask.mask_2d import mask_2d_util
+from autoarray.structures.grids.two_d import sparse_util
 
 
-class Grid2D(abstract_grid_2d.AbstractGrid2D):
-    def __new__(cls, grid, mask, *args, **kwargs):
+class Grid2D(AbstractGrid2D):
+    def __new__(cls, grid: np.ndarray, mask: Mask2D, *args, **kwargs):
         """
         A grid of 2D (y,x) coordinates, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
         on the grid corresponds to the (y,x) coordinates at the centre of a sub-pixel of an unmasked pixel.
@@ -195,9 +200,9 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray
+        grid
             The (y,x) coordinates of the grid.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         """
@@ -209,17 +214,18 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         return obj
 
-    def _new_structure(self, grid, mask):
-        """Conveninence method for creating a new instance of the Grid2D class from this grid.
+    def _new_structure(self, grid: "Grid2D", mask: Mask2D) -> "Grid2D":
+        """
+        Conveninence method for creating a new instance of the Grid2D class from this grid.
 
         This method is over-written by other grids (e.g. Grid2DIterate) such that the slim and native methods return
         instances of that Grid2D's type.
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_sub_coordinates, 2] or list of lists.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         """
@@ -227,9 +233,15 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
     @classmethod
     def manual_slim(
-        cls, grid, shape_native, pixel_scales, sub_size=1, origin=(0.0, 0.0)
-    ):
-        """Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 1D, for example:
+        cls,
+        grid: Union[np.ndarray, List],
+        shape_native: Tuple[int, int],
+        pixel_scales: Union[Tuple[float, float], float],
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 1D, for example:
 
         grid=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]])
 
@@ -240,23 +252,23 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the grid is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
 
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
@@ -268,8 +280,15 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         return Grid2D(grid=grid, mask=mask)
 
     @classmethod
-    def manual_native(cls, grid, pixel_scales, sub_size=1, origin=(0.0, 0.0)):
-        """Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 2D, for example:
+    def manual_native(
+        cls,
+        grid: Union[np.ndarray, List],
+        pixel_scales: Union[Tuple[float, float], float],
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 2D, for example:
 
         grid=np.ndarray([[[1.0, 1.0], [2.0, 2.0]],
                          [[3.0, 3.0], [4.0, 4.0]]])
@@ -282,15 +301,15 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape
             [total_y_coordinates*sub_size, total_x_pixel*sub_size, 2] or a list of lists.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
 
@@ -300,7 +319,7 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         shape = (int(grid.shape[0] / sub_size), int(grid.shape[1] / sub_size))
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=shape,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
@@ -313,26 +332,32 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
     @classmethod
     def manual(
-        cls, grid, pixel_scales, shape_native=None, sub_size=1, origin=(0.0, 0.0)
-    ):
-        """Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 1D or 2D, automatically
+        cls,
+        grid: Union[np.ndarray, List],
+        pixel_scales: Union[Tuple[float, float], float],
+        shape_native: Tuple[int, int] = None,
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in 1D or 2D, automatically
         determining whether to use the 'manual_slim' or 'manual_native' methods.
 
         See the manual_slim and manual_native methods for examples.
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the grid is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
         if len(grid.shape) == 2:
@@ -348,7 +373,7 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def manual_mask(cls, grid, mask):
+    def manual_mask(cls, grid: Union[np.ndarray, List], mask: Mask2D) -> "Grid2D":
         """
         Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates in their native or slimmed format with
         their corresponding mask, automatically determining whether to use the 'manual_slim' or 'manual_native' methods.
@@ -357,9 +382,9 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_sub_coordinates, 2] or list of lists.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         """
@@ -373,9 +398,16 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
     @classmethod
     def manual_yx_1d(
-        cls, y, x, shape_native, pixel_scales, sub_size=1, origin=(0.0, 0.0)
-    ):
-        """Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates as 1D y and x values, for example:
+        cls,
+        y: Union[np.ndarray, List],
+        x: np.ndarray,
+        shape_native: Tuple[int, int],
+        pixel_scales: Union[Tuple[float, float], float],
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates as 1D y and x values, for example:
 
         y = np.array([1.0, 2.0, 3.0, 4.0])
         x = np.array([1.0, 2.0, 3.0, 4.0])
@@ -387,18 +419,18 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        y : np.ndarray or list
+        y or list
             The y coordinates of the grid input as an ndarray of shape [total_coordinates] or list.
-        x : np.ndarray or list
+        x or list
             The x coordinates of the grid input as an ndarray of shape [total_coordinates] or list.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the grid is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
         if type(y) is list:
@@ -416,8 +448,16 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def manual_yx_2d(cls, y, x, pixel_scales, sub_size=1, origin=(0.0, 0.0)):
-        """Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates as 2D y and x values, for example:
+    def manual_yx_2d(
+        cls,
+        y: Union[np.ndarray, List],
+        x: Union[np.ndarray, List],
+        pixel_scales: Union[Tuple[float, float], float],
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) by inputting the grid coordinates as 2D y and x values, for example:
 
         y = np.array([[1.0, 2.0],
                      [3.0, 4.0]])
@@ -433,16 +473,16 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        y : np.ndarray or list
+        y or list
             The y coordinates of the grid input as an ndarray of shape [total_coordinates] or list.
-        x : np.ndarray or list
+        x or list
             The x coordinates of the grid input as an ndarray of shape [total_coordinates] or list.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
         if type(y) is list:
@@ -501,9 +541,14 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
     @classmethod
     def bounding_box(
-        cls, bounding_box, shape_native, sub_size=1, buffer_around_corners=False
-    ):
-        """Create a Grid2D (see *Grid2D.__new__*) from an input bounding box with coordinates [y_min, y_max, x_min, x_max],
+        cls,
+        bounding_box: np.ndarray,
+        shape_native: Tuple[int, int],
+        sub_size: int = 1,
+        buffer_around_corners: bool = False,
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) from an input bounding box with coordinates [y_min, y_max, x_min, x_max],
         where the shape_native is used to compute the (y,x) grid values within this bounding box.
 
         If buffer_around_corners=True, the grid's (y,x) values fully align with the input bounding box values. This
@@ -513,14 +558,14 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the uniform grid and the mask that it is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-grid.
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         buffer_around_corners : bool
             Whether the grid is buffered such that the (y,x) values in the centre of its masks' edge pixels align
@@ -551,7 +596,7 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def from_mask(cls, mask):
+    def from_mask(cls, mask: Mask2D) -> "Grid2D":
         """
         Create a Grid2D (see *Grid2D.__new__*) from a mask, where only unmasked pixels are included in the grid (if the
         grid is represented in its native 2D masked values are (0.0, 0.0)).
@@ -574,8 +619,15 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         return Grid2D(grid=sub_grid_1d, mask=mask)
 
     @classmethod
-    def from_fits(cls, file_path, pixel_scales, sub_size=1, origin=(0.0, 0.0)):
-        """Create a Grid2D (see *Grid2D.__new__*) from a mask, where only unmasked pixels are included in the grid (if the
+    def from_fits(
+        cls,
+        file_path: str,
+        pixel_scales: Union[Tuple[float, float], float],
+        sub_size: int = 1,
+        origin: Tuple[float, float] = (0.0, 0.0),
+    ) -> "Grid2D":
+        """
+        Create a Grid2D (see *Grid2D.__new__*) from a mask, where only unmasked pixels are included in the grid (if the
         grid is represented in its native 2D masked values are (0.0, 0.0)).
 
         The mask's pixel_scales, sub_size and origin properties are used to compute the grid (y,x) coordinates.
@@ -586,7 +638,9 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
             The mask whose masked pixels are used to setup the sub-pixel grid.
         """
 
-        sub_grid_2d = array_2d_util.numpy_array_2d_from_fits(file_path=file_path, hdu=0)
+        sub_grid_2d = array_2d_util.numpy_array_2d_via_fits_from(
+            file_path=file_path, hdu=0
+        )
 
         return Grid2D.manual(
             grid=sub_grid_2d,
@@ -596,11 +650,13 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def blurring_grid_from_mask_and_kernel_shape(cls, mask, kernel_shape_native):
+    def blurring_grid_from(
+        cls, mask: Mask2D, kernel_shape_native: Tuple[int, int]
+    ) -> "Grid2D":
         """
         Setup a blurring-grid from a mask, where a blurring grid consists of all pixels that are masked (and
         therefore have their values set to (0.0, 0.0)), but are close enough to the unmasked pixels that their values
-        will be convolved into the unmasked those pixels. This occurs in *PyAutoGalaxy* when computing images from
+        will be convolved into the unmasked those pixels. This when computing images from
         light profile objects.
 
         The mask's pixel_scales, sub_size and origin properties are used to compute the blurring grid's (y,x)
@@ -665,17 +721,15 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         ----------
         mask : Mask2D
             The mask whose masked pixels are used to setup the blurring grid.
-        kernel_shape_native : (float, float)
+        kernel_shape_native
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
 
-        blurring_mask = mask.blurring_mask_from_kernel_shape(
-            kernel_shape_native=kernel_shape_native
-        )
+        blurring_mask = mask.blurring_mask_from(kernel_shape_native=kernel_shape_native)
 
         return cls.from_mask(mask=blurring_mask)
 
-    def grid_from_deflection_grid(self, deflection_grid):
+    def grid_via_deflection_grid_from(self, deflection_grid: "Grid2D") -> "Grid2D":
         """
         Returns a new Grid2D from this grid, where the (y,x) coordinates of this grid have a grid of (y,x) values,
              termed the deflection grid, subtracted from them to determine the new grid of (y,x) values.
@@ -684,29 +738,31 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
             Parameters
             ----------
-            deflection_grid : np.ndarray
+            deflection_grid
                 The grid of (y,x) coordinates which is subtracted from this grid.
         """
         return Grid2D(grid=self - deflection_grid, mask=self.mask)
 
-    def blurring_grid_from_kernel_shape(self, kernel_shape_native):
+    def blurring_grid_via_kernel_shape_from(
+        self, kernel_shape_native: Tuple[int, int]
+    ) -> "Grid2D":
         """
         Returns the blurring grid from a grid, via an input 2D kernel shape.
 
-            For a full description of blurring grids, checkout *blurring_grid_from_mask_and_kernel_shape*.
+            For a full description of blurring grids, checkout *blurring_grid_from*.
 
             Parameters
             ----------
-            kernel_shape_native : (float, float)
+            kernel_shape_native
                 The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
 
-        return Grid2D.blurring_grid_from_mask_and_kernel_shape(
+        return Grid2D.blurring_grid_from(
             mask=self.mask, kernel_shape_native=kernel_shape_native
         )
 
     def grid_with_coordinates_within_distance_removed(
-        self, coordinates, distance
+        self, coordinates: Union[np.ndarray, List], distance: float
     ) -> "Grid2D":
         """Remove all coordinates from this Grid2D which are within a certain distance of an input list of coordinates.
 
@@ -717,7 +773,7 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
         ----------
         coordinates : [(float, float)]
             The list of coordinates which are removed from the grid if they are within the distance threshold.
-        distance : float
+        distance
             The distance threshold that coordinates are removed if they are within that of the input coordinates.
         """
 
@@ -728,11 +784,11 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         for coordinate in coordinates:
 
-            distances = self.distances_from_coordinate(coordinate=coordinate)
+            distances = self.distances_to_coordinate(coordinate=coordinate)
 
             distance_mask += distances.native < distance
 
-        mask = msk.Mask2D.manual(
+        mask = Mask2D.manual(
             mask=distance_mask,
             pixel_scales=self.pixel_scales,
             sub_size=self.sub_size,
@@ -741,7 +797,7 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         return Grid2D.from_mask(mask=mask)
 
-    def structure_2d_from_result(self, result: np.ndarray):
+    def structure_2d_from(self, result: np.ndarray) -> Union["a2d.Array2D", "Grid2D"]:
         """
         Convert a result from an ndarray to an aa.Array2D or aa.Grid2D structure, where the conversion depends on
         type(result) as follows:
@@ -754,17 +810,27 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        result : np.ndarray or [np.ndarray]
+        result or [np.ndarray]
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
         if len(result.shape) == 1:
-            return array_2d.Array2D(array=result, mask=self.mask)
+            return a2d.Array2D(array=result, mask=self.mask)
         else:
+
+            from autoarray.structures.grids.two_d.grid_transformed import (
+                Grid2DTransformed,
+            )
+            from autoarray.structures.grids.two_d.grid_transformed import (
+                Grid2DTransformedNumpy,
+            )
+
             if isinstance(result, Grid2DTransformedNumpy):
                 return Grid2DTransformed(grid=result, mask=self.mask)
             return Grid2D(grid=result, mask=self.mask)
 
-    def structure_2d_list_from_result_list(self, result_list: list):
+    def structure_2d_list_from(
+        self, result_list: List
+    ) -> List[Union["a2d.Array2D", "Grid2D"]]:
         """
         Convert a result from a list of ndarrays to a list of aa.Array2D or aa.Grid2D structure, where the conversion
         depends on type(result) as follows:
@@ -777,14 +843,14 @@ class Grid2D(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        result_list : np.ndarray or [np.ndarray]
+        result_list or [np.ndarray]
             The input result (e.g. of a decorated function) that is converted to a PyAutoArray structure.
         """
-        return [self.structure_2d_from_result(result=result) for result in result_list]
+        return [self.structure_2d_from(result=result) for result in result_list]
 
 
-class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
-    def __new__(cls, grid, sparse_index_for_slim_index):
+class Grid2DSparse(AbstractGrid2D):
+    def __new__(cls, grid: np.ndarray, sparse_index_for_slim_index: np.ndarray):
         """
         A sparse grid of coordinates, where each entry corresponds to the (y,x) coordinates at the centre of a
         pixel on the sparse grid. To setup the sparse-grid, it is laid over a grid of unmasked pixels, such
@@ -808,9 +874,9 @@ class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        sparse_grid : np.ndarray or Grid2D
+        sparse_grid or Grid2D
             The (y,x) grid of sparse coordinates.
-        sparse_index_for_slim_index : np.ndarray
+        sparse_index_for_slim_index
             An array whose indexes map pixels from a Grid2D's mask to the closest (y,x) coordinate on the sparse_grid.
         """
 
@@ -825,19 +891,21 @@ class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
             self.sparse_index_for_slim_index = obj.sparse_index_for_slim_index
 
     @classmethod
-    def from_grid_and_unmasked_2d_grid_shape(cls, grid, unmasked_sparse_shape):
+    def from_grid_and_unmasked_2d_grid_shape(
+        cls, grid: Union[np.ndarray, List], unmasked_sparse_shape: Tuple[int, int]
+    ) -> "Grid2DSparse":
         """Calculate a Grid2DSparse a Grid2D from the unmasked 2D shape of the sparse grid.
 
         This is performed by overlaying the 2D sparse grid (computed from the unmaksed sparse shape) over the edge
         values of the Grid2D.
 
-        This function is used in the `Inversion` package to set up the VoronoiMagnification Pixelization.
+        This function is used in the `LinearEqn` package to set up the VoronoiMagnification Pixelization.
 
         Parameters
         -----------
         grid : Grid2D
             The grid of (y,x) scaled coordinates at the centre of every image value (e.g. image-pixels).
-        unmasked_sparse_shape : (int, int)
+        unmasked_sparse_shape
             The 2D shape of the sparse grid which is overlaid over the grid.
         """
 
@@ -910,35 +978,35 @@ class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
     @classmethod
     def from_total_pixels_grid_and_weight_map(
         cls,
-        total_pixels,
-        grid,
-        weight_map,
-        n_iter=1,
-        max_iter=5,
-        seed=None,
-        stochastic=False,
-    ):
+        total_pixels: int,
+        grid: "Grid2D",
+        weight_map: np.ndarray,
+        n_iter: int = 1,
+        max_iter: int = 5,
+        seed: Optional[int] = None,
+        stochastic: bool = False,
+    ) -> "Grid2DSparse":
         """
         Calculate a Grid2DSparse from a Grid2D and weight map.
 
         This is performed by running a KMeans clustering algorithm on the weight map, such that Grid2DSparse (y,x)
         coordinates cluster around the weight map values with higher values.
 
-        This function is used in the `Inversion` package to set up the VoronoiMagnification Pixelization.
+        This function is used in the `LinearEqn` package to set up the VoronoiMagnification Pixelization.
 
         Parameters
         -----------
-        total_pixels : int
+        total_pixels
             The total number of pixels in the Grid2DSparse and input into the KMeans algortihm.
         grid : Grid2D
             The grid of (y,x) coordinates corresponding to the weight map.
-        weight_map : np.ndarray
+        weight_map
             The 2D array of weight values that the KMeans clustering algorithm adapts to to determine the Grid2DSparse.
-        n_iter : int
+        n_iter
             The number of times the KMeans algorithm is repeated.
-        max_iter : int
+        max_iter
             The maximum number of iterations in one run of the KMeans algorithm.
-        seed : int or None
+        seed or None
             The random number seed, which can be used to reproduce Grid2DSparse's for the same inputs.
         stochastic : bool
             If True, the random number seed is randommly chosen every time the function is called, ensuring every
@@ -952,7 +1020,10 @@ class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
             raise exc.GridException
 
         kmeans = KMeans(
-            n_clusters=total_pixels, random_state=seed, n_init=n_iter, max_iter=max_iter
+            n_clusters=int(total_pixels),
+            random_state=seed,
+            n_init=n_iter,
+            max_iter=max_iter,
         )
 
         try:
@@ -966,15 +1037,5 @@ class Grid2DSparse(abstract_grid_2d.AbstractGrid2D):
         )
 
     @property
-    def total_sparse_pixels(self):
+    def total_sparse_pixels(self) -> int:
         return len(self)
-
-
-class Grid2DTransformed(Grid2D):
-
-    pass
-
-
-class Grid2DTransformedNumpy(np.ndarray):
-    def __new__(cls, grid, *args, **kwargs):
-        return grid.view(cls)
