@@ -1,27 +1,36 @@
 import numpy as np
+from typing import Callable, Union, List, Tuple, Optional
+
+from autoarray.structures.grids.two_d.abstract_grid_2d import AbstractGrid2D
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.mask.mask_2d import Mask2D
+
+from autoarray.structures.arrays.two_d import array_2d as a2d
+
 
-from autoarray import decorator_util
-from autoarray.mask import mask_2d as msk
 from autoarray.structures.grids import abstract_grid
-from autoarray.structures.grids.two_d import abstract_grid_2d
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures.grids.two_d import grid_2d_util
-from autoarray.geometry import geometry_util
-from autoarray.structures.arrays.two_d import array_2d
 from autoarray.structures.arrays.two_d import array_2d_util
-from autoarray import exc
+from autoarray import numba_util
+from autoarray.geometry import geometry_util
+from autoarray.structures.grids.two_d import grid_2d_util
 
 
-def sub_steps_from_none(sub_steps):
+def sub_steps_from(sub_steps):
 
     if sub_steps is None:
         return [2, 4, 8, 16]
     return sub_steps
 
 
-class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
+class Grid2DIterate(AbstractGrid2D):
     def __new__(
-        cls, grid, mask, fractional_accuracy=0.9999, sub_steps=None, *args, **kwargs
+        cls,
+        grid: np.ndarray,
+        mask: Mask2D,
+        fractional_accuracy: float = 0.9999,
+        sub_steps: List[int] = None,
+        *args,
+        **kwargs
     ):
         """
         Represents a grid of coordinates as described for the `Grid2D` class, but using an iterative sub-grid that
@@ -43,12 +52,12 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray
+        grid
             The (y,x) coordinates of the grid.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
-        fractional_accuracy : float
+        fractional_accuracy
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
             of the value at a higher sub_size to othe value computed using the previous sub_size.
         sub_steps : [int] or None
@@ -56,18 +65,18 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             they are setup as the default values [2, 4, 8, 16].
         """
 
-        sub_steps = sub_steps_from_none(sub_steps=sub_steps)
+        sub_steps = sub_steps_from(sub_steps=sub_steps)
 
         obj = grid.view(cls)
         obj.mask = mask
-        obj.grid = grid_2d.Grid2D.manual_mask(grid=np.asarray(obj), mask=mask)
+        obj.grid = Grid2D.manual_mask(grid=np.asarray(obj), mask=mask)
         obj.fractional_accuracy = fractional_accuracy
         obj.sub_steps = sub_steps
         return obj
 
     def __array_finalize__(self, obj):
 
-        super(Grid2DIterate, self).__array_finalize__(obj)
+        super().__array_finalize__(obj)
 
         if hasattr(obj, "grid"):
             self.grid = obj.grid
@@ -87,9 +96,9 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_sub_coordinates, 2] or list of lists.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
         """
@@ -103,13 +112,13 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
     @classmethod
     def manual_slim(
         cls,
-        grid,
-        shape_native,
-        pixel_scales,
-        origin=(0.0, 0.0),
-        fractional_accuracy=0.9999,
-        sub_steps=None,
-    ):
+        grid: Union[np.ndarray, List],
+        shape_native: Tuple[int, int],
+        pixel_scales: Union[Tuple[float, float], float],
+        origin: Tuple[float, float] = (0.0, 0.0),
+        fractional_accuracy: float = 0.9999,
+        sub_steps: Optional[List[int]] = None,
+    ) -> "Grid2DIterate":
         """
         Create a Grid2DIterate (see *Grid2DIterate.__new__*) by inputting the grid coordinates in 1D, for example:
 
@@ -122,27 +131,27 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid : np.ndarray or list
+        grid or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the grid is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        fractional_accuracy : float
+        fractional_accuracy
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
             of the value at a higher sub_size to othe value computed using the previous sub_size.
         sub_steps : [int] or None
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
         grid = abstract_grid.convert_grid(grid=grid)
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        mask = msk.Mask2D.unmasked(
+        mask = Mask2D.unmasked(
             shape_native=shape_native,
             pixel_scales=pixel_scales,
             sub_size=1,
@@ -159,30 +168,30 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
     @classmethod
     def uniform(
         cls,
-        shape_native,
-        pixel_scales,
-        origin=(0.0, 0.0),
-        fractional_accuracy=0.9999,
-        sub_steps=None,
-    ):
+        shape_native: Tuple[int, int],
+        pixel_scales: Union[Tuple[float, float], float],
+        origin: Tuple[float, float] = (0.0, 0.0),
+        fractional_accuracy: float = 0.9999,
+        sub_steps: Optional[List[int]] = None,
+    ) -> "Grid2DIterate":
         """
         Create a Grid2DIterate (see *Grid2DIterate.__new__*) as a uniform grid of (y,x) values given an input
         shape_native and pixel scale of the grid:
 
         Parameters
         ----------
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the uniform grid and the mask that it is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        fractional_accuracy : float
+        fractional_accuracy
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
             of the value at a higher sub_size to othe value computed using the previous sub_size.
         sub_steps : [int] or None
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
-        origin : (float, float)
+        origin
             The origin of the grid's mask.
         """
 
@@ -205,7 +214,12 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def from_mask(cls, mask, fractional_accuracy=0.9999, sub_steps=None):
+    def from_mask(
+        cls,
+        mask: Mask2D,
+        fractional_accuracy: float = 0.9999,
+        sub_steps: Optional[List[int]] = None,
+    ) -> "Grid2DIterate":
         """
         Create a Grid2DIterate (see *Grid2DIterate.__new__*) from a mask, where only unmasked pixels are included in
         the grid (if the grid is represented in 2D masked values are (0.0, 0.0)).
@@ -216,7 +230,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         ----------
         mask : Mask2D
             The mask whose masked pixels are used to setup the sub-pixel grid.
-        fractional_accuracy : float
+        fractional_accuracy
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
             of the value at a higher sub_size to othe value computed using the previous sub_size.
         sub_steps : [int] or None
@@ -236,25 +250,29 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         )
 
     @classmethod
-    def blurring_grid_from_mask_and_kernel_shape(
-        cls, mask, kernel_shape_native, fractional_accuracy=0.9999, sub_steps=None
-    ):
+    def blurring_grid_from(
+        cls,
+        mask: Mask2D,
+        kernel_shape_native: Tuple[int, int],
+        fractional_accuracy: float = 0.9999,
+        sub_steps: Optional[List[int]] = None,
+    ) -> "Grid2DIterate":
         """
         Setup a blurring-grid from a mask, where a blurring grid consists of all pixels that are masked (and
         therefore have their values set to (0.0, 0.0)), but are close enough to the unmasked pixels that their values
-        will be convolved into the unmasked those pixels. This occurs in *PyAutoGalaxy* when computing images from
+        will be convolved into the unmasked those pixels. This when computing images from
         light profile objects.
 
-        See *grid_2d.Grid2D.blurring_grid_from_mask_and_kernel_shape* for a full description of a blurring grid. This
+        See *Grid2D.blurring_grid_from* for a full description of a blurring grid. This
         method creates the blurring grid as a Grid2DIterate.
 
         Parameters
         ----------
         mask : Mask2D
             The mask whose masked pixels are used to setup the blurring grid.
-        kernel_shape_native : (float, float)
+        kernel_shape_native
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
-        fractional_accuracy : float
+        fractional_accuracy
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
             of the value at a higher sub_size to othe value computed using the previous sub_size.
         sub_steps : [int] or None
@@ -262,9 +280,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             they are setup as the default values [2, 4, 8, 16].
         """
 
-        blurring_mask = mask.blurring_mask_from_kernel_shape(
-            kernel_shape_native=kernel_shape_native
-        )
+        blurring_mask = mask.blurring_mask_from(kernel_shape_native=kernel_shape_native)
 
         return cls.from_mask(
             mask=blurring_mask,
@@ -272,7 +288,9 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             sub_steps=sub_steps,
         )
 
-    def grid_from_deflection_grid(self, deflection_grid):
+    def grid_via_deflection_grid_from(
+        self, deflection_grid: np.ndarray
+    ) -> "Grid2DIterate":
         """
         Returns a new Grid2DIterate from this grid, where the (y,x) coordinates of this grid have a grid of (y,x) values,
         termed the deflection grid, subtracted from them to determine the new grid of (y,x) values.
@@ -281,7 +299,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        deflection_grid : np.ndarray
+        deflection_grid
             The grid of (y,x) coordinates which is subtracted from this grid.
         """
         return Grid2DIterate(
@@ -291,26 +309,28 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             sub_steps=self.sub_steps,
         )
 
-    def blurring_grid_from_kernel_shape(self, kernel_shape_native):
+    def blurring_grid_via_kernel_shape_from(
+        self, kernel_shape_native: Tuple[int, int]
+    ) -> "Grid2DIterate":
         """
         Returns the blurring grid from a grid and create it as a Grid2DIterate, via an input 2D kernel shape.
 
-            For a full description of blurring grids, checkout *blurring_grid_from_mask_and_kernel_shape*.
+            For a full description of blurring grids, checkout *blurring_grid_from*.
 
             Parameters
             ----------
-            kernel_shape_native : (float, float)
+            kernel_shape_native
                 The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
 
-        return Grid2DIterate.blurring_grid_from_mask_and_kernel_shape(
+        return Grid2DIterate.blurring_grid_from(
             mask=self.mask,
             kernel_shape_native=kernel_shape_native,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
         )
 
-    def padded_grid_from_kernel_shape(self, kernel_shape_native):
+    def padded_grid_from(self, kernel_shape_native: Tuple[int, int]) -> "Grid2DIterate":
         """
         When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
         'missing' if the grid is used to evaluate the signal via an analytic function.
@@ -320,7 +340,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        kernel_shape_native : (float, float)
+        kernel_shape_native
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
         shape = self.mask.shape
@@ -330,7 +350,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             shape[1] + kernel_shape_native[1] - 1,
         )
 
-        padded_mask = msk.Mask2D.unmasked(
+        padded_mask = Mask2D.unmasked(
             shape_native=padded_shape,
             pixel_scales=self.mask.pixel_scales,
             sub_size=self.mask.sub_size,
@@ -343,30 +363,28 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         )
 
     @staticmethod
-    def array_at_sub_size_from_func_and_mask(func, cls, mask, sub_size):
+    def array_at_sub_size_from(
+        func: Callable, cls, mask: Mask2D, sub_size
+    ) -> a2d.Array2D:
 
         mask_higher_sub = mask.mask_new_sub_size_from(mask=mask, sub_size=sub_size)
 
-        grid_compute = grid_2d.Grid2D.from_mask(mask=mask_higher_sub)
+        grid_compute = Grid2D.from_mask(mask=mask_higher_sub)
         array_higher_sub = func(cls, grid_compute)
-        return grid_compute.structure_2d_from_result(
-            result=array_higher_sub
-        ).binned.native
+        return grid_compute.structure_2d_from(result=array_higher_sub).binned.native
 
     @staticmethod
-    def grid_at_sub_size_from_func_and_mask(func, cls, mask, sub_size):
+    def grid_at_sub_size_from(func: Callable, cls, mask: Mask2D, sub_size) -> Grid2D:
 
         mask_higher_sub = mask.mask_new_sub_size_from(mask=mask, sub_size=sub_size)
 
-        grid_compute = grid_2d.Grid2D.from_mask(mask=mask_higher_sub)
+        grid_compute = Grid2D.from_mask(mask=mask_higher_sub)
         grid_higher_sub = func(cls, grid_compute)
-        return grid_compute.structure_2d_from_result(
-            result=grid_higher_sub
-        ).binned.native
+        return grid_compute.structure_2d_from(result=grid_higher_sub).binned.native
 
-    def fractional_mask_from_arrays(
-        self, array_lower_sub_2d, array_higher_sub_2d
-    ) -> msk.Mask2D:
+    def fractional_mask_via_arrays_from(
+        self, array_lower_sub_2d: a2d.Array2D, array_higher_sub_2d: a2d.Array2D
+    ) -> Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
         value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
@@ -379,19 +397,19 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        array_lower_sub_2d : array_2d.Array2D
+        array_lower_sub_2d : Array2D
             The results computed by a function using a lower sub-grid size
-        array_higher_sub_2d : array_2d.Array2D
+        array_higher_sub_2d : Array2D
             The results computed by a function using a higher sub-grid size.
         """
 
-        fractional_mask = msk.Mask2D.unmasked(
+        fractional_mask = Mask2D.unmasked(
             shape_native=array_lower_sub_2d.shape_native,
             pixel_scales=array_lower_sub_2d.pixel_scales,
             invert=True,
         )
 
-        fractional_mask = self.fractional_mask_jit_from_array(
+        fractional_mask = self.fractional_mask_via_arrays_jit_from(
             fractional_accuracy_threshold=self.fractional_accuracy,
             fractional_mask=fractional_mask,
             array_higher_sub_2d=array_higher_sub_2d,
@@ -399,21 +417,21 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             array_higher_mask=array_higher_sub_2d.mask,
         )
 
-        return msk.Mask2D(
+        return Mask2D(
             mask=fractional_mask,
             pixel_scales=array_higher_sub_2d.pixel_scales,
             origin=array_higher_sub_2d.origin,
         )
 
     @staticmethod
-    @decorator_util.jit()
-    def fractional_mask_jit_from_array(
-        fractional_accuracy_threshold,
-        fractional_mask,
-        array_higher_sub_2d,
-        array_lower_sub_2d,
-        array_higher_mask,
-    ):
+    @numba_util.jit()
+    def fractional_mask_via_arrays_jit_from(
+        fractional_accuracy_threshold: float,
+        fractional_mask: Mask2D,
+        array_higher_sub_2d: a2d.Array2D,
+        array_lower_sub_2d: a2d.Array2D,
+        array_higher_mask: Mask2D,
+    ) -> np.ndarray:
         """
         Jitted functioon to determine the fractional mask, which is a mask where:
 
@@ -446,7 +464,9 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         return fractional_mask
 
-    def iterated_array_from_func(self, func, cls, array_lower_sub_2d):
+    def iterated_array_from(
+        self, func: Callable, cls: object, array_lower_sub_2d: a2d.Array2D
+    ) -> a2d.Array2D:
         """
         Iterate over a function that returns an array of values until the it meets a specified fractional accuracy.
         The function returns a result on a pixel-grid where evaluating it on more points on a higher resolution
@@ -461,7 +481,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         If the function return all zeros, the iteration is terminated early given that all levels of sub-gridding will
         return zeros. This occurs when a function is missing optional objects that contribute to the calculation.
 
-        An example use case of this function is when a "image_2d_from_grid" methods in **PyAutoGalaxy**'s
+        An example use case of this function is when a "image_2d_from" methods in **PyAutoGalaxy**'s
         `LightProfile` module is comomputed, which by evaluating the function on a higher resolution sub-grids sample
         the analytic light profile at more points and thus more precisely.
 
@@ -471,7 +491,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             The function which is iterated over to compute a more precise evaluation.
         cls : cls
             The class the function belongs to.
-        grid_lower_sub_2d : array_2d.Array2D
+        grid_lower_sub_2d : Array2D
             The results computed by the function using a lower sub-grid size
         """
 
@@ -484,13 +504,13 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         for sub_size in self.sub_steps[:-1]:
 
-            array_higher_sub = self.array_at_sub_size_from_func_and_mask(
+            array_higher_sub = self.array_at_sub_size_from(
                 func=func, cls=cls, mask=fractional_mask_lower_sub, sub_size=sub_size
             )
 
             try:
 
-                fractional_mask_higher_sub = self.fractional_mask_from_arrays(
+                fractional_mask_higher_sub = self.fractional_mask_via_arrays_from(
                     array_lower_sub_2d=array_lower_sub_2d,
                     array_higher_sub_2d=array_higher_sub,
                 )
@@ -513,7 +533,7 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             array_lower_sub_2d = array_higher_sub
             fractional_mask_lower_sub = fractional_mask_higher_sub
 
-        array_higher_sub = self.array_at_sub_size_from_func_and_mask(
+        array_higher_sub = self.array_at_sub_size_from(
             func=func,
             cls=cls,
             mask=fractional_mask_lower_sub,
@@ -524,15 +544,13 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         return self.return_iterated_array_result(iterated_array=iterated_array_2d)
 
-    def return_iterated_array_result(
-        self, iterated_array: np.ndarray
-    ) -> array_2d.Array2D:
+    def return_iterated_array_result(self, iterated_array: a2d.Array2D) -> a2d.Array2D:
         """
         Returns the resulting iterated array, by mapping it to 1D and then passing it back as an `Array2D` structure.
 
         Parameters
         ----------
-        iterated_array : np.ndarray
+        iterated_array
 
         Returns
         -------
@@ -544,16 +562,16 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             mask_2d=self.mask, array_2d_native=iterated_array, sub_size=1
         )
 
-        return array_2d.Array2D(array=iterated_array_1d, mask=self.mask.mask_sub_1)
+        return a2d.Array2D(array=iterated_array_1d, mask=self.mask.mask_sub_1)
 
     @staticmethod
-    @decorator_util.jit()
+    @numba_util.jit()
     def iterated_array_jit_from(
-        iterated_array,
-        fractional_mask_higher_sub,
-        fractional_mask_lower_sub,
-        array_higher_sub_2d,
-    ):
+        iterated_array: a2d.Array2D,
+        fractional_mask_higher_sub: Mask2D,
+        fractional_mask_lower_sub: Mask2D,
+        array_higher_sub_2d: a2d.Array2D,
+    ) -> a2d.Array2D:
         """
         Create the iterated array from a result array that is computed at a higher sub size leel than the previous grid.
 
@@ -570,9 +588,9 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         return iterated_array
 
-    def fractional_mask_from_grids(
-        self, grid_lower_sub_2d, grid_higher_sub_2d
-    ) -> msk.Mask2D:
+    def fractional_mask_via_grids_from(
+        self, grid_lower_sub_2d: Grid2D, grid_higher_sub_2d: Grid2D
+    ) -> Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
         value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
@@ -585,19 +603,19 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         Parameters
         ----------
-        grid_lower_sub_2d : array_2d.Array2D
+        grid_lower_sub_2d : Array2D
             The results computed by a function using a lower sub-grid size
         grid_higher_sub_2d : grids.Array2D
             The results computed by a function using a higher sub-grid size.
         """
 
-        fractional_mask = msk.Mask2D.unmasked(
+        fractional_mask = Mask2D.unmasked(
             shape_native=grid_lower_sub_2d.shape_native,
             pixel_scales=grid_lower_sub_2d.pixel_scales,
             invert=True,
         )
 
-        fractional_mask = self.fractional_mask_jit_from_grid(
+        fractional_mask = self.fractional_mask_via_grids_jit_from(
             fractional_accuracy_threshold=self.fractional_accuracy,
             fractional_mask=fractional_mask,
             grid_higher_sub_2d=grid_higher_sub_2d,
@@ -605,21 +623,21 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             grid_higher_mask=grid_higher_sub_2d.mask,
         )
 
-        return msk.Mask2D(
+        return Mask2D(
             mask=fractional_mask,
             pixel_scales=grid_higher_sub_2d.pixel_scales,
             origin=grid_higher_sub_2d.origin,
         )
 
     @staticmethod
-    @decorator_util.jit()
-    def fractional_mask_jit_from_grid(
-        fractional_accuracy_threshold,
-        fractional_mask,
-        grid_higher_sub_2d,
-        grid_lower_sub_2d,
-        grid_higher_mask,
-    ):
+    @numba_util.jit()
+    def fractional_mask_via_grids_jit_from(
+        fractional_accuracy_threshold: float,
+        fractional_mask: Mask2D,
+        grid_higher_sub_2d: Grid2D,
+        grid_lower_sub_2d: Grid2D,
+        grid_higher_mask: Mask2D,
+    ) -> Mask2D:
         """
         Jitted function to determine the fractional mask, which is a mask where:
 
@@ -668,7 +686,9 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         return fractional_mask
 
-    def iterated_grid_from_func(self, func, cls, grid_lower_sub_2d):
+    def iterated_grid_from(
+        self, func: Callable, cls: object, grid_lower_sub_2d: Grid2D
+    ) -> Grid2D:
         """
         Iterate over a function that returns a grid of values until the it meets a specified fractional accuracy.
         The function returns a result on a pixel-grid where evaluating it on more points on a higher resolution
@@ -683,17 +703,17 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
         If the function return all zeros, the iteration is terminated early given that all levels of sub-gridding will
         return zeros. This occurs when a function is missing optional objects that contribute to the calculation.
 
-        An example use case of this function is when a "deflections_2d_from_grid" methods in **PyAutoLens**'s `MassProfile`
+        An example use case of this function is when a "deflections_2d_from" methods in **PyAutoLens**'s `MassProfile`
         module is computed, which by evaluating the function on a higher resolution sub-grid samples the analytic
         mass profile at more points and thus more precisely.
 
         Parameters
         ----------
-        func : func
+        func
             The function which is iterated over to compute a more precise evaluation.
-        cls : object
+        cls
             The class the function belongs to.
-        grid_lower_sub_2d : array_2d.Array2D
+        grid_lower_sub_2d
             The results computed by the function using a lower sub-grid size
         """
 
@@ -706,11 +726,11 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         for sub_size in self.sub_steps[:-1]:
 
-            grid_higher_sub = self.grid_at_sub_size_from_func_and_mask(
+            grid_higher_sub = self.grid_at_sub_size_from(
                 func=func, cls=cls, mask=fractional_mask_lower_sub, sub_size=sub_size
             )
 
-            fractional_mask_higher_sub = self.fractional_mask_from_grids(
+            fractional_mask_higher_sub = self.fractional_mask_via_grids_from(
                 grid_lower_sub_2d=grid_lower_sub_2d, grid_higher_sub_2d=grid_higher_sub
             )
 
@@ -727,12 +747,12 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
                     mask=self.mask, grid_2d_native=iterated_grid, sub_size=1
                 )
 
-                return grid_2d.Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
+                return Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
 
             grid_lower_sub_2d = grid_higher_sub
             fractional_mask_lower_sub = fractional_mask_higher_sub
 
-        grid_higher_sub = self.grid_at_sub_size_from_func_and_mask(
+        grid_higher_sub = self.grid_at_sub_size_from(
             func=func,
             cls=cls,
             mask=fractional_mask_lower_sub,
@@ -745,16 +765,16 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             mask=self.mask, grid_2d_native=iterated_grid_2d, sub_size=1
         )
 
-        return grid_2d.Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
+        return Grid2D(grid=iterated_grid_1d, mask=self.mask.mask_sub_1)
 
     @staticmethod
-    @decorator_util.jit()
+    @numba_util.jit()
     def iterated_grid_jit_from(
-        iterated_grid,
-        fractional_mask_higher_sub,
-        fractional_mask_lower_sub,
-        grid_higher_sub_2d,
-    ):
+        iterated_grid: Grid2D,
+        fractional_mask_higher_sub: Mask2D,
+        fractional_mask_lower_sub: Mask2D,
+        grid_higher_sub_2d: Grid2D,
+    ) -> Grid2D:
         """
         Create the iterated grid from a result grid that is computed at a higher sub size level than the previous grid.
 
@@ -771,14 +791,16 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
 
         return iterated_grid
 
-    def iterated_result_from_func(self, func, cls):
+    def iterated_result_from(
+        self, func: Callable, cls: object
+    ) -> Union[a2d.Array2D, Grid2D]:
         """
         Iterate over a function that returns an array or grid of values until the it meets a specified fractional
         accuracy. The function returns a result on a pixel-grid where evaluating it on more points on a higher
         resolution sub-grid followed by binning lead to a more precise evaluation of the function.
 
-        A full description of the iteration method can be found in the functions *iterated_array_from_func* and
-        *iterated_grid_from_func*. This function computes the result on a grid with a sub-size of 1, and uses its
+        A full description of the iteration method can be found in the functions *iterated_array_from* and
+        *iterated_grid_from*. This function computes the result on a grid with a sub-size of 1, and uses its
         shape to call the correct function.
 
         Parameters
@@ -789,15 +811,15 @@ class Grid2DIterate(abstract_grid_2d.AbstractGrid2D):
             The class the function belongs to.
         """
         result_sub_1_1d = func(cls, self.grid)
-        result_sub_1_2d = self.grid.structure_2d_from_result(
+        result_sub_1_2d = self.grid.structure_2d_from(
             result=result_sub_1_1d
         ).binned.native
 
         if len(result_sub_1_2d.shape) == 2:
-            return self.iterated_array_from_func(
+            return self.iterated_array_from(
                 func=func, cls=cls, array_lower_sub_2d=result_sub_1_2d
             )
         elif len(result_sub_1_2d.shape) == 3:
-            return self.iterated_grid_from_func(
+            return self.iterated_grid_from(
                 func=func, cls=cls, grid_lower_sub_2d=result_sub_1_2d
             )
