@@ -1,19 +1,20 @@
-from autoarray import decorator_util
 import numpy as np
+from typing import Tuple, Union, Optional
 
-from autoarray.mask import mask_2d_util
-from autoarray.geometry import geometry_util
 from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.geometry import geometry_util
+from autoarray import numba_util
+from autoarray.mask import mask_2d_util
 
 
-@decorator_util.jit()
-def grid_2d_centre_from(grid_2d_slim: np.ndarray) -> (float, float):
+@numba_util.jit()
+def grid_2d_centre_from(grid_2d_slim: np.ndarray) -> Tuple[float, float]:
     """
     Returns the centre of a grid from a 1D grid.
 
     Parameters
     ----------
-    grid_2d_slim :  np.ndarray
+    grid_2d_slim
         The 1D grid of values which are mapped to a 2D array.
 
     Returns
@@ -26,12 +27,12 @@ def grid_2d_centre_from(grid_2d_slim: np.ndarray) -> (float, float):
     return centre_y, centre_x
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_2d_slim_via_mask_from(
     mask_2d: np.ndarray,
-    pixel_scales: (float, float),
+    pixel_scales: Union[float, Tuple[float, float]],
     sub_size: int,
-    origin: (float, float) = (0.0, 0.0),
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     For a sub-grid, every unmasked pixel of its 2D mask with shape (total_y_pixels, total_x_pixels) is divided into
@@ -48,12 +49,12 @@ def grid_2d_slim_via_mask_from(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked and therefore included as part of the calculated
         sub-grid.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D mask array.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
     origin : (float, flloat)
         The (y,x) origin of the 2D array, which the sub-grid is shifted around.
@@ -112,9 +113,9 @@ def grid_2d_slim_via_mask_from(
 
 def grid_2d_via_mask_from(
     mask_2d: np.ndarray,
-    pixel_scales: (float, float),
+    pixel_scales: Union[float, Tuple[float, float]],
     sub_size: int,
-    origin: (float, float) = (0.0, 0.0),
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     For a sub-grid, every unmasked pixel of its 2D mask with shape (total_y_pixels, total_x_pixels) is divided into a
@@ -131,12 +132,12 @@ def grid_2d_via_mask_from(
 
     Parameters
     ----------
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values are unmasked and therefore included as part of the calculated
         sub-grid.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D mask array.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
     origin : (float, flloat)
         The (y,x) origin of the 2D array, which the sub-grid is shifted around.
@@ -165,10 +166,10 @@ def grid_2d_via_mask_from(
 
 
 def grid_2d_slim_via_shape_native_from(
-    shape_native: (int, int),
-    pixel_scales: (float, float),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
     sub_size: int,
-    origin: (float, float) = (0.0, 0.0),
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     For a sub-grid, every unmasked pixel of its 2D mask with shape (total_y_pixels, total_x_pixels) is divided into a
@@ -184,13 +185,13 @@ def grid_2d_slim_via_shape_native_from(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the 2D array the sub-grid of coordinates is computed for.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D mask array.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
-    origin : (float, float)
+    origin
         The (y,x) origin of the 2D array, which the sub-grid is shifted around.
 
     Returns
@@ -215,10 +216,10 @@ def grid_2d_slim_via_shape_native_from(
 
 
 def grid_2d_via_shape_native_from(
-    shape_native: (int, int),
-    pixel_scales: (float, float),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
     sub_size: int,
-    origin: (float, float) = (0.0, 0.0),
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     For a sub-grid, every unmasked pixel of its 2D mask with shape (total_y_pixels, total_x_pixels) is divided
@@ -234,11 +235,11 @@ def grid_2d_via_shape_native_from(
 
     Parameters
     ----------
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the 2D array the sub-grid of coordinates is computed for.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D mask array.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
     origin : (float, flloat)
         The (y,x) origin of the 2D array, which the sub-grid is shifted around.
@@ -261,12 +262,13 @@ def grid_2d_via_shape_native_from(
     )
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_scaled_2d_slim_radial_projected_from(
     extent: np.ndarray,
-    centre: (float, float),
-    pixel_scales: (float, float),
+    centre: Tuple[float, float],
+    pixel_scales: Union[float, Tuple[float, float]],
     sub_size: int,
+    shape_slim: Optional[int] = 0,
 ) -> np.ndarray:
     """
     Determine a projected radial grid of points from a 2D region of coordinates defined by an
@@ -303,14 +305,17 @@ def grid_scaled_2d_slim_radial_projected_from(
 
     Parameters
     ----------
-    extent : np.ndarray
+    extent
         The extent of the grid the radii grid is computed using, with format [xmin, xmax, ymin, ymax]
     centre : (float, flloat)
         The (y,x) central coordinate which the radial grid is traced outwards from.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the 2D mask array.
-    sub_size : int
+    sub_size
         The size of the sub-grid that each pixel of the 2D mask array is divided into.
+    shape_slim
+        Manually choose the shape of the 1D projected grid that is returned. If 0, the border based on the 2D grid is
+        used (due to numba None cannot be used as a default value).
 
     Returns
     -------
@@ -340,7 +345,8 @@ def grid_scaled_2d_slim_radial_projected_from(
     else:
         pixel_scale = pixel_scales[1]
 
-    shape_slim = sub_size * int((scaled_distance / pixel_scale)) + 1
+    if shape_slim == 0:
+        shape_slim = sub_size * int((scaled_distance / pixel_scale)) + 1
 
     grid_scaled_2d_slim_radii = np.zeros((shape_slim, 2))
 
@@ -356,12 +362,12 @@ def grid_scaled_2d_slim_radial_projected_from(
     return grid_scaled_2d_slim_radii
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_pixels_2d_slim_from(
     grid_scaled_2d_slim: np.ndarray,
-    shape_native: (int, int),
-    pixel_scales: (float, float),
-    origin: (float, float) = (0.0, 0.0),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     Convert a slimmed grid of 2d (y,x) scaled coordinates to a slimmed grid of 2d (y,x) pixel coordinate values. Pixel
@@ -380,9 +386,9 @@ def grid_pixels_2d_slim_from(
     ----------
     grid_scaled_2d_slim: np.ndarray
         The slimmed grid of 2D (y,x) coordinates in scaled units which are converted to pixel value coordinates.
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the original 2D array the scaled coordinates were computed on.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the original 2D array.
     origin : (float, flloat)
         The (y,x) origin of the grid, which the scaled grid is shifted to.
@@ -421,12 +427,12 @@ def grid_pixels_2d_slim_from(
     return grid_pixels_2d_slim
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_pixel_centres_2d_slim_from(
     grid_scaled_2d_slim: np.ndarray,
-    shape_native: (int, int),
-    pixel_scales: (float, float),
-    origin: (float, float) = (0.0, 0.0),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     Convert a slimmed grid of 2D (y,x) scaled coordinates to a slimmed grid of 2D (y,x) pixel values. Pixel coordinates
@@ -444,9 +450,9 @@ def grid_pixel_centres_2d_slim_from(
     ----------
     grid_scaled_2d_slim: np.ndarray
         The slimmed grid of 2D (y,x) coordinates in scaled units which is converted to pixel indexes.
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the original 2D array the scaled coordinates were computed on.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the original 2D array.
     origin : (float, flloat)
         The (y,x) origin of the grid, which the scaled grid is shifted
@@ -485,12 +491,12 @@ def grid_pixel_centres_2d_slim_from(
     return grid_pixels_2d_slim
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_pixel_indexes_2d_slim_from(
     grid_scaled_2d_slim: np.ndarray,
-    shape_native: (int, int),
-    pixel_scales: (float, float),
-    origin: (float, float) = (0.0, 0.0),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     Convert a slimmed grid of 2D (y,x) scaled coordinates to a slimmed grid of pixel indexes. Pixel coordinates are
@@ -513,9 +519,9 @@ def grid_pixel_indexes_2d_slim_from(
     ----------
     grid_scaled_2d_slim: np.ndarray
         The slimmed grid of 2D (y,x) coordinates in scaled units which is converted to slimmed pixel indexes.
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the original 2D array the scaled coordinates were computed on.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the original 2D array.
     origin : (float, flloat)
         The (y,x) origin of the grid, which the scaled grid is shifted.
@@ -551,12 +557,12 @@ def grid_pixel_indexes_2d_slim_from(
     return grid_pixel_indexes_2d_slim
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_scaled_2d_slim_from(
     grid_pixels_2d_slim: np.ndarray,
-    shape_native: (int, int),
-    pixel_scales: (float, float),
-    origin: (float, float) = (0.0, 0.0),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     Convert a slimmed grid of 2D (y,x) pixel coordinates to a slimmed grid of 2D (y,x) scaled values.
@@ -573,9 +579,9 @@ def grid_scaled_2d_slim_from(
     ----------
     grid_pixels_2d_slim: np.ndarray
         The slimmed grid of (y,x) coordinates in pixel values which is converted to scaled coordinates.
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the original 2D array the scaled coordinates were computed on.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the original 2D array.
     origin : (float, flloat)
         The (y,x) origin of the grid, which the scaled grid is shifted.
@@ -611,12 +617,12 @@ def grid_scaled_2d_slim_from(
     return grid_scaled_2d_slim
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_pixel_centres_2d_from(
     grid_scaled_2d: np.ndarray,
-    shape_native: (int, int),
-    pixel_scales: (float, float),
-    origin: (float, float) = (0.0, 0.0),
+    shape_native: Tuple[int, int],
+    pixel_scales: Union[float, Tuple[float, float]],
+    origin: Tuple[float, float] = (0.0, 0.0),
 ) -> np.ndarray:
     """
     Convert a native grid of 2D (y,x) scaled coordinates to a native grid of 2D (y,x) pixel values. Pixel coordinates
@@ -634,9 +640,9 @@ def grid_pixel_centres_2d_from(
     ----------
     grid_scaled_2d: np.ndarray
         The native grid of 2D (y,x) coordinates in scaled units which is converted to pixel indexes.
-    shape_native : (int, int)
+    shape_native
         The (y,x) shape of the original 2D array the scaled coordinates were computed on.
-    pixel_scales : (float, float)
+    pixel_scales
         The (y,x) scaled units to pixel units conversion factor of the original 2D array.
     origin : (float, flloat)
         The (y,x) origin of the grid, which the scaled grid is shifted
@@ -671,21 +677,92 @@ def grid_pixel_centres_2d_from(
     return grid_pixels_2d
 
 
-@decorator_util.jit()
+@numba_util.jit()
+def relocated_grid_via_jit_from(grid, border_grid):
+    """
+    Relocate the coordinates of a grid to its border if they are outside the border, where the border is
+    defined as all pixels at the edge of the grid's mask (see *mask._border_1d_indexes*).
+
+    This is performed as follows:
+
+    1: Use the mean value of the grid's y and x coordinates to determine the origin of the grid.
+    2: Compute the radial distance of every grid coordinate from the origin.
+    3: For every coordinate, find its nearest pixel in the border.
+    4: Determine if it is outside the border, by comparing its radial distance from the origin to its paired
+    border pixel's radial distance.
+    5: If its radial distance is larger, use the ratio of radial distances to move the coordinate to the
+    border (if its inside the border, do nothing).
+
+    The method can be used on uniform or irregular grids, however for irregular grids the border of the
+    'image-plane' mask is used to define border pixels.
+
+    Parameters
+    ----------
+    grid : Grid2D
+        The grid (uniform or irregular) whose pixels are to be relocated to the border edge if outside it.
+    border_grid : Grid2D
+        The grid of border (y,x) coordinates.
+    """
+
+    grid_relocated = np.zeros(grid.shape)
+    grid_relocated[:, :] = grid[:, :]
+
+    border_origin = np.zeros(2)
+    border_origin[0] = np.mean(border_grid[:, 0])
+    border_origin[1] = np.mean(border_grid[:, 1])
+    border_grid_radii = np.sqrt(
+        np.add(
+            np.square(np.subtract(border_grid[:, 0], border_origin[0])),
+            np.square(np.subtract(border_grid[:, 1], border_origin[1])),
+        )
+    )
+    border_min_radii = np.min(border_grid_radii)
+
+    grid_radii = np.sqrt(
+        np.add(
+            np.square(np.subtract(grid[:, 0], border_origin[0])),
+            np.square(np.subtract(grid[:, 1], border_origin[1])),
+        )
+    )
+
+    for pixel_index in range(grid.shape[0]):
+
+        if grid_radii[pixel_index] > border_min_radii:
+
+            closest_pixel_index = np.argmin(
+                np.square(grid[pixel_index, 0] - border_grid[:, 0])
+                + np.square(grid[pixel_index, 1] - border_grid[:, 1])
+            )
+
+            move_factor = (
+                border_grid_radii[closest_pixel_index] / grid_radii[pixel_index]
+            )
+
+            if move_factor < 1.0:
+
+                grid_relocated[pixel_index, :] = (
+                    move_factor * (grid[pixel_index, :] - border_origin[:])
+                    + border_origin[:]
+                )
+
+    return grid_relocated
+
+
+@numba_util.jit()
 def furthest_grid_2d_slim_index_from(
-    grid_2d_slim: np.ndarray, slim_indexes: np.ndarray, coordinate: (float, float)
+    grid_2d_slim: np.ndarray, slim_indexes: np.ndarray, coordinate: Tuple[float, float]
 ) -> int:
 
-    distance_from_centre = 0.0
+    distance_to_centre = 0.0
 
     for slim_index in slim_indexes:
 
         y = grid_2d_slim[slim_index, 0]
         x = grid_2d_slim[slim_index, 1]
-        distance_from_centre_new = (x - coordinate[1]) ** 2 + (y - coordinate[0]) ** 2
+        distance_to_centre_new = (x - coordinate[1]) ** 2 + (y - coordinate[0]) ** 2
 
-        if distance_from_centre_new >= distance_from_centre:
-            distance_from_centre = distance_from_centre_new
+        if distance_to_centre_new >= distance_to_centre:
+            distance_to_centre = distance_to_centre_new
             furthest_grid_2d_slim_index = slim_index
 
     return furthest_grid_2d_slim_index
@@ -709,9 +786,9 @@ def grid_2d_slim_from(
     ----------
     grid_2d_native : ndarray
         The native grid of (y,x) values which are mapped to the slimmed grid.
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values mean unmasked and are included in the mapping.
-    sub_size : int
+    sub_size
         The size (sub_size x sub_size) of each unmasked pixels sub-array.
 
     Returns
@@ -748,11 +825,11 @@ def grid_2d_native_from(
 
     Parameters
     ----------
-    grid_2d_slim : np.ndarray
+    grid_2d_slim
         The (y,x) values of the slimmed 2D grid which are mapped to the native 2D grid.
-    mask_2d : np.ndarray
+    mask_2d
         A 2D array of bools, where `False` values mean unmasked and are included in the mapping.
-    sub_size : int
+    sub_size
         The size (sub_size x sub_size) of each unmasked pixels sub-array.
 
     Returns
@@ -773,9 +850,11 @@ def grid_2d_native_from(
     return np.stack((grid_2d_native_y, grid_2d_native_x), axis=-1)
 
 
-@decorator_util.jit()
+@numba_util.jit()
 def grid_2d_slim_upscaled_from(
-    grid_slim: np.ndarray, upscale_factor: int, pixel_scales: (float, float)
+    grid_slim: np.ndarray,
+    upscale_factor: int,
+    pixel_scales: Union[float, Tuple[float, float]],
 ) -> np.ndarray:
     """
     From an input slimmed 2D grid, return an upscaled slimmed 2D grid where (y,x) coordinates are added at an
@@ -783,11 +862,11 @@ def grid_2d_slim_upscaled_from(
 
     Parameters
     ----------
-    grid_slim : np.ndarray
+    grid_slim
         The slimmed grid of (y,x) coordinates over which a square uniform grid is overlaid.
-    upscale_factor : int
+    upscale_factor
         The upscaled resolution at which the new grid coordinates are computed.
-    pixel_scales : (float, float)
+    pixel_scales
         The pixel scale of the uniform grid that laid over the irregular grid of (y,x) coordinates.
     """
 
@@ -830,7 +909,7 @@ def grid_2d_slim_upscaled_from(
 
 
 def grid_2d_of_points_within_radius(
-    radius: float, centre: (float, float), grid_2d: np.ndarray
+    radius: float, centre: Tuple[float, float], grid_2d: np.ndarray
 ):
     y_inside = []
     x_inside = []
