@@ -1,21 +1,22 @@
 from astropy import units
+import numpy as np
 import scipy.signal
 from skimage.transform import resize, rescale
 
-import numpy as np
+from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.structures.arrays.abstract_array import Header
 
-from autoarray.structures.arrays import abstract_array
-from autoarray.structures.arrays.two_d import array_2d
-from autoarray.structures.grids.two_d import grid_2d
-from autoarray.structures.arrays.two_d import array_2d_util
 from autoarray import exc
+from autoarray.structures.arrays.two_d import array_2d_util
 
 
-class Kernel2D(array_2d.Array2D):
+class Kernel2D(Array2D):
 
     # noinspection PyUnusedLocal
     def __new__(cls, array, mask, header=None, normalize=False, *args, **kwargs):
-        """An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
+        """
+        An array of values, which are paired to a uniform 2D mask of pixels and sub-pixels. Each entry
         on the array corresponds to a value at the centre of a sub-pixel in an unmasked pixel. See the *Array2D* class
         for a full description of how Arrays work.
 
@@ -23,9 +24,9 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        array : np.ndarray
+        array
             The values of the array.
-        mask : msk.Mask2D
+        mask :Mask2D
             The 2D mask associated with the array, defining the pixels each array value is paired with and
             originates from.
         normalize : bool
@@ -42,7 +43,8 @@ class Kernel2D(array_2d.Array2D):
     def manual_slim(
         cls, array, shape_native, pixel_scales, origin=(0.0, 0.0), normalize=False
     ):
-        """Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D, for example:
+        """
+        Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D, for example:
 
         kernel=np.array([1.0, 2.0, 3.0, 4.0])
 
@@ -53,22 +55,22 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
-        array = array_2d.Array2D.manual_slim(
+        array = Array2D.manual_slim(
             array=array,
             shape_native=shape_native,
             pixel_scales=pixel_scales,
@@ -79,10 +81,10 @@ class Kernel2D(array_2d.Array2D):
 
     @classmethod
     def manual_native(cls, array, pixel_scales, origin=(0.0, 0.0), normalize=False):
-        """Create an Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 2D, for example:
+        """
+        Create an Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 2D, for example:
 
-        kernel=np.ndarray([[1.0, 2.0],
-                         [3.0, 4.0]])
+        kernel=np.ndarray([[1.0, 2.0], [3.0, 4.0]])
 
         kernel=[[1.0, 2.0],
               [3.0, 4.0]]
@@ -92,20 +94,20 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_y_pixels*sub_size, total_x_pixel*sub_size] or a
              list of lists.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
-        array = array_2d.Array2D.manual_native(
+        array = Array2D.manual_native(
             array=array, pixel_scales=pixel_scales, origin=origin
         )
 
@@ -115,23 +117,24 @@ class Kernel2D(array_2d.Array2D):
     def manual(
         cls, array, pixel_scales, shape_native=None, origin=(0.0, 0.0), normalize=False
     ):
-        """Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D or 2D, automatically
+        """
+        Create a Kernel2D (see *Kernel2D.__new__*) by inputting the kernel values in 1D or 2D, automatically
         determining whether to use the 'manual_slim' or 'manual_native' methods.
 
         See the manual_slim and manual_native methods for examples.
         Parameters
         ----------
-        array : np.ndarray or list
+        array or list
             The values of the array input as an ndarray of shape [total_unmasked_pixels*(sub_size**2)] or a list of
             lists.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
@@ -154,28 +157,29 @@ class Kernel2D(array_2d.Array2D):
         fill_value,
         shape_native,
         pixel_scales,
-        sub_size=1,
+        sub_size: int = 1,
         origin=(0.0, 0.0),
         normalize=False,
     ):
-        """Create a Kernel2D (see *Kernel2D.__new__*) where all values are filled with an input fill value, analogous to
-         the method numpy ndarray.full.
+        """
+        Create a Kernel2D (see *Kernel2D.__new__*) where all values are filled with an input fill value, analogous to
+        the method numpy ndarray.full.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
         input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
-        fill_value : float
+        fill_value
             The value all array elements are filled with.
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
@@ -192,7 +196,8 @@ class Kernel2D(array_2d.Array2D):
 
     @classmethod
     def ones(cls, shape_native, pixel_scales, origin=(0.0, 0.0), normalize=False):
-        """Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with ones, analogous to the method numpy
+        """
+        Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with ones, analogous to the method numpy
         ndarray.ones.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -200,14 +205,14 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
@@ -222,7 +227,8 @@ class Kernel2D(array_2d.Array2D):
 
     @classmethod
     def zeros(cls, shape_native, pixel_scales, origin=(0.0, 0.0), normalize=False):
-        """Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with zeros, analogous to the method numpy
+        """
+        Create an Kernel2D (see *Kernel2D.__new__*) where all values are filled with zeros, analogous to the method numpy
         ndarray.ones.
 
         From 1D input the method cannot determine the 2D shape of the array and its mask, thus the shape_native must be
@@ -230,14 +236,14 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sub_size : int
+        sub_size
             The size (sub_size x sub_size) of each unmasked pixels sub-array.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
@@ -252,12 +258,13 @@ class Kernel2D(array_2d.Array2D):
 
     @classmethod
     def no_blur(cls, pixel_scales):
-        """Setup the Kernel2D as a kernel which does not convolve any signal, which is simply an array of shape (1, 1)
+        """
+        Setup the Kernel2D as a kernel which does not convolve any signal, which is simply an array of shape (1, 1)
         with value 1.
 
         Parameters
         ----------
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
         """
@@ -277,19 +284,20 @@ class Kernel2D(array_2d.Array2D):
         angle=0.0,
         normalize=False,
     ):
-        """Setup the Kernel2D as a 2D symmetric elliptical Gaussian profile, according to the equation:
+        """
+        Setup the Kernel2D as a 2D symmetric elliptical Gaussian profile, according to the equation:
 
         (1.0 / (sigma * sqrt(2.0*pi))) * exp(-0.5 * (r/sigma)**2)
 
 
         Parameters
         ----------
-        shape_native : (float, float)
+        shape_native
             The 2D shape of the mask the array is paired with.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        sigma : float
+        sigma
             The value of sigma in the equation, describing the size and full-width half maximum of the Gaussian.
         centre
             The (y,x) central coordinates of the Gaussian.
@@ -301,9 +309,7 @@ class Kernel2D(array_2d.Array2D):
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
 
-        grid = grid_2d.Grid2D.uniform(
-            shape_native=shape_native, pixel_scales=pixel_scales
-        )
+        grid = Grid2D.uniform(shape_native=shape_native, pixel_scales=pixel_scales)
         grid_shifted = np.subtract(grid, centre)
         grid_radius = np.sqrt(np.sum(grid_shifted ** 2.0, 1))
         theta_coordinate_to_profile = np.arctan2(
@@ -378,38 +384,32 @@ class Kernel2D(array_2d.Array2D):
         file_path : str
             The path the file is loaded from, including the filename and the ``.fits`` extension,
             e.g. '/path/to/filename.fits'
-        hdu : int
+        hdu
             The Header-Data Unit of the .fits file the array data is loaded from.
-        pixel_scales: (float, float) or float
+        pixel_scales
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
             it is converted to a (float, float) structure.
-        origin : (float, float)
+        origin
             The (y,x) scaled units origin of the mask's coordinate system.
         normalize : bool
             If True, the Kernel2D's array values are normalized such that they sum to 1.0.
         """
 
-        array = array_2d.Array2D.from_fits(
+        array = Array2D.from_fits(
             file_path=file_path, hdu=hdu, pixel_scales=pixel_scales, origin=origin
         )
 
-        header_sci_obj = array_2d_util.header_obj_from_fits(file_path=file_path, hdu=0)
-        header_hdu_obj = array_2d_util.header_obj_from_fits(
-            file_path=file_path, hdu=hdu
-        )
+        header_sci_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=0)
+        header_hdu_obj = array_2d_util.header_obj_from(file_path=file_path, hdu=hdu)
 
         return cls(
             array=array[:],
             mask=array.mask,
             normalize=normalize,
-            header=abstract_array.Header(
-                header_sci_obj=header_sci_obj, header_hdu_obj=header_hdu_obj
-            ),
+            header=Header(header_sci_obj=header_sci_obj, header_hdu_obj=header_hdu_obj),
         )
 
-    def rescaled_with_odd_dimensions_from_rescale_factor(
-        self, rescale_factor, normalize=False
-    ):
+    def rescaled_with_odd_dimensions_from(self, rescale_factor, normalize=False):
         """
         If the PSF kernel has one or two even-sized dimensions, return a PSF object where the kernel has odd-sized
         dimensions (odd-sized dimensions are required by a *Convolver*).
@@ -423,7 +423,7 @@ class Kernel2D(array_2d.Array2D):
 
         Parameters
         ----------
-        rescale_factor : float
+        rescale_factor
             The factor by which the kernel is rescaled. If this has a value of 1.0, the kernel is rescaled to the
             closest odd-sized dimensions (e.g. 20 -> 19). Higher / lower values scale to higher / lower dimensions.
         normalize : bool
@@ -490,21 +490,23 @@ class Kernel2D(array_2d.Array2D):
 
     @property
     def normalized(self):
-        """Normalize the Kernel2D such that its data_vector values sum to unity."""
+        """
+        Normalize the Kernel2D such that its data_vector values sum to unity.
+        """
         return self.__class__(array=self, mask=self.mask, normalize=True)
 
-    def convolved_array_from_array(self, array):
+    def convolved_array_from(self, array):
         """
         Convolve an array with this Kernel2D
 
         Parameters
         ----------
-        image : np.ndarray
+        image
             An array representing the image the Kernel2D is convolved with.
 
         Returns
         -------
-        convolved_image : np.ndarray
+        convolved_image
             An array representing the image after convolution.
 
         Raises
@@ -524,20 +526,20 @@ class Kernel2D(array_2d.Array2D):
             mask_2d=array_binned_2d.mask, array_2d_native=convolved_array_2d, sub_size=1
         )
 
-        return array_2d.Array2D(array=convolved_array_1d, mask=array_binned_2d.mask)
+        return Array2D(array=convolved_array_1d, mask=array_binned_2d.mask)
 
-    def convolved_array_from_array_and_mask(self, array, mask):
+    def convolved_array_with_mask_from(self, array, mask):
         """
         Convolve an array with this Kernel2D
 
         Parameters
         ----------
-        image : np.ndarray
+        image
             An array representing the image the Kernel2D is convolved with.
 
         Returns
         -------
-        convolved_image : np.ndarray
+        convolved_image
             An array representing the image after convolution.
 
         Raises
@@ -554,4 +556,4 @@ class Kernel2D(array_2d.Array2D):
             mask_2d=mask, array_2d_native=convolved_array_2d, sub_size=1
         )
 
-        return array_2d.Array2D(array=convolved_array_1d, mask=mask.mask_sub_1)
+        return Array2D(array=convolved_array_1d, mask=mask.mask_sub_1)
