@@ -1,8 +1,10 @@
 import logging
-
 import numpy as np
 
-from autoarray.structures.grids.two_d import grid_2d_irregular
+from autoconf import cached_property
+
+from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
+
 from autoarray.structures.arrays.two_d import array_2d_util
 
 logging.basicConfig()
@@ -30,7 +32,7 @@ class AbstractVisibilities(np.ndarray):
 
         Parameters
         ----------
-        visibilities : np.ndarray
+        visibilities
             The (real, imag) visibilities values.
         """
 
@@ -91,19 +93,17 @@ class AbstractVisibilities(np.ndarray):
     @property
     def in_grid(self):
         """Returns the 1D complex NumPy array of values as an irregular grid."""
-        return grid_2d_irregular.Grid2DIrregular(grid=self.in_array)
+        return Grid2DIrregular(grid=self.in_array)
 
     @property
     def shape_slim(self):
         return self.shape[0]
 
-    @property
-    @array_2d_util.Memoizer()
+    @cached_property
     def amplitudes(self):
         return np.sqrt(np.square(self.real) + np.square(self.imag))
 
-    @property
-    @array_2d_util.Memoizer()
+    @cached_property
     def phases(self):
         return np.arctan2(self.imag, self.real)
 
@@ -162,7 +162,7 @@ class Visibilities(AbstractVisibilities):
 
         Parameters
         ----------
-        visibilities : np.ndarray
+        visibilities
             The (real, imag) visibilities values.
         """
         return cls(visibilities=visibilities)
@@ -178,9 +178,9 @@ class Visibilities(AbstractVisibilities):
 
         Parameters
         ----------
-        fill_value : float
+        fill_value
             The value all real and imaginary array elements are filled with.
-        shape_slim : int
+        shape_slim
             The 1D shape of output visibilities.
         """
         return cls.manual_slim(
@@ -200,7 +200,7 @@ class Visibilities(AbstractVisibilities):
 
         Parameters
         ----------
-        shape_slim : int
+        shape_slim
             The 1D shape of output visibilities.
         """
         return cls.full(fill_value=1.0, shape_slim=shape_slim)
@@ -216,7 +216,7 @@ class Visibilities(AbstractVisibilities):
 
         Parameters
         ----------
-        shape_slim : int
+        shape_slim
             The 1D shape of output visibilities.
         """
         return cls.full(fill_value=0.0, shape_slim=shape_slim)
@@ -234,10 +234,10 @@ class Visibilities(AbstractVisibilities):
         file_path : str
             The path the file is loaded from, including the filename and the ``.fits`` extension,
             e.g. '/path/to/filename.fits'
-        hdu : int
+        hdu
             The Header-Data Unit of the .fits file the visibilitiy data is loaded from.
         """
-        visibilities_1d = array_2d_util.numpy_array_2d_from_fits(
+        visibilities_1d = array_2d_util.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=hdu
         )
         return cls.manual_slim(visibilities=visibilities_1d)
@@ -252,12 +252,12 @@ class VisibilitiesNoiseMap(Visibilities):
         an `Interferometer` dataset.
 
         This data structure behaves the same as the `Visibilities` structure (see `AbstractVisibilities.__new__`). The
-        only difference is that it includes a `WeightOperator` used by `Inversion`'s which use `LinearOperators` and
+        only difference is that it includes a `WeightOperator` used by `LinearEqn`'s which use `LinearOperators` and
         the library `PyLops` to fit `Interferometer` data.
 
         Parameters
         ----------
-        visibilities : np.ndarray
+        visibilities
             The (real, imag) visibilities values.
         """
 
