@@ -1,3 +1,4 @@
+from autoarray import numba_util as numba
 from autoarray.geometry import geometry_util as geometry
 from autoarray.mask import mask_1d_util as mask_1d
 from autoarray.mask import mask_2d_util as mask_2d
@@ -8,8 +9,9 @@ from autoarray.structures.grids.two_d import grid_2d_util as grid_2d
 from autoarray.structures.grids.two_d import sparse_util as sparse
 from autoarray.layout import layout_util as layout
 from autoarray.fit import fit_util as fit
-from autoarray.inversion import pixelization_util as pixelization
-from autoarray.inversion import mapper_util as mapper
-from autoarray.inversion import regularization_util as regularization
-from autoarray.inversion import inversion_util as inversion
+from autoarray.inversion.pixelizations import pixelization_util as pixelization
+from autoarray.inversion.mappers import mapper_util as mapper
+from autoarray.inversion.regularization import regularization_util as regularization
+from autoarray.inversion.linear_eqn import linear_eqn_util as linear_eqn
+from autoarray.inversion.inversion import inversion_util as inversion
 from autoarray.operators import transformer_util as transformer
