@@ -1,6 +1,5 @@
 import os
 from os import path
-
 import pytest
 from matplotlib import pyplot
 
@@ -130,11 +129,21 @@ def make_noise_map_7x7():
     return fixtures.make_noise_map_7x7()
 
 
+@pytest.fixture(name="convolver_7x7")
+def make_convolver_7x7():
+    return fixtures.make_convolver_7x7()
+
+
 @pytest.fixture(name="imaging_7x7")
 def make_imaging_7x7():
     return fixtures.make_imaging_7x7()
 
 
+@pytest.fixture(name="masked_imaging_7x7")
+def make_masked_imaging_7x7():
+    return fixtures.make_masked_imaging_7x7()
+
+
 @pytest.fixture(name="fit_imaging_7x7")
 def make_imaging_fit_x1_plane_7x7():
     return fixtures.make_imaging_fit_x1_plane_7x7()
