@@ -20,14 +20,14 @@ class TestImaging:
         psf = aa.Kernel2D.ones(shape_native=(3, 3), pixel_scales=1.0)
 
         imaging = aa.Imaging(
-            image=image, noise_map=noise_map, psf=psf, setup_convolver=False
+            image=image, noise_map=noise_map, psf=psf, pad_for_convolver=False
         )
 
         assert imaging.image.shape_native == (3, 3)
         assert imaging.noise_map.shape_native == (3, 3)
 
         imaging = aa.Imaging(
-            image=image, noise_map=noise_map, psf=psf, setup_convolver=True
+            image=image, noise_map=noise_map, psf=psf, pad_for_convolver=True
         )
 
         assert imaging.image.shape_native == (5, 5)
@@ -263,35 +263,15 @@ class TestImagingApplyMask:
         assert isinstance(masked_imaging_7x7.blurring_grid, aa.Grid2DIterate)
         assert (masked_imaging_7x7.blurring_grid.slim == blurring_grid_2d_7x7).all()
 
-        masked_imaging_7x7 = imaging_7x7.apply_mask(mask=sub_mask_2d_7x7)
-        masked_imaging_7x7 = masked_imaging_7x7.apply_settings(
-            settings=aa.SettingsImaging(
-                grid_class=aa.Grid2DInterpolate, pixel_scales_interp=1.0, sub_size=2
-            )
-        )
-
-        grid = aa.Grid2DInterpolate.from_mask(
-            mask=sub_mask_2d_7x7, pixel_scales_interp=1.0
-        )
-
-        blurring_grid = grid.blurring_grid_from_kernel_shape(kernel_shape_native=(3, 3))
-
-        assert isinstance(masked_imaging_7x7.grid, aa.Grid2DInterpolate)
-        assert (masked_imaging_7x7.grid == grid).all()
-        assert (masked_imaging_7x7.grid.vtx == grid.vtx).all()
-        assert (masked_imaging_7x7.grid.wts == grid.wts).all()
-
-        assert isinstance(masked_imaging_7x7.blurring_grid, aa.Grid2DInterpolate)
-        assert (masked_imaging_7x7.blurring_grid == blurring_grid).all()
-        assert (masked_imaging_7x7.blurring_grid.vtx == blurring_grid.vtx).all()
-        assert (masked_imaging_7x7.blurring_grid.wts == blurring_grid.wts).all()
-
-    def test__psf_and_convolvers(self, imaging_7x7, sub_mask_2d_7x7):
+    def test__psf_convolvers_and_w_tilde_native(self, imaging_7x7, sub_mask_2d_7x7):
 
         masked_imaging_7x7 = imaging_7x7.apply_mask(mask=sub_mask_2d_7x7)
 
         assert type(masked_imaging_7x7.psf) == aa.Kernel2D
         assert type(masked_imaging_7x7.convolver) == aa.Convolver
+        assert masked_imaging_7x7.w_tilde.curvature_preload.shape == (45,)
+        assert masked_imaging_7x7.w_tilde.indexes.shape == (45,)
+        assert masked_imaging_7x7.w_tilde.lengths.shape == (9,)
 
     def test__masked_imaging__uses_signal_to_noise_limit_and_radii(
         self, imaging_7x7, mask_2d_7x7
@@ -359,32 +339,6 @@ class TestImagingApplyMask:
         assert (masked_imaging.image == np.array([1.0])).all()
         assert (masked_imaging.noise_map == np.array([2.0])).all()
 
-    def test__modified_image_and_noise_map(
-        self, image_7x7, noise_map_7x7, imaging_7x7, sub_mask_2d_7x7
-    ):
-
-        masked_imaging_7x7 = imaging_7x7.apply_mask(mask=sub_mask_2d_7x7)
-
-        image_7x7[0] = 10.0
-        noise_map_7x7[0] = 11.0
-
-        noise_map_7x7[0] = 11.0
-
-        masked_imaging_7x7 = masked_imaging_7x7.modify_noise_map(
-            noise_map=noise_map_7x7
-        )
-
-        assert masked_imaging_7x7.noise_map[0] == 11.0
-
-        masked_imaging_7x7 = masked_imaging_7x7.modify_image_and_noise_map(
-            image=image_7x7, noise_map=noise_map_7x7
-        )
-
-        assert masked_imaging_7x7.image.slim[0] == 10.0
-        assert masked_imaging_7x7.image.native[0, 0] == 10.0
-        assert masked_imaging_7x7.noise_map.slim[0] == 11.0
-        assert masked_imaging_7x7.noise_map.native[0, 0] == 11.0
-
 
 class TestSimulatorImaging:
     def test__from_image__all_features_off(self):
@@ -396,7 +350,7 @@ class TestSimulatorImaging:
 
         simulator = aa.SimulatorImaging(exposure_time=1.0, add_poisson_noise=False)
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert (
             imaging.image.native
@@ -418,7 +372,7 @@ class TestSimulatorImaging:
             noise_seed=1,
         )
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert (
             imaging.image.native
@@ -442,7 +396,7 @@ class TestSimulatorImaging:
             exposure_time=1.0, psf=psf, add_poisson_noise=False, normalize_psf=False
         )
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert (
             imaging.image.native
@@ -460,7 +414,7 @@ class TestSimulatorImaging:
             exposure_time=20.0, add_poisson_noise=True, noise_seed=1
         )
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert imaging.image.native == pytest.approx(
             np.array([[0.0, 0.0, 0.0], [0.0, 1.05, 0.0], [0.0, 0.0, 0.0]]), 1e-2
@@ -489,7 +443,7 @@ class TestSimulatorImaging:
             noise_seed=1,
         )
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert (
             imaging.image.native
@@ -517,7 +471,7 @@ class TestSimulatorImaging:
             normalize_psf=False,
         )
 
-        imaging = simulator.from_image(image=image)
+        imaging = simulator.via_image_from(image=image)
 
         assert imaging.image.native == pytest.approx(
             np.array([[0.0, 1.05, 0.0], [1.3, 2.35, 1.05], [0.0, 1.05, 0.0]]), 1e-2
