@@ -11,69 +11,72 @@ import pytest
 acs_path = "{}".format(path.dirname(path.realpath(__file__)))
 
 
-def create_acs_fits(fits_path, acs_ccd, acs_ccd_0, acs_ccd_1, units):
+def create_acs_fits(
+    fits_path, acs_ccd, acs_ccd_0, acs_ccd_1, units, bias_file_path=None
+):
 
     if path.exists(fits_path):
         shutil.rmtree(fits_path)
 
     os.makedirs(fits_path)
 
-    new_hdul = fits.HDUList()
+    hdu_list = fits.HDUList()
 
-    new_hdul.append(fits.ImageHDU(acs_ccd))
-    new_hdul.append(fits.ImageHDU(acs_ccd_0))
-    new_hdul.append(fits.ImageHDU(acs_ccd))
-    new_hdul.append(fits.ImageHDU(acs_ccd))
-    new_hdul.append(fits.ImageHDU(acs_ccd_1))
-    new_hdul.append(fits.ImageHDU(acs_ccd))
+    hdu_list.append(fits.ImageHDU(acs_ccd))
+    hdu_list.append(fits.ImageHDU(acs_ccd_0))
+    hdu_list.append(fits.ImageHDU(acs_ccd))
+    hdu_list.append(fits.ImageHDU(acs_ccd))
+    hdu_list.append(fits.ImageHDU(acs_ccd_1))
+    hdu_list.append(fits.ImageHDU(acs_ccd))
 
-    new_hdul[0].header.set("CCDGAIN", 1.0, "Instrument GAIN")
-    new_hdul[0].header.set("TELESCOP", "HST", "Telescope Name")
-    new_hdul[0].header.set("INSTRUME", "ACS", "Instrument Name")
-    new_hdul[0].header.set("EXPTIME", 1000.0, "exposure duration (seconds)--calculated")
-    new_hdul[0].header.set(
+    hdu_list[0].header.set("CCDGAIN", 1.0, "Instrument GAIN")
+    hdu_list[0].header.set("TELESCOP", "HST", "Telescope Name")
+    hdu_list[0].header.set("INSTRUME", "ACS", "Instrument Name")
+    hdu_list[0].header.set("EXPTIME", 1000.0, "exposure duration (seconds)--calculated")
+    hdu_list[0].header.set(
         "DATE-OBS", "2000-01-01", "UT date of start of observation (yyyy-mm-dd)"
     )
-    new_hdul[0].header.set(
+    hdu_list[0].header.set(
         "TIME-OBS", "00:00:00", "UT time of start of observation (hh:mm:ss)"
     )
+    hdu_list[0].header.set("BIASFILE", f"jref${bias_file_path}", "Bias file name")
 
     if units in "COUNTS":
-        new_hdul[1].header.set("BUNIT", "COUNTS", "brightness units")
-        new_hdul[4].header.set("BUNIT", "COUNTS", "brightness units")
+        hdu_list[1].header.set("BUNIT", "COUNTS", "brightness units")
+        hdu_list[4].header.set("BUNIT", "COUNTS", "brightness units")
     elif units in "CPS":
-        new_hdul[1].header.set("BUNIT", "CPS", "brightness units")
-        new_hdul[4].header.set("BUNIT", "CPS", "brightness units")
+        hdu_list[1].header.set("BUNIT", "CPS", "brightness units")
+        hdu_list[4].header.set("BUNIT", "CPS", "brightness units")
 
-    new_hdul[1].header.set(
+    hdu_list[1].header.set(
         "BSCALE", 2.0, "scale factor for array value to physical value"
     )
-    new_hdul[1].header.set("BZERO", 10.0, "physical value for an array value of zero")
+    hdu_list[1].header.set("BZERO", 10.0, "physical value for an array value of zero")
 
-    new_hdul[4].header.set(
+    hdu_list[4].header.set(
         "BSCALE", 2.0, "scale factor for array value to physical value"
     )
-    new_hdul[4].header.set("BZERO", 10.0, "physical value for an array value of zero")
+    hdu_list[4].header.set("BZERO", 10.0, "physical value for an array value of zero")
 
-    new_hdul.writeto(path.join(fits_path, "acs_ccd.fits"))
+    hdu_list.writeto(path.join(fits_path, "acs_ccd.fits"))
 
 
 def create_acs_bias_fits(fits_path, bias_ccd, bias_ccd_0, bias_ccd_1):
 
-    new_hdul = fits.HDUList()
+    hdu_list = fits.HDUList()
 
-    new_hdul.append(fits.ImageHDU(bias_ccd))
-    new_hdul.append(fits.ImageHDU(bias_ccd_0))
-    new_hdul.append(fits.ImageHDU(bias_ccd))
-    new_hdul.append(fits.ImageHDU(bias_ccd))
-    new_hdul.append(fits.ImageHDU(bias_ccd_1))
-    new_hdul.append(fits.ImageHDU(bias_ccd))
+    hdu_list.append(fits.ImageHDU(bias_ccd))
+    hdu_list.append(fits.ImageHDU(bias_ccd_0))
+    hdu_list.append(fits.ImageHDU(bias_ccd))
+    hdu_list.append(fits.ImageHDU(bias_ccd))
+    hdu_list.append(fits.ImageHDU(bias_ccd_1))
+    hdu_list.append(fits.ImageHDU(bias_ccd))
 
-    new_hdul[0].header.set("CCDGAIN", 1.0, "Instrument GAIN")
-    new_hdul[1].header.set("BUNIT", "COUNTS", "brightness units")
-    new_hdul[4].header.set("BUNIT", "COUNTS", "brightness units")
+    hdu_list[0].header.set("CCDGAIN", 1.0, "Instrument GAIN")
+    hdu_list[1].header.set("BUNIT", "COUNTS", "brightness units")
+    hdu_list[4].header.set("BUNIT", "COUNTS", "brightness units")
 
-    new_hdul.writeto(path.join(fits_path, "acs_bias_ccd.fits"))
+    hdu_list.writeto(path.join(fits_path, "acs_bias_ccd.fits"))
 
 
 class TestArray2DACS:
@@ -163,8 +166,6 @@ class TestImageACS:
             "{}".format(path.dirname(path.realpath(__file__))), "files", "acs"
         )
 
-        file_path = path.join(fits_path, "acs_ccd.fits")
-
         create_acs_fits(
             fits_path=fits_path,
             acs_ccd=acs_ccd,
@@ -173,6 +174,8 @@ class TestImageACS:
             units="COUNTS",
         )
 
+        file_path = path.join(fits_path, "acs_ccd.fits")
+
         array = aa.acs.ImageACS.from_fits(file_path=file_path, quadrant_letter="B")
 
         assert array.header.exposure_time == 1000.0
@@ -221,7 +224,9 @@ class TestImageACS:
         assert array.in_counts.native[0, 0] == 30.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 30.0
 
@@ -232,7 +237,9 @@ class TestImageACS:
         assert array.native[0, 0] == (40.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 40.0
 
@@ -243,7 +250,9 @@ class TestImageACS:
         assert array.native[0, 0] == (10.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 10.0
 
@@ -254,7 +263,9 @@ class TestImageACS:
         assert array.native[0, 0] == (20.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 20.0
 
@@ -291,7 +302,9 @@ class TestImageACS:
         assert array.native[0, 0] == (30.0 * 1000.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 30.0
 
@@ -302,7 +315,9 @@ class TestImageACS:
         assert array.native[0, 0] == (40.0 * 1000.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 40.0
 
@@ -313,7 +328,9 @@ class TestImageACS:
         assert array.native[0, 0] == (10.0 * 1000.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 10.0
 
@@ -324,7 +341,9 @@ class TestImageACS:
         assert array.native[0, 0] == (20.0 * 1000.0 * 2.0) + 10.0
         assert array.shape_native == (2068, 2072)
 
-        array_original = array.header.array_from_electrons_to_original(array=array)
+        array_original = array.header.array_electrons_to_original(
+            array=array, use_calibrated_gain=False
+        )
 
         assert array_original.native[0, 0] == 20.0
 
@@ -428,6 +447,7 @@ class TestImageACS:
             acs_ccd_0=acs_ccd_0,
             acs_ccd_1=acs_ccd_1,
             units="COUNTS",
+            bias_file_path=path.join(fits_path, "acs_bias_ccd.fits"),
         )
 
         create_acs_bias_fits(
@@ -438,12 +458,11 @@ class TestImageACS:
         )
 
         file_path = path.join(fits_path, "acs_ccd.fits")
-        bias_path = path.join(fits_path, "acs_bias_ccd.fits")
 
         array = aa.acs.ImageACS.from_fits(
             file_path=file_path,
             quadrant_letter="A",
-            bias_path=bias_path,
+            bias_subtract_via_bias_file=True,
             use_calibrated_gain=False,
         )
 
@@ -455,7 +474,7 @@ class TestImageACS:
         array = aa.acs.ImageACS.from_fits(
             file_path=file_path,
             quadrant_letter="B",
-            bias_path=bias_path,
+            bias_subtract_via_bias_file=True,
             use_calibrated_gain=False,
         )
 
@@ -467,7 +486,7 @@ class TestImageACS:
         array = aa.acs.ImageACS.from_fits(
             file_path=file_path,
             quadrant_letter="C",
-            bias_path=bias_path,
+            bias_subtract_via_bias_file=True,
             use_calibrated_gain=False,
         )
 
@@ -479,8 +498,9 @@ class TestImageACS:
         array = aa.acs.ImageACS.from_fits(
             file_path=file_path,
             quadrant_letter="D",
-            bias_path=bias_path,
+            bias_subtract_via_bias_file=True,
             use_calibrated_gain=False,
+            bias_file_path=path.join(fits_path, "acs_bias_ccd.fits"),
         )
 
         assert array.native[0, 0] == pytest.approx(
@@ -591,14 +611,14 @@ class TestOutputQuadrants:
             overwrite=True,
         )
 
-        acs_ccd_output = aa.util.array_2d.numpy_array_2d_from_fits(
+        acs_ccd_output = aa.util.array_2d.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=1, do_not_scale_image_data=True
         )
 
         assert acs_ccd_output[0, 0] == 10.0
         assert acs_ccd_output[0, -1] == 20.0
 
-        acs_ccd_output = aa.util.array_2d.numpy_array_2d_from_fits(
+        acs_ccd_output = aa.util.array_2d.numpy_array_2d_via_fits_from(
             file_path=file_path, hdu=4, do_not_scale_image_data=True
         )
 
