@@ -593,7 +593,7 @@ class TestNewMasksFromMask:
         mask = aa.Mask2D.unmasked(shape_native=(5, 5), pixel_scales=1.0)
         mask[2, 2] = True
 
-        mask_resized = mask.resized_mask_from_new_shape(new_shape=(7, 7))
+        mask_resized = mask.resized_mask_from(new_shape=(7, 7))
 
         mask_resized_manual = np.full(fill_value=False, shape=(7, 7))
         mask_resized_manual[3, 3] = True
@@ -605,19 +605,19 @@ class TestNewMasksFromMask:
         mask = aa.Mask2D.unmasked(shape_native=(5, 5), pixel_scales=1.0)
         mask[2, 2] = True
 
-        mask_resized = mask.resized_mask_from_new_shape(new_shape=(3, 3))
+        mask_resized = mask.resized_mask_from(new_shape=(3, 3))
 
         mask_resized_manual = np.full(fill_value=False, shape=(3, 3))
         mask_resized_manual[1, 1] = True
 
         assert (mask_resized == mask_resized_manual).all()
 
-    def test__rescaled_mask_from_rescale_factor__compare_to_manual_mask(self):
+    def test__rescaled_mask_from__compare_to_manual_mask(self):
 
         mask = aa.Mask2D.unmasked(shape_native=(5, 5), pixel_scales=1.0)
         mask[2, 2] = True
 
-        mask_rescaled = mask.rescaled_mask_from_rescale_factor(rescale_factor=2.0)
+        mask_rescaled = mask.rescaled_mask_from(rescale_factor=2.0)
 
         mask_rescaled_manual = np.full(fill_value=False, shape=(3, 3))
         mask_rescaled_manual[1, 1] = True
@@ -652,7 +652,7 @@ class TestRegions:
             mask_2d=mask, sub_size=1
         )
 
-        assert mask._sub_native_index_for_sub_slim_index == pytest.approx(
+        assert mask.native_index_for_slim_index == pytest.approx(
             sub_native_index_for_sub_slim_index_2d, 1e-4
         )
 
@@ -696,7 +696,7 @@ class TestRegions:
             mask_2d=mask, kernel_shape_native=(3, 3)
         )
 
-        blurring_mask = mask.blurring_mask_from_kernel_shape(kernel_shape_native=(3, 3))
+        blurring_mask = mask.blurring_mask_from(kernel_shape_native=(3, 3))
 
         assert (blurring_mask == blurring_mask_via_util).all()
 
@@ -718,10 +718,10 @@ class TestRegions:
 
         edge_pixels_util = aa.util.mask_2d.edge_1d_indexes_from(mask_2d=mask)
 
-        assert mask._edge_1d_indexes == pytest.approx(edge_pixels_util, 1e-4)
-        assert mask._edge_2d_indexes[0] == pytest.approx(np.array([1, 1]), 1e-4)
-        assert mask._edge_2d_indexes[10] == pytest.approx(np.array([3, 3]), 1e-4)
-        assert mask._edge_1d_indexes.shape[0] == mask._edge_2d_indexes.shape[0]
+        assert mask.edge_1d_indexes == pytest.approx(edge_pixels_util, 1e-4)
+        assert mask.edge_2d_indexes[0] == pytest.approx(np.array([1, 1]), 1e-4)
+        assert mask.edge_2d_indexes[10] == pytest.approx(np.array([3, 3]), 1e-4)
+        assert mask.edge_1d_indexes.shape[0] == mask.edge_2d_indexes.shape[0]
 
     def test__edge_mask(self):
         mask = aa.Mask2D.manual(
@@ -774,10 +774,10 @@ class TestRegions:
 
         border_pixels_util = aa.util.mask_2d.border_slim_indexes_from(mask_2d=mask)
 
-        assert mask._border_1d_indexes == pytest.approx(border_pixels_util, 1e-4)
-        assert mask._border_2d_indexes[0] == pytest.approx(np.array([1, 1]), 1e-4)
-        assert mask._border_2d_indexes[10] == pytest.approx(np.array([3, 7]), 1e-4)
-        assert mask._border_1d_indexes.shape[0] == mask._border_2d_indexes.shape[0]
+        assert mask.border_1d_indexes == pytest.approx(border_pixels_util, 1e-4)
+        assert mask.border_2d_indexes[0] == pytest.approx(np.array([1, 1]), 1e-4)
+        assert mask.border_2d_indexes[10] == pytest.approx(np.array([3, 7]), 1e-4)
+        assert mask.border_1d_indexes.shape[0] == mask.border_2d_indexes.shape[0]
 
     def test__border_mask(self):
         mask = aa.Mask2D.manual(
@@ -832,7 +832,7 @@ class TestRegions:
             mask_2d=mask, sub_size=2
         )
 
-        assert mask._sub_border_flat_indexes == pytest.approx(
+        assert mask.sub_border_flat_indexes == pytest.approx(
             sub_border_pixels_util, 1e-4
         )
 
@@ -851,7 +851,7 @@ class TestRegions:
         )
 
         assert (
-            mask._sub_border_flat_indexes == np.array([0, 5, 9, 14, 23, 26, 31, 35])
+            mask.sub_border_flat_indexes == np.array([0, 5, 9, 14, 23, 26, 31, 35])
         ).all()
 
     def test__slim_index_for_sub_slim_index__compare_to_util(self):
@@ -866,7 +866,7 @@ class TestRegions:
         )
 
         assert (
-            mask._slim_index_for_sub_slim_index == slim_index_for_sub_slim_index_util
+            mask.slim_index_for_sub_slim_index == slim_index_for_sub_slim_index_util
         ).all()
 
     def test__sub_mask_index_for_sub_mask_1d_index__compare_to_array_util(self):
@@ -880,10 +880,63 @@ class TestRegions:
             mask_2d=mask, sub_size=2
         )
 
-        assert mask._sub_mask_index_for_sub_mask_1d_index == pytest.approx(
+        assert mask.sub_mask_index_for_sub_mask_1d_index == pytest.approx(
             sub_mask_index_for_sub_mask_1d_index, 1e-4
         )
 
+    def test__shape_masked_pixels(self):
+
+        mask = aa.Mask2D.manual(
+            mask=[
+                [True, True, True, True, True, True, True, True, True],
+                [True, False, False, False, False, False, False, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, False, True, False, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, False, False, False, False, False, False, True],
+                [True, True, True, True, True, True, True, True, True],
+            ],
+            pixel_scales=1.0,
+        )
+
+        assert mask.shape_native_masked_pixels == (7, 7)
+
+        mask = aa.Mask2D.manual(
+            mask=[
+                [True, True, True, True, True, True, True, True, False],
+                [True, False, False, False, False, False, False, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, False, True, False, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, False, False, False, False, False, False, True],
+                [True, True, True, True, True, True, True, True, True],
+            ],
+            pixel_scales=1.0,
+        )
+
+        assert mask.shape_native_masked_pixels == (8, 8)
+
+        mask = aa.Mask2D.manual(
+            mask=[
+                [True, True, True, True, True, True, True, False, True],
+                [True, False, False, False, False, False, False, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, False, True, False, True, False, True],
+                [True, False, True, False, False, False, True, False, True],
+                [True, False, True, True, True, True, True, False, True],
+                [True, False, False, False, False, False, False, False, True],
+                [True, True, True, True, True, True, True, True, True],
+            ],
+            pixel_scales=1.0,
+        )
+
+        assert mask.shape_native_masked_pixels == (8, 7)
+
 
 class TestZoom:
     def test__odd_sized_false_mask__centre_is_0_0__pixels_from_centre_are_0_0(self):
@@ -1648,9 +1701,7 @@ class TestGridConversions:
             shape_native=(2, 2),
             pixel_scales=(2.0, 4.0),
         )
-        grid_pixels = mask.grid_pixels_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled_1d
-        )
+        grid_pixels = mask.grid_pixels_from(grid_scaled_1d=grid_scaled_1d)
 
         assert (grid_pixels == grid_pixels_util).all()
         assert (grid_pixels.slim == grid_pixels_util).all()
@@ -1667,9 +1718,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
         )
 
-        grid_pixels = mask.grid_pixel_centres_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled_1d
-        )
+        grid_pixels = mask.grid_pixel_centres_from(grid_scaled_1d=grid_scaled_1d)
 
         assert (grid_pixels == grid_pixels_util).all()
 
@@ -1683,9 +1732,7 @@ class TestGridConversions:
             pixel_scales=(7.0, 2.0),
         )
 
-        grid_pixels = mask.grid_pixel_centres_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled_1d
-        )
+        grid_pixels = mask.grid_pixel_centres_from(grid_scaled_1d=grid_scaled_1d)
 
         assert (grid_pixels == grid_pixels_util).all()
 
@@ -1700,9 +1747,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
         )
 
-        grid_pixel_indexes = mask.grid_pixel_indexes_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixel_indexes = mask.grid_pixel_indexes_from(grid_scaled_1d=grid_scaled)
 
         assert (grid_pixel_indexes == grid_pixel_indexes_util).all()
 
@@ -1716,9 +1761,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 4.0),
         )
 
-        grid_pixels = mask.grid_pixel_indexes_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixels = mask.grid_pixel_indexes_from(grid_scaled_1d=grid_scaled)
 
         assert (grid_pixels == grid_pixels_util).all()
 
@@ -1733,7 +1776,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
         )
 
-        grid_pixels = mask.grid_scaled_from_grid_pixels_1d(grid_pixels_1d=grid_pixels)
+        grid_pixels = mask.grid_scaled_from(grid_pixels_1d=grid_pixels)
 
         assert (grid_pixels == grid_pixels_util).all()
 
@@ -1746,7 +1789,7 @@ class TestGridConversions:
             shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
-        grid_pixels = mask.grid_scaled_from_grid_pixels_1d(grid_pixels_1d=grid_pixels)
+        grid_pixels = mask.grid_scaled_from(grid_pixels_1d=grid_pixels)
 
         assert (grid_pixels == grid_pixels_util).all()
 
@@ -1763,7 +1806,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixels_from_grid_scaled_1d(grid_scaled_1d=grid_scaled)
+        grid_pixels = mask.grid_pixels_from(grid_scaled_1d=grid_scaled)
         assert (grid_pixels == grid_pixels_util).all()
 
         grid_pixels_util = aa.util.grid_2d.grid_pixel_indexes_2d_slim_from(
@@ -1772,9 +1815,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixel_indexes_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixels = mask.grid_pixel_indexes_from(grid_scaled_1d=grid_scaled)
         assert grid_pixels == pytest.approx(grid_pixels_util, 1e-4)
 
         grid_pixels_util = aa.util.grid_2d.grid_pixel_centres_2d_slim_from(
@@ -1783,9 +1824,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixel_centres_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixels = mask.grid_pixel_centres_from(grid_scaled_1d=grid_scaled)
         assert grid_pixels == pytest.approx(grid_pixels_util, 1e-4)
 
         grid_pixels = np.array([[0, 0], [0, 1], [1, 0], [1, 1]])
@@ -1797,7 +1836,7 @@ class TestGridConversions:
             origin=(1.0, 2.0),
         )
 
-        grid_scaled = mask.grid_scaled_from_grid_pixels_1d(grid_pixels_1d=grid_pixels)
+        grid_scaled = mask.grid_scaled_from(grid_pixels_1d=grid_pixels)
 
         assert (grid_scaled == grid_scaled_util).all()
 
@@ -1813,7 +1852,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixels_from_grid_scaled_1d(grid_scaled_1d=grid_scaled)
+        grid_pixels = mask.grid_pixels_from(grid_scaled_1d=grid_scaled)
         assert (grid_pixels == grid_pixels_util).all()
 
         grid_pixels_util = aa.util.grid_2d.grid_pixel_indexes_2d_slim_from(
@@ -1822,9 +1861,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixel_indexes_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixels = mask.grid_pixel_indexes_from(grid_scaled_1d=grid_scaled)
         assert (grid_pixels == grid_pixels_util).all()
 
         grid_pixels_util = aa.util.grid_2d.grid_pixel_centres_2d_slim_from(
@@ -1833,9 +1870,7 @@ class TestGridConversions:
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
         )
-        grid_pixels = mask.grid_pixel_centres_from_grid_scaled_1d(
-            grid_scaled_1d=grid_scaled
-        )
+        grid_pixels = mask.grid_pixel_centres_from(grid_scaled_1d=grid_scaled)
         assert grid_pixels == pytest.approx(grid_pixels_util, 1e-4)
 
         grid_pixels = np.array([[0, 0], [0, 1], [1, 0], [1, 1]])
@@ -1847,6 +1882,6 @@ class TestGridConversions:
             origin=(1.0, 2.0),
         )
 
-        grid_scaled = mask.grid_scaled_from_grid_pixels_1d(grid_pixels_1d=grid_pixels)
+        grid_scaled = mask.grid_scaled_from(grid_pixels_1d=grid_pixels)
 
         assert (grid_scaled == grid_scaled_util).all()
