@@ -11,92 +11,12 @@ test_data_path = os.path.join(
 )
 
 
-@pytest.fixture(name="memoizer")
-def make_memoizer():
-    return util.array_2d.Memoizer()
-
-
-class TestMemoizer:
-    def test_storing(self, memoizer):
-        @memoizer
-        def func(arg):
-            return "result for {}".format(arg)
-
-        func(1)
-        func(2)
-        func(1)
-
-        assert memoizer.results == {
-            "('arg', 1)": "result for 1",
-            "('arg', 2)": "result for 2",
-        }
-        assert memoizer.calls == 2
-
-    def test_multiple_arguments(self, memoizer):
-        @memoizer
-        def func(arg1, arg2):
-            return arg1 * arg2
-
-        func(1, 2)
-        func(2, 1)
-        func(1, 2)
-
-        assert memoizer.results == {
-            "('arg1', 1), ('arg2', 2)": 2,
-            "('arg1', 2), ('arg2', 1)": 2,
-        }
-        assert memoizer.calls == 2
-
-    def test_key_word_arguments(self, memoizer):
-        @memoizer
-        def func(arg1=0, arg2=0):
-            return arg1 * arg2
-
-        func(arg1=1)
-        func(arg2=1)
-        func(arg1=1)
-        func(arg1=1, arg2=1)
-
-        assert memoizer.results == {
-            "('arg1', 1)": 0,
-            "('arg2', 1)": 0,
-            "('arg1', 1), ('arg2', 1)": 1,
-        }
-        assert memoizer.calls == 3
-
-    def test_key_word_for_positional(self, memoizer):
-        @memoizer
-        def func(arg):
-            return "result for {}".format(arg)
-
-        func(1)
-        func(arg=2)
-        func(arg=1)
-
-        assert memoizer.calls == 2
-
-    def test_methods(self, memoizer):
-        class Class:
-            def __init__(self, value):
-                self.value = value
-
-            @memoizer
-            def method(self):
-                return self.value
-
-        one = Class(1)
-        two = Class(2)
-
-        assert one.method() == 1
-        assert two.method() == 2
-
-
 class TestResize:
     def test__trim__from_7x7_to_3x3(self):
         array = np.ones((7, 7))
         array[3, 3] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3)
         )
 
@@ -108,7 +28,7 @@ class TestResize:
         array = np.ones((7, 7))
         array[3, 3] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(4, 4)
         )
 
@@ -129,7 +49,7 @@ class TestResize:
         array = np.ones((6, 6))
         array[2:4, 2:4] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(4, 4)
         )
 
@@ -150,7 +70,7 @@ class TestResize:
         array = np.ones((6, 6))
         array[2:4, 2:4] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3)
         )
 
@@ -162,7 +82,7 @@ class TestResize:
         array = np.ones((5, 4))
         array[2, 1:3] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 2)
         )
 
@@ -172,7 +92,7 @@ class TestResize:
         array = np.ones((4, 5))
         array[1:3, 2] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(2, 3)
         )
 
@@ -182,7 +102,7 @@ class TestResize:
 
         array = np.ones((7, 7))
         array[4, 4] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3), origin=(4, 4)
         )
         assert (
@@ -191,7 +111,7 @@ class TestResize:
 
         array = np.ones((6, 6))
         array[3, 4] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3), origin=(3, 4)
         )
         assert (
@@ -200,7 +120,7 @@ class TestResize:
 
         array = np.ones((9, 8))
         array[4, 3] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3), origin=(4, 3)
         )
         assert (
@@ -209,7 +129,7 @@ class TestResize:
 
         array = np.ones((8, 9))
         array[3, 5] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(3, 3), origin=(3, 5)
         )
         assert (
@@ -221,7 +141,7 @@ class TestResize:
         array = np.ones((3, 3))
         array[1, 1] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(5, 5)
         )
 
@@ -243,7 +163,7 @@ class TestResize:
         array = np.ones((3, 3))
         array[1, 1] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(4, 4)
         )
 
@@ -264,7 +184,7 @@ class TestResize:
         array = np.ones((4, 4))
         array[1:3, 1:3] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(6, 6)
         )
 
@@ -287,7 +207,7 @@ class TestResize:
         array = np.ones((4, 4))
         array[1:3, 1:3] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(5, 5)
         )
 
@@ -308,7 +228,7 @@ class TestResize:
         array = np.ones((3, 2))
         array[1, 0:2] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(5, 4)
         )
 
@@ -329,7 +249,7 @@ class TestResize:
         array = np.ones((2, 3))
         array[0:2, 1] = 2.0
 
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(4, 5)
         )
 
@@ -349,7 +269,7 @@ class TestResize:
 
         array = np.ones((3, 3))
         array[2, 2] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(5, 5), origin=(2, 2)
         )
 
@@ -368,7 +288,7 @@ class TestResize:
 
         array = np.ones((2, 3))
         array[0, 0] = 2.0
-        modified = util.array_2d.resized_array_2d_from_array_2d(
+        modified = util.array_2d.resized_array_2d_from(
             array_2d=array, resized_shape=(4, 5), origin=(0, 1)
         )
 
@@ -386,15 +306,15 @@ class TestResize:
 
 
 class TestFits:
-    def test__numpy_array_2d_from_fits(self):
+    def test__numpy_array_2d_via_fits_from(self):
 
-        arr = util.array_2d.numpy_array_2d_from_fits(
+        arr = util.array_2d.numpy_array_2d_via_fits_from(
             file_path=os.path.join(test_data_path, "3x3_ones.fits"), hdu=0
         )
 
         assert (arr == np.ones((3, 3))).all()
 
-        arr = util.array_2d.numpy_array_2d_from_fits(
+        arr = util.array_2d.numpy_array_2d_via_fits_from(
             file_path=os.path.join(test_data_path, "4x3_ones.fits"), hdu=0
         )
 
@@ -411,13 +331,15 @@ class TestFits:
 
         util.array_2d.numpy_array_2d_to_fits(arr, file_path=file_path)
 
-        array_load = util.array_2d.numpy_array_2d_from_fits(file_path=file_path, hdu=0)
+        array_load = util.array_2d.numpy_array_2d_via_fits_from(
+            file_path=file_path, hdu=0
+        )
 
         assert (arr == array_load).all()
 
-    def test__header_obj_from_fits(self):
+    def test__header_obj_from(self):
 
-        header_obj = util.array_2d.header_obj_from_fits(
+        header_obj = util.array_2d.header_obj_from(
             file_path=os.path.join(test_data_path, "3x3_ones.fits"), hdu=0
         )
 
